@@ -1,17 +1,28 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
-/************************************************
-
-  rbglib_keyfile.c -
-
-  $Author: sakai $
-  $Date: 2007/06/16 02:46:28 $
-
-  Copyright (C) 2006 Masao Mutoh
-************************************************/
+/*
+ *  Copyright (C) 2011  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2006  Masao Mutoh
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
+ */
 
 #include "rbgprivate.h"
 
 #if GLIB_CHECK_VERSION(2,6,0)
+#if !GLIB_CHECK_VERSION(2,31,2)
 /************************************************/
 static GKeyFile*
 keyfile_copy(const GKeyFile* keyfile)
@@ -26,7 +37,6 @@ keyfile_copy(const GKeyFile* keyfile)
   return (GKeyFile*)keyfile;
 }
 
-
 GType
 g_key_file_get_type(void)
 {
@@ -38,25 +48,27 @@ g_key_file_get_type(void)
   return our_type;
 }
 /************************************************/
+#endif
 
+#define RG_TARGET_NAMESPACE cKeyFile
 #define _SELF(self) ((GKeyFile*)(RVAL2BOXED(self, G_TYPE_KEY_FILE)))
 
 static VALUE
-keyfile_initialize(VALUE self)
+rg_initialize(VALUE self)
 {
     G_INITIALIZE(self, g_key_file_new());
     return Qnil;
 }
 
 static VALUE
-keyfile_set_list_separator(VALUE self, VALUE sep)
+rg_set_list_separator(VALUE self, VALUE sep)
 {
     g_key_file_set_list_separator(_SELF(self), NUM2INT(sep));
     return self;
 }
 
 static VALUE
-keyfile_load_from_file(int argc, VALUE *argv, VALUE self)
+rg_load_from_file(int argc, VALUE *argv, VALUE self)
 {
     VALUE file, flags;
     GError* error = NULL;
@@ -79,7 +91,7 @@ keyfile_load_from_file(int argc, VALUE *argv, VALUE self)
 }
 
 static VALUE
-keyfile_load_from_data(int argc, VALUE *argv, VALUE self)
+rg_load_from_data(int argc, VALUE *argv, VALUE self)
 {
     VALUE data, flags;
     GError* error = NULL;
@@ -104,7 +116,7 @@ keyfile_load_from_data(int argc, VALUE *argv, VALUE self)
 }
 
 static VALUE
-keyfile_load_from_data_dirs(int argc, VALUE *argv, VALUE self)
+rg_load_from_data_dirs(int argc, VALUE *argv, VALUE self)
 {
     VALUE file, flags;
     GError* error = NULL;
@@ -131,7 +143,7 @@ keyfile_load_from_data_dirs(int argc, VALUE *argv, VALUE self)
 
 #if GLIB_CHECK_VERSION(2, 14, 0)
 static VALUE
-keyfile_load_from_dirs(int argc, VALUE *argv, VALUE self)
+rg_load_from_dirs(int argc, VALUE *argv, VALUE self)
 {
     VALUE rb_file, rb_search_dirs, rb_flags;
     GError* error = NULL;
@@ -150,24 +162,24 @@ keyfile_load_from_dirs(int argc, VALUE *argv, VALUE self)
         flags = RVAL2GFLAGS(rb_flags, G_TYPE_KEY_FILE_FLAGS);
 
     if (search_dirs != NULL)
-	success = g_key_file_load_from_dirs(_SELF(self), file,
-					    search_dirs,
-					    &full_path, flags, &error);
+        success = g_key_file_load_from_dirs(_SELF(self), file,
+                                            search_dirs,
+                                            &full_path, flags, &error);
     else
-	success = g_key_file_load_from_data_dirs(_SELF(self), file,
-						 &full_path, flags, &error);
+        success = g_key_file_load_from_data_dirs(_SELF(self), file,
+                                                 &full_path, flags, &error);
 
     g_free(search_dirs);
 
     if (!success)
-	RAISE_GERROR(error);
+        RAISE_GERROR(error);
 
     return CSTR2RVAL(full_path);
 }
 #endif
 
 static VALUE
-keyfile_to_data(VALUE self)
+rg_to_data(VALUE self)
 {
     GError* error = NULL;
     gchar* data = g_key_file_to_data(_SELF(self), NULL, &error);
@@ -178,19 +190,19 @@ keyfile_to_data(VALUE self)
 }
 
 static VALUE
-keyfile_get_start_group(VALUE self)
+rg_start_group(VALUE self)
 {
     return CSTR2RVAL(g_key_file_get_start_group(_SELF(self)));
 }
 
 static VALUE
-keyfile_get_groups(VALUE self)
+rg_groups(VALUE self)
 {
     return STRV2RVAL_FREE(g_key_file_get_groups(_SELF(self), NULL));
 }
 
 static VALUE
-keyfile_get_keys(VALUE self, VALUE group_name)
+rg_get_keys(VALUE self, VALUE group_name)
 {
     GError *error = NULL;
     gchar **keys = g_key_file_get_keys(_SELF(self),
@@ -204,14 +216,14 @@ keyfile_get_keys(VALUE self, VALUE group_name)
 }
 
 static VALUE
-keyfile_has_group(VALUE self, VALUE group_name)
+rg_has_group_p(VALUE self, VALUE group_name)
 {
     return CBOOL2RVAL(g_key_file_has_group(_SELF(self), 
                                            (const gchar*)RVAL2CSTR(group_name)));
 }
 
 static VALUE
-keyfile_has_key(VALUE self, VALUE group_name, VALUE key)
+rg_has_key_p(VALUE self, VALUE group_name, VALUE key)
 {
     GError* error = NULL;
     gboolean ret = g_key_file_has_key(_SELF(self), 
@@ -225,7 +237,7 @@ keyfile_has_key(VALUE self, VALUE group_name, VALUE key)
 }
 
 static VALUE
-keyfile_get_value(VALUE self, VALUE group_name, VALUE key)
+rg_get_value(VALUE self, VALUE group_name, VALUE key)
 {
     GError* error = NULL;
     gchar* ret = g_key_file_get_value(_SELF(self), 
@@ -239,7 +251,7 @@ keyfile_get_value(VALUE self, VALUE group_name, VALUE key)
 }
 
 static VALUE
-keyfile_get_string(VALUE self, VALUE group_name, VALUE key)
+rg_get_string(VALUE self, VALUE group_name, VALUE key)
 {
     GError* error = NULL;
     gchar* ret = g_key_file_get_string(_SELF(self), 
@@ -253,7 +265,7 @@ keyfile_get_string(VALUE self, VALUE group_name, VALUE key)
 }
 
 static VALUE
-keyfile_get_locale_string(int argc, VALUE *argv, VALUE self)
+rg_get_locale_string(int argc, VALUE *argv, VALUE self)
 {
     VALUE group_name, key, locale;
     GError* error = NULL;
@@ -264,7 +276,7 @@ keyfile_get_locale_string(int argc, VALUE *argv, VALUE self)
     ret = g_key_file_get_locale_string(_SELF(self), 
                                        (const gchar*)RVAL2CSTR(group_name),
                                        (const gchar*)RVAL2CSTR(key),
-                                       (const gchar*)(NIL_P(locale) ? NULL : RVAL2CSTR(locale)),
+                                       (const gchar*)RVAL2CSTR_ACCEPT_NIL(locale),
                                        &error);
 
     if (error) RAISE_GERROR(error);
@@ -273,7 +285,7 @@ keyfile_get_locale_string(int argc, VALUE *argv, VALUE self)
 }
 
 static VALUE
-keyfile_get_boolean(VALUE self, VALUE group_name, VALUE key)
+rg_get_boolean(VALUE self, VALUE group_name, VALUE key)
 {
     GError* error = NULL;
     gboolean ret = g_key_file_get_boolean(_SELF(self), 
@@ -287,7 +299,7 @@ keyfile_get_boolean(VALUE self, VALUE group_name, VALUE key)
 }
 
 static VALUE
-keyfile_get_integer(VALUE self, VALUE group_name, VALUE key)
+rg_get_integer(VALUE self, VALUE group_name, VALUE key)
 {
     GError* error = NULL;
     gint ret = g_key_file_get_integer(_SELF(self), 
@@ -302,7 +314,7 @@ keyfile_get_integer(VALUE self, VALUE group_name, VALUE key)
 
 #if GLIB_CHECK_VERSION(2,12,0)
 static VALUE
-keyfile_get_double(VALUE self, VALUE group_name, VALUE key)
+rg_get_double(VALUE self, VALUE group_name, VALUE key)
 {
     GError* error = NULL;
     gdouble ret = g_key_file_get_double(_SELF(self), 
@@ -317,7 +329,7 @@ keyfile_get_double(VALUE self, VALUE group_name, VALUE key)
 #endif
 
 static VALUE
-keyfile_get_string_list(VALUE self, VALUE group_name, VALUE key)
+rg_get_string_list(VALUE self, VALUE group_name, VALUE key)
 {
     VALUE ary;
     gsize i;
@@ -340,7 +352,7 @@ keyfile_get_string_list(VALUE self, VALUE group_name, VALUE key)
 }
 
 static VALUE
-keyfile_get_locale_string_list(int argc, VALUE *argv, VALUE self)
+rg_get_locale_string_list(int argc, VALUE *argv, VALUE self)
 {
     VALUE group_name, key, locale;
     GError* error = NULL;
@@ -354,7 +366,7 @@ keyfile_get_locale_string_list(int argc, VALUE *argv, VALUE self)
     ret = g_key_file_get_locale_string_list(_SELF(self), 
                                             (const gchar*)RVAL2CSTR(group_name),
                                             (const gchar*)RVAL2CSTR(key),
-                                            (const gchar*)(NIL_P(locale) ? NULL : RVAL2CSTR(locale)),
+                                            (const gchar*)RVAL2CSTR_ACCEPT_NIL(locale),
                                             &length, &error);
 
     if (error) RAISE_GERROR(error);
@@ -369,7 +381,7 @@ keyfile_get_locale_string_list(int argc, VALUE *argv, VALUE self)
 }
 
 static VALUE
-keyfile_get_boolean_list(VALUE self, VALUE group_name, VALUE key)
+rg_get_boolean_list(VALUE self, VALUE group_name, VALUE key)
 {
     VALUE ary;
     gsize i;
@@ -390,7 +402,7 @@ keyfile_get_boolean_list(VALUE self, VALUE group_name, VALUE key)
 }
 
 static VALUE
-keyfile_get_integer_list(VALUE self, VALUE group_name, VALUE key)
+rg_get_integer_list(VALUE self, VALUE group_name, VALUE key)
 {
     VALUE ary;
     gsize i;
@@ -412,7 +424,7 @@ keyfile_get_integer_list(VALUE self, VALUE group_name, VALUE key)
 
 #if GLIB_CHECK_VERSION(2,12,0)
 static VALUE
-keyfile_get_double_list(VALUE self, VALUE group_name, VALUE key)
+rg_get_double_list(VALUE self, VALUE group_name, VALUE key)
 {
     VALUE ary;
     gsize i;
@@ -422,7 +434,7 @@ keyfile_get_double_list(VALUE self, VALUE group_name, VALUE key)
                                               (const gchar*)RVAL2CSTR(group_name),
                                               (const gchar*)RVAL2CSTR(key),
                                               &length, &error);
-    
+
     if (error) RAISE_GERROR(error);
 
     ary = rb_ary_new();
@@ -434,21 +446,21 @@ keyfile_get_double_list(VALUE self, VALUE group_name, VALUE key)
 #endif
 
 static VALUE
-keyfile_get_comment(VALUE self, VALUE group_name, VALUE key)
+rg_get_comment(VALUE self, VALUE group_name, VALUE key)
 {
     GError* error = NULL;
     gchar* ret = g_key_file_get_comment(_SELF(self), 
                                         (const gchar*)RVAL2CSTR(group_name),
                                         (const gchar*)RVAL2CSTR(key),
                                         &error);
-    
+
     if (error) RAISE_GERROR(error);
 
     return CSTR2RVAL_FREE(ret);
 }
 
 static VALUE
-keyfile_set_value(VALUE self, VALUE group_name, VALUE key, VALUE value)
+rg_set_value(VALUE self, VALUE group_name, VALUE key, VALUE value)
 {
     g_key_file_set_value(_SELF(self), (const gchar*)RVAL2CSTR(group_name),
                          (const gchar*)RVAL2CSTR(key),
@@ -457,7 +469,7 @@ keyfile_set_value(VALUE self, VALUE group_name, VALUE key, VALUE value)
 }
 
 static VALUE
-keyfile_set_string(VALUE self, VALUE group_name, VALUE key, VALUE string)
+rg_set_string(VALUE self, VALUE group_name, VALUE key, VALUE string)
 {
     g_key_file_set_string(_SELF(self), (const gchar*)RVAL2CSTR(group_name),
                          (const gchar*)RVAL2CSTR(key),
@@ -466,7 +478,7 @@ keyfile_set_string(VALUE self, VALUE group_name, VALUE key, VALUE string)
 }
 
 static VALUE
-keyfile_set_locale_string(VALUE self, VALUE group_name, VALUE key, VALUE locale, VALUE locale_string)
+rg_set_locale_string(VALUE self, VALUE group_name, VALUE key, VALUE locale, VALUE locale_string)
 {
     g_key_file_set_locale_string(_SELF(self), (const gchar*)RVAL2CSTR(group_name),
                                  (const gchar*)RVAL2CSTR(key),
@@ -476,7 +488,7 @@ keyfile_set_locale_string(VALUE self, VALUE group_name, VALUE key, VALUE locale,
 }
 
 static VALUE
-keyfile_set_boolean(VALUE self, VALUE group_name, VALUE key, VALUE value)
+rg_set_boolean(VALUE self, VALUE group_name, VALUE key, VALUE value)
 {
     g_key_file_set_boolean(_SELF(self), (const gchar*)RVAL2CSTR(group_name),
                            (const gchar*)RVAL2CSTR(key),
@@ -485,7 +497,7 @@ keyfile_set_boolean(VALUE self, VALUE group_name, VALUE key, VALUE value)
 }
 
 static VALUE
-keyfile_set_integer(VALUE self, VALUE group_name, VALUE key, VALUE value)
+rg_set_integer(VALUE self, VALUE group_name, VALUE key, VALUE value)
 {
     g_key_file_set_integer(_SELF(self), (const gchar*)RVAL2CSTR(group_name),
                            (const gchar*)RVAL2CSTR(key),
@@ -495,7 +507,7 @@ keyfile_set_integer(VALUE self, VALUE group_name, VALUE key, VALUE value)
 
 #if GLIB_CHECK_VERSION(2,12,0)
 static VALUE
-keyfile_set_double(VALUE self, VALUE group_name, VALUE key, VALUE value)
+rg_set_double(VALUE self, VALUE group_name, VALUE key, VALUE value)
 {
     g_key_file_set_double(_SELF(self), (const gchar*)RVAL2CSTR(group_name),
                           (const gchar*)RVAL2CSTR(key),
@@ -505,16 +517,15 @@ keyfile_set_double(VALUE self, VALUE group_name, VALUE key, VALUE value)
 #endif
 
 static VALUE
-keyfile_set_string_list(VALUE self, VALUE group_name, VALUE key, VALUE rblist)
+rg_set_string_list(VALUE self, VALUE rbgroup_name, VALUE rbkey, VALUE rblist)
 {
-    VALUE ary = rb_ary_to_ary(rblist);
-    const gchar **list = RVAL2STRV(ary);
+    GKeyFile *key_file = _SELF(self);
+    const gchar *group_name = RVAL2CSTR(rbgroup_name);
+    const gchar *key = RVAL2CSTR(rbkey);
+    long n;
+    const gchar **list = RVAL2STRS(rblist, n);
 
-    g_key_file_set_string_list(_SELF(self), 
-                               RVAL2CSTR(group_name),
-                               RVAL2CSTR(key),
-                               list,
-                               RARRAY_LEN(ary));
+    g_key_file_set_string_list(key_file, group_name, key, list, n);
 
     g_free(list);
 
@@ -522,17 +533,16 @@ keyfile_set_string_list(VALUE self, VALUE group_name, VALUE key, VALUE rblist)
 }
 
 static VALUE
-keyfile_set_locale_string_list(VALUE self, VALUE group_name, VALUE key, VALUE locale, VALUE rblist)
+rg_set_locale_string_list(VALUE self, VALUE rbgroup_name, VALUE rbkey, VALUE rblocale, VALUE rblist)
 {
-    VALUE ary = rb_ary_to_ary(rblist);
-    const gchar **list = RVAL2STRV(ary);
+    GKeyFile *key_file = _SELF(self);
+    const gchar *group_name = RVAL2CSTR(rbgroup_name);
+    const gchar *key = RVAL2CSTR(rbkey);
+    const gchar *locale = RVAL2CSTR(rblocale);
+    long n;
+    const gchar **list = RVAL2STRS(rblist, n);
 
-    g_key_file_set_locale_string_list(_SELF(self),
-                                      RVAL2CSTR(group_name),
-                                      RVAL2CSTR(key),
-                                      RVAL2CSTR(locale),
-                                      list,
-                                      RARRAY_LEN(ary));
+    g_key_file_set_locale_string_list(key_file, group_name, key, locale, list, n);
 
     g_free(list);
 
@@ -540,75 +550,55 @@ keyfile_set_locale_string_list(VALUE self, VALUE group_name, VALUE key, VALUE lo
 }
 
 static VALUE
-keyfile_set_boolean_list(VALUE self, VALUE group_name, VALUE key, VALUE list)
+rg_set_boolean_list(VALUE self, VALUE rbgroup_name, VALUE rbkey, VALUE rblist)
 {
-    VALUE ary;
-    long i, n;
-    gboolean *booleans;
+    GKeyFile *key_file = _SELF(self);
+    const gchar *group_name = RVAL2CSTR(rbgroup_name);
+    const gchar *key = RVAL2CSTR(rbkey);
+    long n;
+    gboolean *list = RVAL2GBOOLEANS(rblist, n);
 
-    ary = rb_ary_to_ary(list);
-    n = RARRAY_LEN(ary);
-    booleans = ALLOCA_N(gboolean, n);
-    for (i = 0; i < n; i++)
-        booleans[i] = RVAL2CBOOL(RARRAY_PTR(ary)[i]);
+    g_key_file_set_boolean_list(key_file, group_name, key, list, n);
 
-    g_key_file_set_boolean_list(_SELF(self),
-                                RVAL2CSTR(group_name),
-                                RVAL2CSTR(key),
-                                booleans,
-                                n);
+    g_free(list);
 
     return self;
 }
 
 static VALUE
-keyfile_set_integer_list(VALUE self, VALUE group_name, VALUE key, VALUE list)
+rg_set_integer_list(VALUE self, VALUE rbgroup_name, VALUE rbkey, VALUE rblist)
 {
-    VALUE ary;
-    long i, n;
-    gint *ints;
+    GKeyFile *key_file = _SELF(self);
+    const gchar *group_name = RVAL2CSTR(rbgroup_name);
+    const gchar *key = RVAL2CSTR(rbkey);
+    long n;
+    gint *list = RVAL2GINTS(rblist, n);
 
-    ary = rb_ary_to_ary(list);
-    n = RARRAY_LEN(ary);
-    ints = ALLOCA_N(gint, n);
-    for (i = 0; i < n; i++)
-        ints[i] = NUM2INT(RARRAY_PTR(ary)[i]);
+    g_key_file_set_integer_list(key_file, group_name, key, list, n);
 
-    g_key_file_set_integer_list(_SELF(self),
-                                RVAL2CSTR(group_name),
-                                RVAL2CSTR(key),
-                                ints,
-                                n);
+    g_free(list);
 
     return self;
 }
 
 #if GLIB_CHECK_VERSION(2,12,0)
 static VALUE
-keyfile_set_double_list(VALUE self, VALUE group_name, VALUE key, VALUE list)
+rg_set_double_list(VALUE self, VALUE rbgroup_name, VALUE rbkey, VALUE rblist)
 {
-    VALUE ary;
-    long i, n;
-    gdouble *doubles;
-    
-    ary = rb_ary_to_ary(list);
-    n = RARRAY_LEN(ary);
-    doubles = ALLOCA_N(gdouble, n);
-    for (i = 0; i < n; i++)
-        doubles[i] = NUM2DBL(RARRAY_PTR(ary)[i]);
+    GKeyFile *key_file = _SELF(self);
+    const gchar *group_name = RVAL2CSTR(rbgroup_name);
+    const gchar *key = RVAL2CSTR(rbkey);
+    long n;
+    gdouble *list = RVAL2GDOUBLES(rblist, n);
 
-    g_key_file_set_double_list(_SELF(self),
-                               RVAL2CSTR(group_name),
-                               RVAL2CSTR(key),
-                               doubles,
-                               n);
+    g_key_file_set_double_list(key_file, group_name, key, list, n);
 
     return self;
 }
 #endif
 
 static VALUE
-keyfile_set_comment(VALUE self, VALUE group_name, VALUE key, VALUE comment)
+rg_set_comment(VALUE self, VALUE group_name, VALUE key, VALUE comment)
 {
     GError* error = NULL;
 
@@ -624,7 +614,7 @@ keyfile_set_comment(VALUE self, VALUE group_name, VALUE key, VALUE comment)
 }
 
 static VALUE
-keyfile_remove_group(VALUE self, VALUE group_name)
+rg_remove_group(VALUE self, VALUE group_name)
 {
     GError* error = NULL;
 
@@ -637,7 +627,7 @@ keyfile_remove_group(VALUE self, VALUE group_name)
 }
 
 static VALUE
-keyfile_remove_key(VALUE self, VALUE group_name, VALUE key)
+rg_remove_key(VALUE self, VALUE group_name, VALUE key)
 {
     GError* error = NULL;
 
@@ -652,9 +642,8 @@ keyfile_remove_key(VALUE self, VALUE group_name, VALUE key)
     return self;
 }
 
-
 static VALUE
-keyfile_remove_comment(VALUE self, VALUE group_name, VALUE key)
+rg_remove_comment(VALUE self, VALUE group_name, VALUE key)
 {
     GError* error = NULL;
 
@@ -671,115 +660,115 @@ keyfile_remove_comment(VALUE self, VALUE group_name, VALUE key)
 #endif
 
 void
-Init_glib_keyfile()
+Init_glib_keyfile(void)
 {
 #if GLIB_CHECK_VERSION(2,6,0)
-    VALUE kf = G_DEF_CLASS(G_TYPE_KEY_FILE, "KeyFile", mGLib);   
+    VALUE RG_TARGET_NAMESPACE = G_DEF_CLASS(G_TYPE_KEY_FILE, "KeyFile", mGLib);   
     G_DEF_ERROR(G_KEY_FILE_ERROR, "KeyFileError", mGLib, 
                 rb_eRuntimeError, G_TYPE_KEY_FILE_ERROR);
 
-    rb_define_method(kf, "initialize", keyfile_initialize, 0);
-    rb_define_method(kf, "set_list_separator", keyfile_set_list_separator, 1);
-    rb_define_method(kf, "load_from_file", keyfile_load_from_file, -1);
-    rb_define_method(kf, "load_from_data", keyfile_load_from_data, -1);
-    rb_define_method(kf, "load_from_data_dirs", keyfile_load_from_data_dirs, -1);
+    RG_DEF_METHOD(initialize, 0);
+    RG_DEF_METHOD(set_list_separator, 1);
+    RG_DEF_METHOD(load_from_file, -1);
+    RG_DEF_METHOD(load_from_data, -1);
+    RG_DEF_METHOD(load_from_data_dirs, -1);
 #if GLIB_CHECK_VERSION(2, 14, 0)
-    rb_define_method(kf, "load_from_dirs", keyfile_load_from_dirs, -1);
+    RG_DEF_METHOD(load_from_dirs, -1);
 #endif
-    rb_define_method(kf, "to_data", keyfile_to_data, 0);
-    rb_define_method(kf, "start_group", keyfile_get_start_group, 0);
-    rb_define_method(kf, "groups", keyfile_get_groups, 0);
-    rb_define_method(kf, "get_keys", keyfile_get_keys, 1);
-    rb_define_method(kf, "has_group?", keyfile_has_group, 1);
-    rb_define_method(kf, "has_key?", keyfile_has_key, 2);
-    rb_define_method(kf, "get_value", keyfile_get_value, 2);
-    rb_define_method(kf, "get_string", keyfile_get_string, 2);
-    rb_define_method(kf, "get_locale_string", keyfile_get_locale_string, -1);
-    rb_define_method(kf, "get_boolean", keyfile_get_boolean, 2);
-    rb_define_method(kf, "get_integer", keyfile_get_integer, 2);
+    RG_DEF_METHOD(to_data, 0);
+    RG_DEF_METHOD(start_group, 0);
+    RG_DEF_METHOD(groups, 0);
+    RG_DEF_METHOD(get_keys, 1);
+    RG_DEF_METHOD_P(has_group, 1);
+    RG_DEF_METHOD_P(has_key, 2);
+    RG_DEF_METHOD(get_value, 2);
+    RG_DEF_METHOD(get_string, 2);
+    RG_DEF_METHOD(get_locale_string, -1);
+    RG_DEF_METHOD(get_boolean, 2);
+    RG_DEF_METHOD(get_integer, 2);
 #if GLIB_CHECK_VERSION(2,12,0)
-    rb_define_method(kf, "get_double", keyfile_get_double, 2);
+    RG_DEF_METHOD(get_double, 2);
 #endif
-    rb_define_method(kf, "get_string_list", keyfile_get_string_list, 2);
-    rb_define_method(kf, "get_locale_string_list", keyfile_get_locale_string_list, -1);
-    rb_define_method(kf, "get_boolean_list", keyfile_get_boolean_list, 2);
-    rb_define_method(kf, "get_integer_list", keyfile_get_integer_list, 2);
+    RG_DEF_METHOD(get_string_list, 2);
+    RG_DEF_METHOD(get_locale_string_list, -1);
+    RG_DEF_METHOD(get_boolean_list, 2);
+    RG_DEF_METHOD(get_integer_list, 2);
 #if GLIB_CHECK_VERSION(2,12,0)
-    rb_define_method(kf, "get_double_list", keyfile_get_double_list, 2);
+    RG_DEF_METHOD(get_double_list, 2);
 #endif
-    rb_define_method(kf, "get_comment", keyfile_get_comment, 2);
-    rb_define_method(kf, "set_value", keyfile_set_value, 3);
-    rb_define_method(kf, "set_string", keyfile_set_string, 3);
-    rb_define_method(kf, "set_locale_string", keyfile_set_locale_string, 4);
-    rb_define_method(kf, "set_boolean", keyfile_set_boolean, 3);
-    rb_define_method(kf, "set_integer", keyfile_set_integer, 3);
+    RG_DEF_METHOD(get_comment, 2);
+    RG_DEF_METHOD(set_value, 3);
+    RG_DEF_METHOD(set_string, 3);
+    RG_DEF_METHOD(set_locale_string, 4);
+    RG_DEF_METHOD(set_boolean, 3);
+    RG_DEF_METHOD(set_integer, 3);
 #if GLIB_CHECK_VERSION(2,12,0)
-    rb_define_method(kf, "set_double", keyfile_set_double, 3);
+    RG_DEF_METHOD(set_double, 3);
 #endif
-    rb_define_method(kf, "set_string_list", keyfile_set_string_list, 3);
-    rb_define_method(kf, "set_locale_string_list", keyfile_set_locale_string_list, 4);
-    rb_define_method(kf, "set_boolean_list", keyfile_set_boolean_list, 3);
-    rb_define_method(kf, "set_integer_list", keyfile_set_integer_list, 3);
+    RG_DEF_METHOD(set_string_list, 3);
+    RG_DEF_METHOD(set_locale_string_list, 4);
+    RG_DEF_METHOD(set_boolean_list, 3);
+    RG_DEF_METHOD(set_integer_list, 3);
 #if GLIB_CHECK_VERSION(2,12,0)
-    rb_define_method(kf, "set_double_list", keyfile_set_double_list, 3);
+    RG_DEF_METHOD(set_double_list, 3);
 #endif
-    rb_define_method(kf, "set_comment", keyfile_set_comment, 3);
-    rb_define_method(kf, "remove_group", keyfile_remove_group, 1);
-    rb_define_method(kf, "remove_key", keyfile_remove_key, 2);
-    rb_define_method(kf, "remove_comment", keyfile_remove_comment, 2);
+    RG_DEF_METHOD(set_comment, 3);
+    RG_DEF_METHOD(remove_group, 1);
+    RG_DEF_METHOD(remove_key, 2);
+    RG_DEF_METHOD(remove_comment, 2);
 
     /* GKeyFileFlags */
-    G_DEF_CLASS(G_TYPE_KEY_FILE_FLAGS, "Flags", kf);
-    G_DEF_CONSTANTS(kf, G_TYPE_KEY_FILE_FLAGS, "G_KEY_FILE_");
+    G_DEF_CLASS(G_TYPE_KEY_FILE_FLAGS, "Flags", RG_TARGET_NAMESPACE);
+    G_DEF_CONSTANTS(RG_TARGET_NAMESPACE, G_TYPE_KEY_FILE_FLAGS, "G_KEY_FILE_");
 
 #if GLIB_CHECK_VERSION(2, 14, 0)
     /* Defines for handling freedesktop.org Desktop files */
-    rb_define_const(kf, "DESKTOP_GROUP", CSTR2RVAL(G_KEY_FILE_DESKTOP_GROUP));
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_GROUP", CSTR2RVAL(G_KEY_FILE_DESKTOP_GROUP));
 
-    rb_define_const(kf, "DESKTOP_KEY_TYPE",
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_KEY_TYPE",
                     CSTR2RVAL(G_KEY_FILE_DESKTOP_KEY_TYPE));
-    rb_define_const(kf, "DESKTOP_KEY_VERSION",
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_KEY_VERSION",
                     CSTR2RVAL(G_KEY_FILE_DESKTOP_KEY_VERSION));
-    rb_define_const(kf, "DESKTOP_KEY_NAME",
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_KEY_NAME",
                     CSTR2RVAL(G_KEY_FILE_DESKTOP_KEY_NAME));
-    rb_define_const(kf, "DESKTOP_KEY_GENERIC_NAME",
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_KEY_GENERIC_NAME",
                     CSTR2RVAL(G_KEY_FILE_DESKTOP_KEY_GENERIC_NAME));
-    rb_define_const(kf, "DESKTOP_KEY_NO_DISPLAY",
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_KEY_NO_DISPLAY",
                     CSTR2RVAL(G_KEY_FILE_DESKTOP_KEY_NO_DISPLAY));
-    rb_define_const(kf, "DESKTOP_KEY_COMMENT",
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_KEY_COMMENT",
                     CSTR2RVAL(G_KEY_FILE_DESKTOP_KEY_COMMENT));
-    rb_define_const(kf, "DESKTOP_KEY_ICON",
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_KEY_ICON",
                     CSTR2RVAL(G_KEY_FILE_DESKTOP_KEY_ICON));
-    rb_define_const(kf, "DESKTOP_KEY_HIDDEN",
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_KEY_HIDDEN",
                     CSTR2RVAL(G_KEY_FILE_DESKTOP_KEY_HIDDEN));
-    rb_define_const(kf, "DESKTOP_KEY_ONLY_SHOW_IN",
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_KEY_ONLY_SHOW_IN",
                     CSTR2RVAL(G_KEY_FILE_DESKTOP_KEY_ONLY_SHOW_IN));
-    rb_define_const(kf, "DESKTOP_KEY_NOT_SHOW_IN",
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_KEY_NOT_SHOW_IN",
                     CSTR2RVAL(G_KEY_FILE_DESKTOP_KEY_NOT_SHOW_IN));
-    rb_define_const(kf, "DESKTOP_KEY_TRY_EXEC",
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_KEY_TRY_EXEC",
                     CSTR2RVAL(G_KEY_FILE_DESKTOP_KEY_TRY_EXEC));
-    rb_define_const(kf, "DESKTOP_KEY_EXEC",
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_KEY_EXEC",
                     CSTR2RVAL(G_KEY_FILE_DESKTOP_KEY_EXEC));
-    rb_define_const(kf, "DESKTOP_KEY_PATH",
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_KEY_PATH",
                     CSTR2RVAL(G_KEY_FILE_DESKTOP_KEY_PATH));
-    rb_define_const(kf, "DESKTOP_KEY_TERMINAL",
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_KEY_TERMINAL",
                     CSTR2RVAL(G_KEY_FILE_DESKTOP_KEY_TERMINAL));
-    rb_define_const(kf, "DESKTOP_KEY_MIME_TYPE",
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_KEY_MIME_TYPE",
                     CSTR2RVAL(G_KEY_FILE_DESKTOP_KEY_MIME_TYPE));
-    rb_define_const(kf, "DESKTOP_KEY_CATEGORIES",
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_KEY_CATEGORIES",
                     CSTR2RVAL(G_KEY_FILE_DESKTOP_KEY_CATEGORIES));
-    rb_define_const(kf, "DESKTOP_KEY_STARTUP_NOTIFY",
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_KEY_STARTUP_NOTIFY",
                     CSTR2RVAL(G_KEY_FILE_DESKTOP_KEY_STARTUP_NOTIFY));
-    rb_define_const(kf, "DESKTOP_KEY_STARTUP_WM_CLASS",
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_KEY_STARTUP_WM_CLASS",
                     CSTR2RVAL(G_KEY_FILE_DESKTOP_KEY_STARTUP_WM_CLASS));
-    rb_define_const(kf, "DESKTOP_KEY_URL",
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_KEY_URL",
                     CSTR2RVAL(G_KEY_FILE_DESKTOP_KEY_URL));
 
-    rb_define_const(kf, "DESKTOP_TYPE_APPLICATION",
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_TYPE_APPLICATION",
                     CSTR2RVAL(G_KEY_FILE_DESKTOP_TYPE_APPLICATION));
-    rb_define_const(kf, "DESKTOP_TYPE_LINK",
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_TYPE_LINK",
                     CSTR2RVAL(G_KEY_FILE_DESKTOP_TYPE_LINK));
-    rb_define_const(kf, "DESKTOP_TYPE_DIRECTORY",
+    rb_define_const(RG_TARGET_NAMESPACE, "DESKTOP_TYPE_DIRECTORY",
                     CSTR2RVAL(G_KEY_FILE_DESKTOP_TYPE_DIRECTORY));
 #endif
 #endif
