@@ -1,36 +1,44 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
-/**********************************************************************
-
-  rbgobj_object.c -
-
-  $Author: sakai $
-  $Date: 2007/07/19 22:03:44 $
-
-  Copyright (C) 2002-2004  Ruby-GNOME2 Project Team
-  Copyright (C) 2002-2003  Masahiro Sakai
-
-  This file is derived from rbgtkobject.c in Ruby/Gtk distribution.
-  rbgtkobject.c -
-  Copyright (C) 1998-2000 Yukihiro Matsumoto,
-                          Daisuke Kanda,
-                          Hiroshi Igarashi
-
-**********************************************************************/
+/*
+ *  Copyright (C) 2011  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2002-2004  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2002-2003  Masahiro Sakai
+ *  Copyright (C) 1998-2000 Yukihiro Matsumoto,
+ *                          Daisuke Kanda,
+ *                          Hiroshi Igarashi
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
+ */
 
 #include "rbgprivate.h"
 
-VALUE rbgobj_cObject;
+#define RG_TARGET_NAMESPACE rbgobj_cObject
+
+VALUE RG_TARGET_NAMESPACE;
 static VALUE eNoPropertyError;
 static GQuark RUBY_GOBJECT_OBJ_KEY;
 
 /* deperecated */
 void
-rbgobj_add_abstract_but_create_instance_class(GType gtype)
+rbgobj_add_abstract_but_create_instance_class(G_GNUC_UNUSED GType gtype)
 {
 }
 
 static void
-weak_notify(gpointer data, GObject *where_the_object_was)
+weak_notify(gpointer data, G_GNUC_UNUSED GObject *where_the_object_was)
 {
     gobj_holder *holder = data;
 
@@ -56,7 +64,7 @@ holder_free(gobj_holder *holder)
         if (!holder->destroyed) {
             g_object_set_qdata(holder->gobj, RUBY_GOBJECT_OBJ_KEY, NULL);
             g_object_weak_unref(holder->gobj, (GWeakNotify)weak_notify, holder);
-	    weak_notify(holder, holder->gobj);
+            weak_notify(holder, holder->gobj);
         }
         holder->gobj = NULL;
     }
@@ -121,7 +129,7 @@ rbgobj_get_ruby_object_from_gobject(GObject* gobj, gboolean alloc)
     } else if (alloc) {
         VALUE obj;
 
-	obj = gobj_s_allocate(GTYPE2CLASS(G_OBJECT_TYPE(gobj)));
+        obj = gobj_s_allocate(GTYPE2CLASS(G_OBJECT_TYPE(gobj)));
         gobj = g_object_ref(gobj);
         rbgobj_gobject_initialize(obj, (gpointer)gobj);
         return obj;
@@ -163,7 +171,7 @@ rbgobj_init_object_class(VALUE klass)
 {
     rbgobj_define_property_accessors(klass);
     if (G_TYPE_IS_ABSTRACT(CLASS2GTYPE(klass)))
-        rb_define_method(klass, "initialize", dummy_init, -1);
+        rbg_define_method(klass, "initialize", dummy_init, -1);
 }
 
 /**********************************************************************/
@@ -183,7 +191,7 @@ gobj_mark(gpointer ptr)
     GObject* gobj = ptr;
     guint n_properties;
     GParamSpec** properties;
-    GValue gval = {0,};
+    GValue gval = G_VALUE_INIT;
     guint i;
 
     properties = g_object_class_list_properties(G_OBJECT_GET_CLASS(gobj), &n_properties);
@@ -207,7 +215,7 @@ gobj_mark(gpointer ptr)
 }
 
 static VALUE
-gobj_s_gobject_new(int argc, VALUE *argv, VALUE self)
+rg_s_new_bang(int argc, VALUE *argv, VALUE self)
 {
     const RGObjClassInfo* cinfo = rbgobj_lookup_class(self);
     VALUE params_hash;
@@ -337,7 +345,7 @@ rbgobj_gobject_new(GType gtype, VALUE params_hash)
 }
 
 static VALUE
-gobj_s_install_property(int argc, VALUE* argv, VALUE self)
+rg_s_install_property(int argc, VALUE* argv, VALUE self)
 {
     const RGObjClassInfo* cinfo = rbgobj_lookup_class(self);
     gpointer gclass;
@@ -431,8 +439,8 @@ rbgobj_register_property_setter(GType gtype, const char *name, RValueToGValueFun
 
     oclass = g_type_class_ref(gtype);
     pspec = g_object_class_find_property(oclass, name);
-    
-    rb_hash_aset(table, rb_str_new2(g_param_spec_get_name(pspec)),
+
+    rb_hash_aset(table, CSTR2RVAL(g_param_spec_get_name(pspec)),
                  Data_Wrap_Struct(rb_cData, NULL, NULL, func));
 
     g_type_class_unref(oclass);
@@ -453,12 +461,14 @@ rbgobj_register_property_getter(GType gtype, const char *name, GValueToRValueFun
     oclass = g_type_class_ref(gtype);
     pspec = g_object_class_find_property(oclass, name);
 
-    rb_hash_aset(table, rb_str_new2(g_param_spec_get_name(pspec)),
+    rb_hash_aset(table, CSTR2RVAL(g_param_spec_get_name(pspec)),
                  Data_Wrap_Struct(rb_cData, NULL, NULL, func));
+
+    g_type_class_unref(oclass);
 }
 
 static VALUE
-gobj_set_property(VALUE self, VALUE prop_name, VALUE val)
+rg_set_property(VALUE self, VALUE prop_name, VALUE val)
 {
     GParamSpec* pspec;
     const char* name;
@@ -476,7 +486,7 @@ gobj_set_property(VALUE self, VALUE prop_name, VALUE val)
     else {
         // FIXME: use rb_ensure to call g_value_unset()
         RValueToGValueFunc setter = NULL;
-        GValue gval = {0,};
+        GValue gval = G_VALUE_INIT;
 
         g_value_init(&gval, G_PARAM_SPEC_VALUE_TYPE(pspec));
 
@@ -484,7 +494,7 @@ gobj_set_property(VALUE self, VALUE prop_name, VALUE val)
             VALUE table = rb_hash_aref(type_to_prop_setter_table,
                                        INT2FIX(pspec->owner_type));
             if (!NIL_P(table)){
-                VALUE obj = rb_hash_aref(table, rb_intern(g_param_spec_get_name(pspec)));
+                VALUE obj = rb_hash_aref(table, CSTR2RVAL(g_param_spec_get_name(pspec)));
                 if (!NIL_P(obj))
                     Data_Get_Struct(obj, void, setter);
             }
@@ -505,7 +515,7 @@ gobj_set_property(VALUE self, VALUE prop_name, VALUE val)
 }
 
 static VALUE
-gobj_get_property(VALUE self, VALUE prop_name)
+rg_get_property(VALUE self, VALUE prop_name)
 {
     GParamSpec* pspec;
     const char* name;
@@ -523,7 +533,7 @@ gobj_get_property(VALUE self, VALUE prop_name)
     else {
         // FIXME: use rb_ensure to call g_value_unset()
         GValueToRValueFunc getter = NULL;
-        GValue gval = {0,};
+        GValue gval = G_VALUE_INIT;
         VALUE ret;
 
         {
@@ -548,34 +558,34 @@ gobj_get_property(VALUE self, VALUE prop_name)
     }
 }
 
-static VALUE gobj_thaw_notify(VALUE self);
+static VALUE rg_thaw_notify(VALUE self);
 
 static VALUE
-gobj_freeze_notify(VALUE self)
+rg_freeze_notify(VALUE self)
 {
     g_object_freeze_notify(RVAL2GOBJ(self));
     if (rb_block_given_p()) {
-        return rb_ensure(rb_yield, self, gobj_thaw_notify, self);
+        return rb_ensure(rb_yield, self, rg_thaw_notify, self);
     }
     return self;
 }
 
 static VALUE
-gobj_notify(VALUE self, VALUE property_name)
+rg_notify(VALUE self, VALUE property_name)
 {
     g_object_notify(RVAL2GOBJ(self), StringValuePtr(property_name));
     return self;
 }
 
 static VALUE
-gobj_thaw_notify(VALUE self)
+rg_thaw_notify(VALUE self)
 {
     g_object_thaw_notify(RVAL2GOBJ(self));
     return self;
 }
 
 static VALUE
-gobj_is_destroyed(VALUE self)
+rg_destroyed_p(VALUE self)
 {
     gobj_holder* holder;
 
@@ -588,7 +598,7 @@ gobj_is_destroyed(VALUE self)
 }
 
 static VALUE
-gobj_inspect(VALUE self)
+rg_inspect(VALUE self)
 {
     gobj_holder* holder;
     const char *class_name;
@@ -600,7 +610,7 @@ gobj_inspect(VALUE self)
     class_name = rb_class2name(CLASS_OF(self));
     if (!holder->destroyed)
         s = g_strdup_printf("#<%s:%p ptr=%p>", class_name, (void *)self,
-			    holder->gobj);
+                            holder->gobj);
     else
         s = g_strdup_printf("#<%s:%p destroyed>", class_name, (void *)self);
 
@@ -611,11 +621,17 @@ gobj_inspect(VALUE self)
 }
 
 static VALUE
-gobj_initialize(int argc, VALUE *argv, VALUE self)
+rg_type_name(VALUE self)
+{
+    return CSTR2RVAL(G_OBJECT_TYPE_NAME(RVAL2GOBJ(self)));
+}
+
+static VALUE
+rg_initialize(int argc, VALUE *argv, VALUE self)
 {
     VALUE params_hash;
     GObject* gobj;
-    
+
     rb_scan_args(argc, argv, "01", &params_hash);
 
     if (!NIL_P(params_hash))
@@ -651,7 +667,7 @@ static GQuark q_ruby_getter;
 // FIXME: use rb_protect
 static void
 get_prop_func(GObject* object,
-              guint property_id,
+              G_GNUC_UNUSED guint property_id,
               GValue* value,
               GParamSpec* pspec)
 {
@@ -677,7 +693,7 @@ get_prop_func(GObject* object,
 // FIXME: use rb_protect
 static void
 set_prop_func(GObject* object,
-              guint property_id,
+              G_GNUC_UNUSED guint property_id,
               const GValue* value,
               GParamSpec* pspec)
 {
@@ -699,7 +715,7 @@ set_prop_func(GObject* object,
 
 // FIXME: use rb_protect
 static void
-class_init_func(gpointer g_class_, gpointer class_data)
+class_init_func(gpointer g_class_, G_GNUC_UNUSED gpointer class_data)
 {
     GObjectClass* g_class = G_OBJECT_CLASS(g_class_);
 
@@ -714,7 +730,7 @@ class_init_func(gpointer g_class_, gpointer class_data)
 }
 
 static VALUE
-type_register(int argc, VALUE* argv, VALUE self)
+rg_s_type_register(int argc, VALUE* argv, VALUE self)
 {
     VALUE type_name, flags;
     volatile VALUE class_init_proc = Qnil;
@@ -752,6 +768,8 @@ type_register(int argc, VALUE* argv, VALUE self)
         GTypeQuery query;
         g_type_query(parent_type, &query);
 
+        /* TODO: Why new?  g_type_register_static() doesn’t retain a copy, so
+         * this should be allocated on the stack. */
         info = g_new0(GTypeInfo, 1);
         info->class_size     = query.class_size;
         info->base_init      = NULL;
@@ -785,7 +803,7 @@ type_register(int argc, VALUE* argv, VALUE self)
             VALUE m = rb_define_module_under(self, RubyGObjectHookModule);
 
             if (! (cinfo->flags & RBGOBJ_DEFINED_BY_RUBY)) {
-                rb_define_method(m, "initialize", gobj_initialize, -1);
+                rbg_define_method(m, "initialize", rg_initialize, -1);
             }
 
             rb_include_module(self, m);
@@ -795,26 +813,13 @@ type_register(int argc, VALUE* argv, VALUE self)
     }
 }
 
-static void
-Init_gobject_subclass()
-{
-    VALUE cGObject = GTYPE2CLASS(G_TYPE_OBJECT);
-    rb_define_singleton_method(cGObject, "type_register", type_register, -1);
-
-    rb_global_variable(&proc_mod_eval);
-    proc_mod_eval = rb_eval_string("lambda{|obj,proc| obj.module_eval(&proc)}");
-}
-
 /**********************************************************************/
 
 void 
-Init_gobject_gobject()
+Init_gobject_gobject(void)
 {
-    VALUE cGObject;
-
-    rbgobj_cObject = G_DEF_CLASS_WITH_GC_FUNC(G_TYPE_OBJECT, "Object", mGLib,
-					      gobj_mark, NULL);
-    cGObject = rbgobj_cObject;
+    RG_TARGET_NAMESPACE = G_DEF_CLASS_WITH_GC_FUNC(G_TYPE_OBJECT, "Object", mGLib,
+                                                  gobj_mark, NULL);
 
 #ifdef G_TYPE_INITIALLY_UNOWNED
     G_DEF_CLASS(G_TYPE_INITIALLY_UNOWNED, "InitiallyUnowned", mGLib);
@@ -822,26 +827,27 @@ Init_gobject_gobject()
 
     RUBY_GOBJECT_OBJ_KEY = g_quark_from_static_string("__ruby_gobject_object__");
 
-    rb_define_alloc_func(cGObject, (VALUE(*)_((VALUE)))gobj_s_allocate);
-    rb_define_singleton_method(cGObject, "new!", gobj_s_gobject_new, -1);
+    rb_define_alloc_func(RG_TARGET_NAMESPACE, (VALUE(*)_((VALUE)))gobj_s_allocate);
+    RG_DEF_SMETHOD_BANG(new, -1);
 
-    rb_define_singleton_method(cGObject, "property", &gobj_s_property, 1);
-    rb_define_singleton_method(cGObject, "properties", &gobj_s_properties, -1);
-    rb_define_singleton_method(cGObject, "install_property", gobj_s_install_property, -1);
+    rbg_define_singleton_method(RG_TARGET_NAMESPACE, "property", &gobj_s_property, 1);
+    rbg_define_singleton_method(RG_TARGET_NAMESPACE, "properties", &gobj_s_properties, -1);
+    RG_DEF_SMETHOD(install_property, -1);
     q_ruby_getter = g_quark_from_static_string("__ruby_getter");
     q_ruby_setter = g_quark_from_static_string("__ruby_setter");
 
-    rb_define_method(cGObject, "set_property", gobj_set_property, 2);
-    rb_define_method(cGObject, "get_property", gobj_get_property, 1);
-    rb_define_method(cGObject, "freeze_notify", gobj_freeze_notify, 0);
-    rb_undef_method(cGObject, "notify");
-    rb_define_method(cGObject, "notify", gobj_notify, 1);
-    rb_define_method(cGObject, "thaw_notify", gobj_thaw_notify, 0);
-    rb_define_method(cGObject, "destroyed?", gobj_is_destroyed, 0);
+    RG_DEF_METHOD(set_property, 2);
+    RG_DEF_METHOD(get_property, 1);
+    RG_DEF_METHOD(freeze_notify, 0);
+    rb_undef_method(RG_TARGET_NAMESPACE, "notify");
+    RG_DEF_METHOD(notify, 1);
+    RG_DEF_METHOD(thaw_notify, 0);
+    RG_DEF_METHOD_P(destroyed, 0);
 
-    rb_define_method(cGObject, "initialize", gobj_initialize, -1);
-    rb_define_method(cGObject, "ref_count", gobj_ref_count, 0); /* for debugging */
-    rb_define_method(cGObject, "inspect", gobj_inspect, 0);
+    RG_DEF_METHOD(initialize, -1);
+    rbg_define_method(RG_TARGET_NAMESPACE, "ref_count", gobj_ref_count, 0); /* for debugging */
+    RG_DEF_METHOD(inspect, 0);
+    RG_DEF_METHOD(type_name, 0);
 
     eNoPropertyError = rb_define_class_under(mGLib, "NoPropertyError",
                                              rb_eNameError);
@@ -851,6 +857,9 @@ Init_gobject_gobject()
     type_to_prop_setter_table = rb_hash_new();
     type_to_prop_getter_table = rb_hash_new();
 
-    Init_gobject_subclass();
-}
+    /* subclass */
+    RG_DEF_SMETHOD(type_register, -1);
 
+    rb_global_variable(&proc_mod_eval);
+    proc_mod_eval = rb_eval_string("lambda{|obj,proc| obj.module_eval(&proc)}");
+}
