@@ -20,27 +20,46 @@ rescue LoadError
 end
 require 'glib-mkenums'
 
-unless defined?(macro_defined?)
-  def macro_defined?(macro, src, opt="")
-    try_cpp(src + <<EOP, opt)
-#ifndef #{macro}
-# error
-#endif
-EOP
+$CFLAGS += " #{ENV['CFLAGS']}" if ENV['CFLAGS']
+
+def try_compiler_option(opt, &block)
+  checking_for "#{opt} option to compiler" do
+    $CFLAGS += " #{opt}" if try_compile '', opt, &block
   end
 end
 
-
-STDOUT.print("checking for GCC... ")
-STDOUT.flush
-if macro_defined?("__GNUC__", "")
-  STDOUT.print "yes\n"
-  $CFLAGS += ' -Wall'
-  $cc_is_gcc = true
-else
-  STDOUT.print "no\n"
-  $cc_is_gcc = false
-end
+try_compiler_option '-Wall'
+try_compiler_option '-Waggregate-return'
+try_compiler_option '-Wcast-align'
+# NOTE: Generates way too many false positives.
+# try_compiler_option '-Wconversion'
+try_compiler_option '-Wextra'
+try_compiler_option '-Wformat=2'
+try_compiler_option '-Winit-self'
+# NOTE: This generates warnings for functions defined in ruby.h.
+# try_compiler_option '-Winline'
+try_compiler_option '-Wlarger-than-65500'
+try_compiler_option '-Wmissing-declarations'
+try_compiler_option '-Wmissing-format-attribute'
+try_compiler_option '-Wmissing-include-dirs'
+try_compiler_option '-Wmissing-noreturn'
+try_compiler_option '-Wmissing-prototypes'
+try_compiler_option '-Wnested-externs'
+try_compiler_option '-Wold-style-definition'
+try_compiler_option '-Wpacked'
+try_compiler_option '-Wp,-D_FORTIFY_SOURCE=2'
+try_compiler_option '-Wpointer-arith'
+# NOTE: ruby.h and intern.h have too many of these.
+# try_compiler_option '-Wredundant-decls'
+# NOTE: Complains about index, for example.
+# try_compiler_option '-Wshadow'
+try_compiler_option '-Wswitch-default'
+try_compiler_option '-Wswitch-enum'
+try_compiler_option '-Wundef'
+# NOTE: Incredible amounts of false positives.
+#try_compiler_option '-Wunreachable-code'
+try_compiler_option '-Wunsafe-loop-optimizations'
+try_compiler_option '-Wwrite-strings'
 
 if /-Wl,--no-undefined/ =~ $LDFLAGS.to_s
   $LDFLAGS.gsub!(/-Wl,--no-undefined/, '')
