@@ -1,16 +1,26 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
-/************************************************
-
-  rbgdkevent.c -
-
-  $Author: ggc $
-  $Date: 2007/07/13 16:07:31 $
-
-  Copyright (C) 2002-2004 Ruby-GNOME2 Project Team
-  Copyright (C) 1998-2000 Yukihiro Matsumoto,
-                          Daisuke Kanda,
-                          Hiroshi Igarashi
-************************************************/
+/*
+ *  Copyright (C) 2011  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2002-2004 Ruby-GNOME2 Project Team
+ *  Copyright (C) 1998-2000 Yukihiro Matsumoto,
+ *                          Daisuke Kanda,
+ *                          Hiroshi Igarashi
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
+ */
 
 #include "global.h"
 
@@ -238,25 +248,25 @@ gdkevent ## type ## _initialize(int argc, VALUE *argv, VALUE self)\
 
 /* GdkEvent Singleton Methods */
 static VALUE
-gdkevent_s_events_pending(VALUE self)
+gdkevent_s_events_pending(G_GNUC_UNUSED VALUE self)
 {
     return CBOOL2RVAL(gdk_events_pending());
 }
 
 static VALUE
-gdkevent_s_peek(VALUE self)
+gdkevent_s_peek(G_GNUC_UNUSED VALUE self)
 {
     return make_gdkevent(gdk_event_peek());
 }
 
 static VALUE
-gdkevent_s_get(VALUE self)
+gdkevent_s_get(G_GNUC_UNUSED VALUE self)
 {
     return make_gdkevent(gdk_event_get());
 }
 
 static VALUE
-gdkevent_s_get_graphics_expose(VALUE self, VALUE window)
+gdkevent_s_get_graphics_expose(G_GNUC_UNUSED VALUE self, VALUE window)
 {
     return make_gdkevent(gdk_event_get_graphics_expose(GDK_WINDOW(RVAL2GOBJ(window))));
 }
@@ -338,7 +348,7 @@ gdkevent_s_handler_set(VALUE self)
 }
 
 static VALUE
-gdkevent_s_get_show_events(VALUE self)
+gdkevent_s_get_show_events(G_GNUC_UNUSED VALUE self)
 {
     return CBOOL2RVAL(gdk_get_show_events());
 }
@@ -368,11 +378,11 @@ gdkevent_screen(VALUE self)
   type: String, Integer, Gdk::Color.
  */
 static VALUE
-gdkevent_s_setting_get(int argc, VALUE *argv, VALUE self)
+gdkevent_s_setting_get(int argc, VALUE *argv, G_GNUC_UNUSED VALUE self)
 {
     VALUE name, type;
     GType gtype;
-    GValue val = {0,};
+    GValue val = G_VALUE_INIT;
     gboolean ret;
     VALUE value;
 
@@ -647,7 +657,7 @@ gdkevent_g2r(const GValue *values)
 }
 
 void
-Init_gtk_gdk_event()
+Init_gtk_gdk_event(VALUE mGdk)
 {
     VALUE ev;
     VALUE gdkEvent;
