@@ -1,23 +1,34 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
-/************************************************
-
-  rbgtkaction.c -
-
-  $Author: ggc $
-  $Date: 2007/07/13 16:07:31 $
-
-  Copyright (C) 2004-2006 Masao Mutoh
-************************************************/
+/*
+ *  Copyright (C) 2011  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2004-2006 Masao Mutoh
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
+ */
 
 #include "global.h"
 
 #if GTK_CHECK_VERSION(2,4,0)
 
+#define RG_TARGET_NAMESPACE cAction
 #define _SELF(self) (GTK_ACTION(RVAL2GOBJ(self)))
 #define RVAL2WIDGET(w) (GTK_WIDGET(RVAL2GOBJ(w)))
 
 static VALUE
-action_initialize(int argc, VALUE *argv, VALUE self)
+rg_initialize(int argc, VALUE *argv, VALUE self)
 {
     VALUE name, label, tooltip, stock_id;
     const gchar *stock = NULL;
@@ -37,120 +48,109 @@ action_initialize(int argc, VALUE *argv, VALUE self)
 }
 
 static VALUE
-action_is_sensitive(VALUE self)
+rg_is_sensitive_p(VALUE self)
 {
     return CBOOL2RVAL(gtk_action_is_sensitive(_SELF(self)));
 }
 
 static VALUE
-action_is_visible(VALUE self)
+rg_is_visible_p(VALUE self)
 {
     return CBOOL2RVAL(gtk_action_is_visible(_SELF(self)));
 }
 
-/* Defined as property.
-const gchar* gtk_action_get_name            (GtkAction *action);
-gboolean    gtk_action_get_sensitive        (GtkAction *action);
-void                gtk_action_set_sensitive            (GtkAction *action,
-                                                         gboolean
-                                                         sensitive);
-gboolean    gtk_action_get_visible          (GtkAction *action);
-void                gtk_action_set_visible              (GtkAction *action,
-                                                         gboolean visible);
-*/
-
 static VALUE
-action_activate(VALUE self)
+rg_activate(VALUE self)
 {
     gtk_action_activate(_SELF(self));
     return self;
 }
 
 static VALUE
-action_create_icon(VALUE self, VALUE icon_size)
+rg_create_icon(VALUE self, VALUE icon_size)
 {
     return GOBJ2RVAL(gtk_action_create_icon(_SELF(self), 
                                             RVAL2GENUM(icon_size, GTK_TYPE_ICON_SIZE)));
 }
 
 static VALUE
-action_create_menu_item(VALUE self)
+rg_create_menu_item(VALUE self)
 {
     return GOBJ2RVAL(gtk_action_create_menu_item(_SELF(self)));
 }
 
 #if GTK_CHECK_VERSION(2, 12, 0)
 static VALUE
-action_create_menu(VALUE self)
+rg_create_menu(VALUE self)
 {
     return GOBJ2RVAL(gtk_action_create_menu(_SELF(self)));
 }
 #endif
 
 static VALUE
-action_create_tool_item(VALUE self)
+rg_create_tool_item(VALUE self)
 {
     return GOBJ2RVAL(gtk_action_create_tool_item(_SELF(self)));
 }
 
 static VALUE
-action_connect_proxy(VALUE self, VALUE proxy)
+rg_connect_proxy(VALUE self, VALUE proxy)
 {
     gtk_action_connect_proxy(_SELF(self), RVAL2WIDGET(proxy));
     return self;
 }
 
 static VALUE
-action_disconnect_proxy(VALUE self, VALUE proxy)
+rg_disconnect_proxy(VALUE self, VALUE proxy)
 {
     gtk_action_disconnect_proxy(_SELF(self), RVAL2WIDGET(proxy));
     return self;
 }
 
 static VALUE
-action_get_proxies(VALUE self)
+rg_proxies(VALUE self)
 {
     /* Owned by GTK+ */
     return GSLIST2ARY(gtk_action_get_proxies(_SELF(self)));
 }
 
 static VALUE
-action_connect_accelerator(VALUE self)
+rg_connect_accelerator(VALUE self)
 {
     gtk_action_connect_accelerator(_SELF(self));
     return self;
 }
 
 static VALUE
-action_disconnect_accelerator(VALUE self)
+rg_disconnect_accelerator(VALUE self)
 {
     gtk_action_disconnect_accelerator(_SELF(self));
     return self;
 }
 
 static VALUE
-action_block_activate_from(VALUE self, VALUE proxy)
+rg_block_activate_from(VALUE self, VALUE proxy)
 {
     gtk_action_block_activate_from(_SELF(self), RVAL2WIDGET(proxy));
     return self;
 }
 
 static VALUE
-action_unblock_activate_from(VALUE self, VALUE proxy)
+rg_unblock_activate_from(VALUE self, VALUE proxy)
 {
     gtk_action_unblock_activate_from(_SELF(self), RVAL2WIDGET(proxy));
     return self;
 }
 
 static VALUE
-action_set_accel_path(VALUE self, VALUE accel_path)
+rg_set_accel_path(VALUE self, VALUE accel_path)
 {
     gtk_action_set_accel_path(_SELF(self), RVAL2CSTR(accel_path));
     return self;
 }
 
 static VALUE
-action_set_accel_group(VALUE self, VALUE accel_group)
+rg_set_accel_group(VALUE self, VALUE accel_group)
 {
     gtk_action_set_accel_group(_SELF(self), RVAL2GOBJ(accel_group));
     return self;
@@ -158,7 +158,7 @@ action_set_accel_group(VALUE self, VALUE accel_group)
 
 #if GTK_CHECK_VERSION(2,6,0)
 static VALUE
-action_get_accel_path(VALUE self)
+rg_accel_path(VALUE self)
 {
     return CSTR2RVAL(gtk_action_get_accel_path(_SELF(self)));
 }
@@ -166,7 +166,7 @@ action_get_accel_path(VALUE self)
 
 #if GTK_CHECK_VERSION(2,8,0)
 static VALUE
-action_get_accel_closure(VALUE self)
+rg_accel_closure(VALUE self)
 {
     return BOXED2RVAL(gtk_action_get_accel_closure(_SELF(self)), G_TYPE_CLOSURE);
 }
@@ -180,24 +180,24 @@ action_mark(void *p)
 
     action = GTK_ACTION(p);
     for (node = gtk_action_get_proxies(action);
-	 node;
-	 node = g_slist_next(node)) {
-	GtkWidget *proxy = node->data;
-	rbgobj_gc_mark_instance(proxy);
+         node;
+         node = g_slist_next(node)) {
+        GtkWidget *proxy = node->data;
+        rbgobj_gc_mark_instance(proxy);
     }
 }
 #endif
 
 void
-Init_gtk_action()
+Init_gtk_action(VALUE mGtk)
 {
 #if GTK_CHECK_VERSION(2,4,0)
-    VALUE gAction;
+    VALUE RG_TARGET_NAMESPACE;
 
-    gAction = G_DEF_CLASS_WITH_GC_FUNC(GTK_TYPE_ACTION, "Action", mGtk,
-				       action_mark, NULL);
+    RG_TARGET_NAMESPACE = G_DEF_CLASS_WITH_GC_FUNC(GTK_TYPE_ACTION, "Action", mGtk,
+                                                   action_mark, NULL);
 
-    rb_define_method(gAction, "initialize", action_initialize, -1);
+    RG_DEF_METHOD(initialize, -1);
     /* (NOTICE) Gtk::Action#is_sensitive?, #is_visible are special.
        Because there are also Gtk::Action#sensitive?, #visible? as property 
        accessors. 
@@ -205,33 +205,33 @@ Init_gtk_action()
        action group.
        Gtk::Action#sensitive?, #visible? returns the value of the properties.
     */
-    rb_define_method(gAction, "is_sensitive?", action_is_sensitive, 0);
-    rb_define_method(gAction, "is_visible?", action_is_visible, 0);
-    rb_define_method(gAction, "activate", action_activate, 0);
-    rb_define_method(gAction, "create_icon", action_create_icon, 1);
-    rb_define_method(gAction, "create_menu_item", action_create_menu_item, 0);
+    RG_DEF_METHOD_P(is_sensitive, 0);
+    RG_DEF_METHOD_P(is_visible, 0);
+    RG_DEF_METHOD(activate, 0);
+    RG_DEF_METHOD(create_icon, 1);
+    RG_DEF_METHOD(create_menu_item, 0);
 #if GTK_CHECK_VERSION(2, 12, 0)
-    rb_define_method(gAction, "create_menu", action_create_menu, 0);
+    RG_DEF_METHOD(create_menu, 0);
 #endif
-    rb_define_method(gAction, "create_tool_item", action_create_tool_item, 0);
-    rb_define_method(gAction, "connect_proxy", action_connect_proxy, 1);
-    rb_define_method(gAction, "disconnect_proxy", action_disconnect_proxy, 1);
-    rb_define_method(gAction, "proxies", action_get_proxies, 0);
-    rb_define_method(gAction, "connect_accelerator", action_connect_accelerator, 0);
-    rb_define_method(gAction, "disconnect_accelerator", action_disconnect_accelerator, 0);
-    rb_define_method(gAction, "block_activate_from", action_block_activate_from, 1);
-    rb_define_method(gAction, "unblock_activate_from", action_unblock_activate_from, 1);
-    rb_define_method(gAction, "set_accel_path", action_set_accel_path, 1);
-    G_DEF_SETTER(gAction, "accel_path");
-    rb_define_method(gAction, "set_accel_group", action_set_accel_group, 1);
-    G_DEF_SETTER(gAction, "accel_group");
+    RG_DEF_METHOD(create_tool_item, 0);
+    RG_DEF_METHOD(connect_proxy, 1);
+    RG_DEF_METHOD(disconnect_proxy, 1);
+    RG_DEF_METHOD(proxies, 0);
+    RG_DEF_METHOD(connect_accelerator, 0);
+    RG_DEF_METHOD(disconnect_accelerator, 0);
+    RG_DEF_METHOD(block_activate_from, 1);
+    RG_DEF_METHOD(unblock_activate_from, 1);
+    RG_DEF_METHOD(set_accel_path, 1);
+    G_DEF_SETTER(RG_TARGET_NAMESPACE, "accel_path");
+    RG_DEF_METHOD(set_accel_group, 1);
+    G_DEF_SETTER(RG_TARGET_NAMESPACE, "accel_group");
 
 #if GTK_CHECK_VERSION(2,6,0)
-    rb_define_method(gAction, "accel_path", action_get_accel_path, 0);
+    RG_DEF_METHOD(accel_path, 0);
 #endif
 
 #if GTK_CHECK_VERSION(2,8,0)
-    rb_define_method(gAction, "accel_closure", action_get_accel_closure, 0);
+    RG_DEF_METHOD(accel_closure, 0);
 #endif
 #endif
 }
