@@ -1,32 +1,43 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
-/************************************************
-
-  rbgtkcellview.c -
-
-  $Author: ggc $
-  $Date: 2007/07/13 16:07:31 $
-
-  Copyright (C) 2005,2006 Masao Mutoh
-************************************************/
+/*
+ *  Copyright (C) 2011  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2005,2006 Masao Mutoh
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
+ */
 
 #include "global.h"
 
 #if GTK_CHECK_VERSION(2,6,0)
 
+#define RG_TARGET_NAMESPACE cCellView
 #define _SELF(self) (GTK_CELL_VIEW(RVAL2GOBJ(self)))
 
 static ID id_model;
 static ID id_text;
 
 static VALUE
-cview_initialize(int argc, VALUE *argv, VALUE self)
+rg_initialize(int argc, VALUE *argv, VALUE self)
 {
     VALUE text;
     VALUE with_markup = Qnil;
     GtkWidget *widget = NULL;
 
     rb_scan_args(argc, argv, "02", &text, &with_markup);
-    
+
     if (NIL_P(text)) {
         widget = gtk_cell_view_new();
     } else {
@@ -51,14 +62,8 @@ cview_initialize(int argc, VALUE *argv, VALUE self)
     return Qnil;
 }
 
-/* Properties:
-void                gtk_cell_view_set_model             (GtkCellView *cell_view,
-                                                         GtkTreeModel *model);
-GtkTreeModel *      gtk_cell_view_get_model             (GtkCellView *cell_view);
-*/
-
 static VALUE
-cview_set_displayed_row(VALUE self, VALUE path)
+rg_set_displayed_row(VALUE self, VALUE path)
 {
     gtk_cell_view_set_displayed_row(_SELF(self),  
                                     NIL_P(path) ? (GtkTreePath*)NULL :
@@ -67,13 +72,13 @@ cview_set_displayed_row(VALUE self, VALUE path)
 }
 
 static VALUE
-cview_get_displayed_row(VALUE self)
+rg_displayed_row(VALUE self)
 {
     return GTKTREEPATH2RVAL(gtk_cell_view_get_displayed_row(_SELF(self)));
 }
 
 static VALUE
-cview_get_size_of_row(VALUE self, VALUE path)
+rg_get_size_of_row(VALUE self, VALUE path)
 {
     GtkRequisition req;
     gboolean ret = gtk_cell_view_get_size_of_row(_SELF(self),  
@@ -92,30 +97,26 @@ void        gtk_cell_view_set_background_color
 */
 
 static VALUE
-cview_get_cell_renderers(VALUE self)
+rg_cell_renderers(VALUE self)
 {
     return GLIST2ARYF(gtk_cell_view_get_cell_renderers(_SELF(self)));
 }
 #endif
 
 void
-Init_gtk_cellview()
+Init_gtk_cellview(VALUE mGtk)
 {
 #if GTK_CHECK_VERSION(2,6,0)
-    VALUE cview = G_DEF_CLASS(GTK_TYPE_CELL_VIEW, "CellView", mGtk);
+    VALUE RG_TARGET_NAMESPACE = G_DEF_CLASS(GTK_TYPE_CELL_VIEW, "CellView", mGtk);
 
     id_model = rb_intern("model");
     id_text = rb_intern("text");
 
-    rb_define_method(cview, "initialize", cview_initialize, -1);
-    rb_define_method(cview, "set_displayed_row", cview_set_displayed_row, 1);
-    G_DEF_SETTER(cview, "displayed_row");
-    rb_define_method(cview, "displayed_row", cview_get_displayed_row, 0);
-    rb_define_method(cview, "get_size_of_row", cview_get_size_of_row, 1);
-    rb_define_method(cview, "cell_renderers", cview_get_cell_renderers, 0);
+    RG_DEF_METHOD(initialize, -1);
+    RG_DEF_METHOD(set_displayed_row, 1);
+    G_DEF_SETTER(RG_TARGET_NAMESPACE, "displayed_row");
+    RG_DEF_METHOD(displayed_row, 0);
+    RG_DEF_METHOD(get_size_of_row, 1);
+    RG_DEF_METHOD(cell_renderers, 0);
 #endif
 }
-
-
- 
-
