@@ -1,71 +1,118 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
-/************************************************
-
-  rbgtkdrag.c -
-
-  $Author: ggc $
-  $Date: 2007/07/13 16:07:31 $
-
-  Copyright (C) 2002-2006 Masao Mutoh
-************************************************/
-
+/*
+ *  Copyright (C) 2011  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2002-2006 Masao Mutoh
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
+ */
 
 #include "global.h"
 
+#define RG_TARGET_NAMESPACE mDrag
+
 #define RVAL2DC(c) (GDK_DRAG_CONTEXT(RVAL2GOBJ(c)))
 #define RVAL2WIDGET(w) (GTK_WIDGET(RVAL2GOBJ(w)))
 
-GtkTargetEntry*
+struct rbgtk_rval2gtktargetentries_args {
+    VALUE ary;
+    long n;
+    GtkTargetEntry *result;
+};
+
+static VALUE
+rbgtk_rval2gtktargetentries_body(VALUE value)
+{
+    long i;
+    struct rbgtk_rval2gtktargetentries_args *args = (struct rbgtk_rval2gtktargetentries_args *)value;
+
+    for (i = 0; i < args->n; i++) {
+        VALUE entry = rb_ary_to_ary(RARRAY_PTR(args->ary)[i]);
+        VALUE flags = RARRAY_PTR(entry)[1];
+        VALUE info = RARRAY_PTR(entry)[2];
+
+        args->result[i].target = (gchar *)RVAL2CSTR_ACCEPT_NIL(RARRAY_PTR(entry)[0]);
+        args->result[i].flags = NIL_P(flags) ? 0 : RVAL2GFLAGS(flags, GTK_TYPE_TARGET_FLAGS);
+        args->result[i].info = NIL_P(info) ? 0 : NUM2INT(info);
+    }
+
+    return Qnil;
+}
+
+static G_GNUC_NORETURN VALUE
+rbgtk_rval2gtktargetentries_rescue(VALUE value)
+{
+    g_free(((struct rbgtk_rval2gtktargetentries_args *)value)->result);
+
+    rb_exc_raise(rb_errinfo());
+}
+
+GtkTargetEntry *
+rbgtk_rval2gtktargetentries(VALUE value, long *n)
+{
+    struct rbgtk_rval2gtktargetentries_args args;
+
+    args.ary = rb_ary_to_ary(value);
+    args.n = RARRAY_LEN(args.ary);
+    args.result = g_new(GtkTargetEntry, args.n + 1);
+
+    rb_rescue(rbgtk_rval2gtktargetentries_body, (VALUE)&args,
+              rbgtk_rval2gtktargetentries_rescue, (VALUE)&args);
+
+    *n = args.n;
+
+    return args.result;
+}
+
+GtkTargetEntry *
+rbgtk_rval2gtktargetentries_accept_nil(VALUE value, long *n)
+{
+    if (!NIL_P(value))
+        return rbgtk_rval2gtktargetentries(value, n);
+
+    *n = 0;
+
+    return NULL;
+}
+
+GtkTargetEntry *
 rbgtk_get_target_entry(VALUE targets)
 {
-    VALUE ary;
-    VALUE e_target, e_flags, e_info;
-    GtkTargetEntry *entries;
-    int i, n_targets;
-    
-    if (NIL_P(targets)) return NULL;
-    Check_Type(targets, T_ARRAY);
-    
-    n_targets = RARRAY_LEN(targets);
-    entries = ALLOC_N(GtkTargetEntry, n_targets);
-    
-    for (i = 0; i < n_targets; i++) {
-        ary = rb_ary_entry(targets, i);
-        Check_Type(ary, T_ARRAY);
-        e_target = rb_ary_entry(ary, 0);
-        e_flags = rb_ary_entry(ary, 1);
-        e_info = rb_ary_entry(ary, 2);
-        
-        entries[i].target = NIL_P(e_target) ? NULL : (char *)RVAL2CSTR(e_target);
-        entries[i].flags = NIL_P(e_flags) ? 0 : RVAL2GFLAGS(e_flags, GTK_TYPE_TARGET_FLAGS);
-        entries[i].info = NIL_P(e_info) ? 0 : NUM2INT(e_info);
+    long n;
 
-    }
-    return entries;
+    return RVAL2GTKTARGETENTRIES(targets, &n);
 }
 
 static VALUE
-gtkdrag_dest_set(VALUE self, VALUE widget, VALUE flags, VALUE targets, VALUE actions)
+rg_m_dest_set(VALUE self, VALUE rbwidget, VALUE rbflags, VALUE rbtargets, VALUE rbactions)
 {
-    int num;
-    GtkTargetEntry* entries = rbgtk_get_target_entry(targets);
-    if (entries){
-        num = RARRAY_LEN(targets);
-        
-        gtk_drag_dest_set(RVAL2WIDGET(widget), RVAL2GFLAGS(flags, GTK_TYPE_DEST_DEFAULTS), 
-                          entries, 
-                          num, RVAL2GFLAGS(actions, GDK_TYPE_DRAG_ACTION));
-    }
-    else
-    {
-        gtk_drag_dest_set(RVAL2WIDGET(widget), RVAL2GFLAGS(flags, GTK_TYPE_DEST_DEFAULTS), 
-                          NULL, 0, RVAL2GFLAGS(actions, GDK_TYPE_DRAG_ACTION));
-    }
+    GtkWidget *widget = RVAL2WIDGET(rbwidget);
+    GtkDestDefaults flags = RVAL2GFLAGS(rbflags, GTK_TYPE_DEST_DEFAULTS);
+    GdkDragAction actions = RVAL2GFLAGS(rbactions, GDK_TYPE_DRAG_ACTION);
+    long n;
+    GtkTargetEntry *targets = RVAL2GTKTARGETENTRIES_ACCEPT_NIL(rbtargets, &n);
+
+    gtk_drag_dest_set(widget, flags, targets, n, actions);
+
+    g_free(targets);
+
     return self;
 }
 
 static VALUE
-gtkdrag_dest_set_proxy(VALUE self, VALUE widget, VALUE proxy_window, VALUE protocol, VALUE use_coordinates)
+rg_m_dest_set_proxy(VALUE self, VALUE widget, VALUE proxy_window, VALUE protocol, VALUE use_coordinates)
 {
     gtk_drag_dest_set_proxy(RVAL2WIDGET(widget), 
                             GDK_WINDOW(RVAL2GOBJ(proxy_window)),
@@ -75,14 +122,14 @@ gtkdrag_dest_set_proxy(VALUE self, VALUE widget, VALUE proxy_window, VALUE proto
 }
 
 static VALUE
-gtkdrag_dest_unset(VALUE self, VALUE widget)
+rg_m_dest_unset(VALUE self, VALUE widget)
 {
     gtk_drag_dest_unset(RVAL2WIDGET(widget));
     return self;
 }
 
 static VALUE
-gtkdrag_dest_find_target(int argc, VALUE *argv, VALUE self)
+rg_m_dest_find_target(int argc, VALUE *argv, G_GNUC_UNUSED VALUE self)
 {
     VALUE widget, context, target_list;
     GdkAtom ret;
@@ -91,19 +138,19 @@ gtkdrag_dest_find_target(int argc, VALUE *argv, VALUE self)
     ret = gtk_drag_dest_find_target(
         RVAL2WIDGET(widget), RVAL2DC(context),
         NIL_P(target_list) ? NULL : RVAL2BOXED(target_list, GTK_TYPE_TARGET_LIST));
- 
+
     return BOXED2RVAL(ret, GDK_TYPE_ATOM);
 }
 
 static VALUE
-gtkdrag_dest_get_target_list(VALUE self, VALUE widget)
+rg_m_dest_get_target_list(G_GNUC_UNUSED VALUE self, VALUE widget)
 {
     GtkTargetList* list = gtk_drag_dest_get_target_list(RVAL2WIDGET(widget));
     return BOXED2RVAL(list, GTK_TYPE_TARGET_LIST);
 }
 
 static VALUE
-gtkdrag_dest_set_target_list(VALUE self, VALUE widget, VALUE target_list)
+rg_m_dest_set_target_list(VALUE self, VALUE widget, VALUE target_list)
 {
     gtk_drag_dest_set_target_list(
         RVAL2WIDGET(widget), 
@@ -112,22 +159,21 @@ gtkdrag_dest_set_target_list(VALUE self, VALUE widget, VALUE target_list)
     return self;
 }
 
-
 #if GTK_CHECK_VERSION(2,6,0)
 static VALUE
-gtkdrag_dest_add_text_targets(VALUE self, VALUE widget)
+rg_m_dest_add_text_targets(VALUE self, VALUE widget)
 {
     gtk_drag_dest_add_text_targets(RVAL2WIDGET(widget));
     return self;
 }
 static VALUE
-gtkdrag_dest_add_image_targets(VALUE self, VALUE widget)
+rg_m_dest_add_image_targets(VALUE self, VALUE widget)
 {
     gtk_drag_dest_add_image_targets(RVAL2WIDGET(widget));
     return self;
 }
 static VALUE
-gtkdrag_dest_add_uri_targets(VALUE self, VALUE widget)
+rg_m_dest_add_uri_targets(VALUE self, VALUE widget)
 {
     gtk_drag_dest_add_uri_targets(RVAL2WIDGET(widget));
     return self;
@@ -136,21 +182,21 @@ gtkdrag_dest_add_uri_targets(VALUE self, VALUE widget)
 
 #if GTK_CHECK_VERSION(2,10,0)
 static VALUE
-gtkdrag_dest_set_track_motion(VALUE self, VALUE widget, VALUE track_motion)
+rg_m_dest_set_track_motion(VALUE self, VALUE widget, VALUE track_motion)
 {
     gtk_drag_dest_set_track_motion(RVAL2WIDGET(widget), RVAL2CBOOL(track_motion));
     return self;
 }
 
 static VALUE
-gtkdrag_dest_get_track_motion(VALUE self, VALUE widget)
+rg_m_dest_get_track_motion(G_GNUC_UNUSED VALUE self, VALUE widget)
 {
     return CBOOL2RVAL(gtk_drag_dest_get_track_motion(RVAL2WIDGET(widget)));
 }
 #endif
 
 static VALUE
-gtkdrag_finish(VALUE self, VALUE context, VALUE success, VALUE del, VALUE time)
+rg_m_finish(VALUE self, VALUE context, VALUE success, VALUE del, VALUE time)
 {
     gtk_drag_finish(RVAL2DC(context), RVAL2CBOOL(success),
                     RVAL2CBOOL(del), NUM2UINT(time));
@@ -158,7 +204,7 @@ gtkdrag_finish(VALUE self, VALUE context, VALUE success, VALUE del, VALUE time)
 }
 
 static VALUE
-gtkdrag_get_data(VALUE self, VALUE widget, VALUE context, VALUE target, VALUE time)
+rg_m_get_data(VALUE self, VALUE widget, VALUE context, VALUE target, VALUE time)
 {
     gtk_drag_get_data(RVAL2WIDGET(widget), RVAL2DC(context), RVAL2ATOM(target),
                       NUM2UINT(time));
@@ -166,27 +212,27 @@ gtkdrag_get_data(VALUE self, VALUE widget, VALUE context, VALUE target, VALUE ti
 }
 
 static VALUE
-gtkdrag_get_source_widget(VALUE self, VALUE context)
+rg_m_get_source_widget(G_GNUC_UNUSED VALUE self, VALUE context)
 {
     return GOBJ2RVAL(gtk_drag_get_source_widget(RVAL2DC(context)));
 }
 
 static VALUE
-gtkdrag_highlight(VALUE self, VALUE widget)
+rg_m_highlight(VALUE self, VALUE widget)
 {
     gtk_drag_highlight(RVAL2WIDGET(widget));
     return self;
 }
 
 static VALUE
-gtkdrag_unhighlight(VALUE self, VALUE widget)
+rg_m_unhighlight(VALUE self, VALUE widget)
 {
     gtk_drag_unhighlight(RVAL2WIDGET(widget));
     return self;
 }
 
 static VALUE
-gtkdrag_begin(VALUE self, VALUE widget, VALUE target_list, VALUE actions, VALUE button, VALUE event)
+rg_m_begin(G_GNUC_UNUSED VALUE self, VALUE widget, VALUE target_list, VALUE actions, VALUE button, VALUE event)
 {
     return GOBJ2RVAL(gtk_drag_begin(RVAL2WIDGET(widget),
                                     RVAL2BOXED(target_list, GTK_TYPE_TARGET_LIST),
@@ -196,7 +242,7 @@ gtkdrag_begin(VALUE self, VALUE widget, VALUE target_list, VALUE actions, VALUE
 }
 
 static VALUE
-gtkdrag_set_icon(int argc, VALUE *argv, VALUE self)
+rg_m_set_icon(int argc, VALUE *argv, VALUE self)
 {
     VALUE context, obj, pixmap = Qnil, mask = Qnil, hot_x, hot_y;
 
@@ -229,7 +275,7 @@ gtkdrag_set_icon(int argc, VALUE *argv, VALUE self)
 
 #if GTK_CHECK_VERSION(2,8,0)
 static VALUE
-gtkdrag_set_icon_name(VALUE self, VALUE context, VALUE name, VALUE hot_x, VALUE hot_y)
+rg_m_set_icon_name(VALUE self, VALUE context, VALUE name, VALUE hot_x, VALUE hot_y)
 {
     gtk_drag_set_icon_name(RVAL2DC(context), RVAL2CSTR(name), NUM2INT(hot_x), NUM2INT(hot_y));
     return self;
@@ -237,14 +283,14 @@ gtkdrag_set_icon_name(VALUE self, VALUE context, VALUE name, VALUE hot_x, VALUE
 #endif
 
 static VALUE
-gtkdrag_set_icon_default(VALUE self, VALUE context)
+rg_m_set_icon_default(VALUE self, VALUE context)
 {
     gtk_drag_set_icon_default(RVAL2DC(context));
     return self;
 }
 
 static VALUE
-gtkdrag_check_threshold(VALUE self, VALUE widget, VALUE start_x, VALUE start_y, VALUE current_x, VALUE current_y)
+rg_m_threshold_p(G_GNUC_UNUSED VALUE self, VALUE widget, VALUE start_x, VALUE start_y, VALUE current_x, VALUE current_y)
 {
     return CBOOL2RVAL(gtk_drag_check_threshold(RVAL2WIDGET(widget), 
                                                NUM2INT(start_x), NUM2INT(start_y),
@@ -252,17 +298,23 @@ gtkdrag_check_threshold(VALUE self, VALUE widget, VALUE start_x, VALUE start_y,
 }
 
 static VALUE
-gtkdrag_source_set(VALUE self, VALUE widget, VALUE flags, VALUE targets, VALUE actions)
+rg_m_source_set(VALUE self, VALUE rbwidget, VALUE rbstart_button_mask, VALUE rbtargets, VALUE rbactions)
 {
-    gtk_drag_source_set(RVAL2WIDGET(widget), RVAL2GFLAGS(flags, GDK_TYPE_MODIFIER_TYPE),
-                        rbgtk_get_target_entry(targets), 
-                        RARRAY_LEN(targets), 
-                        RVAL2GFLAGS(actions, GDK_TYPE_DRAG_ACTION));
+    GtkWidget *widget = RVAL2WIDGET(rbwidget);
+    GdkModifierType start_button_mask = RVAL2GFLAGS(rbstart_button_mask, GDK_TYPE_MODIFIER_TYPE);
+    GdkDragAction actions = RVAL2GFLAGS(rbactions, GDK_TYPE_DRAG_ACTION);
+    long n;
+    GtkTargetEntry *targets = RVAL2GTKTARGETENTRIES(rbtargets, &n);
+
+    gtk_drag_source_set(widget, start_button_mask, targets, n, actions);
+
+    g_free(targets);
+
     return self;
 }
 
 static VALUE
-gtkdrag_source_set_icon(int argc, VALUE *argv, VALUE self)
+rg_m_source_set_icon(int argc, VALUE *argv, VALUE self)
 {
     VALUE widget, obj, pixmap = Qnil, mask = Qnil;
 
@@ -285,7 +337,7 @@ gtkdrag_source_set_icon(int argc, VALUE *argv, VALUE self)
 
 #if GTK_CHECK_VERSION(2,8,0)
 static VALUE
-gtkdrag_source_set_icon_name(VALUE self, VALUE widget, VALUE icon_name)
+rg_m_source_set_icon_name(VALUE self, VALUE widget, VALUE icon_name)
 {
     gtk_drag_source_set_icon_name(RVAL2WIDGET(widget), RVAL2CSTR(icon_name));
     return self;
@@ -293,7 +345,7 @@ gtkdrag_source_set_icon_name(VALUE self, VALUE widget, VALUE icon_name)
 #endif
 
 static VALUE
-gtkdrag_source_unset(VALUE self, VALUE widget)
+rg_m_source_unset(VALUE self, VALUE widget)
 {
     gtk_drag_source_unset(RVAL2WIDGET(widget));
     return self;
@@ -301,7 +353,7 @@ gtkdrag_source_unset(VALUE self, VALUE widget)
 
 #if GTK_CHECK_VERSION(2,4,0)
 static VALUE
-gtkdrag_source_set_target_list(VALUE self, VALUE widget, VALUE targetlist)
+rg_m_source_set_target_list(VALUE self, VALUE widget, VALUE targetlist)
 {
     GtkTargetList* tlist = NULL;
     if (! NIL_P(targetlist))
@@ -312,7 +364,7 @@ gtkdrag_source_set_target_list(VALUE self, VALUE widget, VALUE targetlist)
 }
 
 static VALUE
-gtkdrag_source_get_target_list(VALUE self, VALUE widget)
+rg_m_source_get_target_list(G_GNUC_UNUSED VALUE self, VALUE widget)
 {
     GtkTargetList* ret = gtk_drag_source_get_target_list(RVAL2WIDGET(widget));
     return NIL_P(ret) ? Qnil : BOXED2RVAL(ret, GTK_TYPE_TARGET_LIST);
@@ -321,19 +373,19 @@ gtkdrag_source_get_target_list(VALUE self, VALUE widget)
 
 #if GTK_CHECK_VERSION(2,6,0)
 static VALUE
-gtkdrag_source_add_text_targets(VALUE self, VALUE widget)
+rg_m_source_add_text_targets(VALUE self, VALUE widget)
 {
     gtk_drag_source_add_text_targets(RVAL2WIDGET(widget));
     return self;
 }
 static VALUE
-gtkdrag_source_add_image_targets(VALUE self, VALUE widget)
+rg_m_source_add_image_targets(VALUE self, VALUE widget)
 {
     gtk_drag_source_add_image_targets(RVAL2WIDGET(widget));
     return self;
 }
 static VALUE
-gtkdrag_source_add_uri_targets(VALUE self, VALUE widget)
+rg_m_source_add_uri_targets(VALUE self, VALUE widget)
 {
     gtk_drag_source_add_uri_targets(RVAL2WIDGET(widget));
     return self;
@@ -341,59 +393,59 @@ gtkdrag_source_add_uri_targets(VALUE self, VALUE widget)
 #endif
 
 void
-Init_gtk_drag()
+Init_gtk_drag(VALUE mGtk)
 {
-    VALUE mGtkDrag = rb_define_module_under(mGtk, "Drag");
+    VALUE RG_TARGET_NAMESPACE = rb_define_module_under(mGtk, "Drag");
 
-    rb_define_module_function(mGtkDrag, "dest_set", gtkdrag_dest_set, 4);
-    rb_define_module_function(mGtkDrag, "dest_set_proxy", gtkdrag_dest_set_proxy, 4);
-    rb_define_module_function(mGtkDrag, "dest_unset", gtkdrag_dest_unset, 1);
-    rb_define_module_function(mGtkDrag, "dest_find_target", gtkdrag_dest_find_target, -1);
-    rb_define_module_function(mGtkDrag, "dest_get_target_list", gtkdrag_dest_get_target_list, 1);
-    rb_define_module_function(mGtkDrag, "dest_set_target_list", gtkdrag_dest_set_target_list, 2);
+    RG_DEF_MODFUNC(dest_set, 4);
+    RG_DEF_MODFUNC(dest_set_proxy, 4);
+    RG_DEF_MODFUNC(dest_unset, 1);
+    RG_DEF_MODFUNC(dest_find_target, -1);
+    RG_DEF_MODFUNC(dest_get_target_list, 1);
+    RG_DEF_MODFUNC(dest_set_target_list, 2);
 #if GTK_CHECK_VERSION(2,6,0)
-    rb_define_module_function(mGtkDrag, "dest_add_text_targets", gtkdrag_dest_add_text_targets, 1);
-    rb_define_module_function(mGtkDrag, "dest_add_image_targets", gtkdrag_dest_add_image_targets, 1);
-    rb_define_module_function(mGtkDrag, "dest_add_uri_targets", gtkdrag_dest_add_uri_targets, 1);
+    RG_DEF_MODFUNC(dest_add_text_targets, 1);
+    RG_DEF_MODFUNC(dest_add_image_targets, 1);
+    RG_DEF_MODFUNC(dest_add_uri_targets, 1);
 #endif
 #if GTK_CHECK_VERSION(2,10,0)
-    rb_define_module_function(mGtkDrag, "dest_set_track_motion", gtkdrag_dest_set_track_motion, 2);
-    rb_define_module_function(mGtkDrag, "dest_get_track_motion", gtkdrag_dest_get_track_motion, 1);
+    RG_DEF_MODFUNC(dest_set_track_motion, 2);
+    RG_DEF_MODFUNC(dest_get_track_motion, 1);
 #endif
-    rb_define_module_function(mGtkDrag, "finish", gtkdrag_finish, 4);
-    rb_define_module_function(mGtkDrag, "get_data", gtkdrag_get_data, 4);
-    rb_define_module_function(mGtkDrag, "get_source_widget", gtkdrag_get_source_widget, 1);
-    rb_define_module_function(mGtkDrag, "highlight", gtkdrag_highlight, 1);
-    rb_define_module_function(mGtkDrag, "unhighlight", gtkdrag_unhighlight, 1);
-    rb_define_module_function(mGtkDrag, "begin", gtkdrag_begin, 5);
-    rb_define_module_function(mGtkDrag, "threshold?", gtkdrag_check_threshold, 5);
-    rb_define_module_function(mGtkDrag, "set_icon", gtkdrag_set_icon, -1);
+    RG_DEF_MODFUNC(finish, 4);
+    RG_DEF_MODFUNC(get_data, 4);
+    RG_DEF_MODFUNC(get_source_widget, 1);
+    RG_DEF_MODFUNC(highlight, 1);
+    RG_DEF_MODFUNC(unhighlight, 1);
+    RG_DEF_MODFUNC(begin, 5);
+    RG_DEF_MODFUNC_P(threshold, 5);
+    RG_DEF_MODFUNC(set_icon, -1);
 #if GTK_CHECK_VERSION(2,8,0)
-    rb_define_module_function(mGtkDrag, "set_icon_name", gtkdrag_set_icon_name, 4);
+    RG_DEF_MODFUNC(set_icon_name, 4);
 #endif
-    rb_define_module_function(mGtkDrag, "set_icon_default", gtkdrag_set_icon_default, 1);
-    rb_define_module_function(mGtkDrag, "source_set", gtkdrag_source_set, 4);
-    rb_define_module_function(mGtkDrag, "source_set_icon", gtkdrag_source_set_icon, -1);
+    RG_DEF_MODFUNC(set_icon_default, 1);
+    RG_DEF_MODFUNC(source_set, 4);
+    RG_DEF_MODFUNC(source_set_icon, -1);
 #if GTK_CHECK_VERSION(2,8,0)
-    rb_define_module_function(mGtkDrag, "source_set_icon_name", gtkdrag_source_set_icon_name, 2);
+    RG_DEF_MODFUNC(source_set_icon_name, 2);
 #endif
-    rb_define_module_function(mGtkDrag, "source_unset", gtkdrag_source_unset, 1);
+    RG_DEF_MODFUNC(source_unset, 1);
 #if GTK_CHECK_VERSION(2,4,0)
-    rb_define_module_function(mGtkDrag, "source_set_target_list", gtkdrag_source_set_target_list, 2);
-    rb_define_module_function(mGtkDrag, "source_get_target_list", gtkdrag_source_get_target_list, 1);
+    RG_DEF_MODFUNC(source_set_target_list, 2);
+    RG_DEF_MODFUNC(source_get_target_list, 1);
 #endif
 #if GTK_CHECK_VERSION(2,6,0)
-    rb_define_module_function(mGtkDrag, "source_add_text_targets", gtkdrag_source_add_text_targets, 1);
-    rb_define_module_function(mGtkDrag, "source_add_image_targets", gtkdrag_source_add_image_targets, 1);
-    rb_define_module_function(mGtkDrag, "source_add_uri_targets", gtkdrag_source_add_uri_targets, 1);
+    RG_DEF_MODFUNC(source_add_text_targets, 1);
+    RG_DEF_MODFUNC(source_add_image_targets, 1);
+    RG_DEF_MODFUNC(source_add_uri_targets, 1);
 #endif
-    G_DEF_SETTERS(mGtkDrag);
+    G_DEF_SETTERS(RG_TARGET_NAMESPACE);
 
     /* GtkDestDefaults */
-    G_DEF_CLASS(GTK_TYPE_DEST_DEFAULTS, "DestDefaults", mGtkDrag);
-    G_DEF_CONSTANTS(mGtkDrag, GTK_TYPE_DEST_DEFAULTS, "GTK_");
+    G_DEF_CLASS(GTK_TYPE_DEST_DEFAULTS, "DestDefaults", RG_TARGET_NAMESPACE);
+    G_DEF_CONSTANTS(RG_TARGET_NAMESPACE, GTK_TYPE_DEST_DEFAULTS, "GTK_");
 
     /* GtkTargetFlags */
-    G_DEF_CLASS(GTK_TYPE_TARGET_FLAGS, "TargetFlags", mGtkDrag);
-    G_DEF_CONSTANTS(mGtkDrag, GTK_TYPE_TARGET_FLAGS, "GTK_");
+    G_DEF_CLASS(GTK_TYPE_TARGET_FLAGS, "TargetFlags", RG_TARGET_NAMESPACE);
+    G_DEF_CONSTANTS(RG_TARGET_NAMESPACE, GTK_TYPE_TARGET_FLAGS, "GTK_");
 }
