@@ -1,22 +1,33 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
-/************************************************
- 
-  rbgtkfilechooserdialog.c -
- 
-  $Author: mutoh $
-  $Date: 2006/12/26 16:11:13 $
- 
-  Copyright (C) 2004 Seiya Nishizawa, Masao Mutoh
-************************************************/
- 
+/*
+ *  Copyright (C) 2011  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2004  Seiya Nishizawa, Masao Mutoh
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
+ */
+
 #include "global.h"
 
 #if GTK_CHECK_VERSION(2,4,0)
 
+#define RG_TARGET_NAMESPACE cFileChooserDialog
 #define _SELF(self) GTK_FILE_CHOOSER_DIALOG(RVAL2GOBJ(self))
 
 static VALUE
-fchodiag_initialize(int argc, VALUE *argv, VALUE self)
+rg_initialize(int argc, VALUE *argv, VALUE self)
 {
     VALUE title, parent, action, back, button_ary;
     GtkWidget* dialog;
@@ -44,14 +55,13 @@ fchodiag_initialize(int argc, VALUE *argv, VALUE self)
 #endif
 
 void 
-Init_gtk_file_chooser_dialog()
+Init_gtk_file_chooser_dialog(VALUE mGtk)
 {
 #if GTK_CHECK_VERSION(2,4,0)
 
-    VALUE gFileChoDiag = G_DEF_CLASS(GTK_TYPE_FILE_CHOOSER_DIALOG, "FileChooserDialog", mGtk);
+    VALUE RG_TARGET_NAMESPACE = G_DEF_CLASS(GTK_TYPE_FILE_CHOOSER_DIALOG, "FileChooserDialog", mGtk);
 
-    rb_define_method(gFileChoDiag, "initialize", fchodiag_initialize, -1);
+    RG_DEF_METHOD(initialize, -1);
 
 #endif
 }
-
