@@ -1,20 +1,31 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
-/************************************************
-
-  rbgtkmessagedialog.c -
-
-  $Author: mutoh $
-  $Date: 2006/10/21 16:58:00 $
-
-  Copyright (C) 2002-2006 Masao Mutoh
-************************************************/
+/*
+ *  Copyright (C) 2011  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2002-2006 Masao Mutoh
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
+ */
 
 #include "global.h"
 
+#define RG_TARGET_NAMESPACE cMessageDialog
 #define _SELF(s) (GTK_MESSAGE_DIALOG(RVAL2GOBJ(s)))
 
 static VALUE
-mdiag_initialize(int argc, VALUE *argv, VALUE self)
+rg_initialize(int argc, VALUE *argv, VALUE self)
 {
     VALUE parent, flags, type, buttons, message;
     GtkWidget* w;
@@ -43,18 +54,13 @@ GtkWidget*  gtk_message_dialog_new_with_markup
 */
 #if GTK_CHECK_VERSION(2,4,0)
 static VALUE
-mdiag_set_markup(VALUE self, VALUE str)
+rg_set_markup(VALUE self, VALUE str)
 {
     gtk_message_dialog_set_markup(_SELF(self), RVAL2CSTR(str));
     return self;
 }
 #endif
 
-/* Defined as properties.
-void        gtk_message_dialog_set_image    (GtkMessageDialog *dialog,
-                                             GtkWidget *image);
-*/
-
 /* Not needed in Ruby
 void                gtk_message_dialog_format_secondary_text
                                                         (GtkMessageDialog *message_dialog,
@@ -67,21 +73,21 @@ void                gtk_message_dialog_format_secondary_markup
 */
 
 void 
-Init_gtk_message_dialog()
+Init_gtk_message_dialog(VALUE mGtk)
 {
-    VALUE gMessageDialog = G_DEF_CLASS(GTK_TYPE_MESSAGE_DIALOG, "MessageDialog", mGtk);
+    VALUE RG_TARGET_NAMESPACE = G_DEF_CLASS(GTK_TYPE_MESSAGE_DIALOG, "MessageDialog", mGtk);
 
-    rb_define_method(gMessageDialog, "initialize", mdiag_initialize, -1);
+    RG_DEF_METHOD(initialize, -1);
 #if GTK_CHECK_VERSION(2,4,0)
-    rb_define_method(gMessageDialog, "set_markup", mdiag_set_markup, 1);
-    G_DEF_SETTER(gMessageDialog, "markup");
+    RG_DEF_METHOD(set_markup, 1);
+    G_DEF_SETTER(RG_TARGET_NAMESPACE, "markup");
 #endif
 
     /* GtkMessageType */
-    G_DEF_CLASS(GTK_TYPE_MESSAGE_TYPE, "Type", gMessageDialog);
-    G_DEF_CONSTANTS(gMessageDialog, GTK_TYPE_MESSAGE_TYPE, "GTK_MESSAGE_");
+    G_DEF_CLASS(GTK_TYPE_MESSAGE_TYPE, "Type", RG_TARGET_NAMESPACE);
+    G_DEF_CONSTANTS(RG_TARGET_NAMESPACE, GTK_TYPE_MESSAGE_TYPE, "GTK_MESSAGE_");
 
     /* GtkButtonsType */
-    G_DEF_CLASS(GTK_TYPE_BUTTONS_TYPE, "ButtonsType", gMessageDialog);
-    G_DEF_CONSTANTS(gMessageDialog, GTK_TYPE_BUTTONS_TYPE, "GTK_");
+    G_DEF_CLASS(GTK_TYPE_BUTTONS_TYPE, "ButtonsType", RG_TARGET_NAMESPACE);
+    G_DEF_CONSTANTS(RG_TARGET_NAMESPACE, GTK_TYPE_BUTTONS_TYPE, "GTK_");
 }
