@@ -1,32 +1,43 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
-/************************************************
-
-  rbgtknotebook.c -
-
-  $Author: ggc $
-  $Date: 2007/07/13 16:07:31 $
-
-  Copyright (C) 2002,2003 Ruby-GNOME2 Project Team
-  Copyright (C) 1998-2000 Yukihiro Matsumoto,
-                          Daisuke Kanda,
-                          Hiroshi Igarashi
-************************************************/
+/*
+ *  Copyright (C) 2011  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2002,2003 Ruby-GNOME2 Project Team
+ *  Copyright (C) 1998-2000 Yukihiro Matsumoto,
+ *                          Daisuke Kanda,
+ *                          Hiroshi Igarashi
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
+ */
 
 #include "global.h"
 
+#define RG_TARGET_NAMESPACE cNotebook
 #define _SELF(self) GTK_NOTEBOOK(RVAL2GOBJ(self))
 #define RVAL2WIDGET(w) GTK_WIDGET(RVAL2GOBJ(w))
 #define GTK_TYPE_NOTEBOOK_PAGE (gtk_notebookpage_get_type())
 
 static VALUE
-note_initialize(VALUE self)
+rg_initialize(VALUE self)
 {
     RBGTK_INITIALIZE(self, gtk_notebook_new());
     return Qnil;
 }
 
 static VALUE
-note_append_page(int argc, VALUE *argv, VALUE self)
+rg_append_page(int argc, VALUE *argv, VALUE self)
 {
     VALUE child, label;
 
@@ -40,10 +51,10 @@ note_append_page(int argc, VALUE *argv, VALUE self)
 }
 
 static VALUE
-note_append_page_menu(int argc, VALUE *argv, VALUE self)
+rg_append_page_menu(int argc, VALUE *argv, VALUE self)
 {
     VALUE child, tab_label, menu_label;
-    
+
     rb_scan_args(argc, argv, "12", &child, &tab_label, &menu_label);
     gtk_notebook_append_page_menu(_SELF(self),
                                   RVAL2WIDGET(child),
@@ -54,7 +65,7 @@ note_append_page_menu(int argc, VALUE *argv, VALUE self)
 }
 
 static VALUE
-note_prepend_page(int argc, VALUE *argv, VALUE self)
+rg_prepend_page(int argc, VALUE *argv, VALUE self)
 {
     VALUE child, label;
 
@@ -66,7 +77,7 @@ note_prepend_page(int argc, VALUE *argv, VALUE self)
 }
 
 static VALUE
-note_prepend_page_menu(int argc, VALUE *argv, VALUE self)
+rg_prepend_page_menu(int argc, VALUE *argv, VALUE self)
 {
     VALUE child, tab_label, menu_label;
 
@@ -80,7 +91,7 @@ note_prepend_page_menu(int argc, VALUE *argv, VALUE self)
 }
 
 static VALUE
-note_insert_page(int argc, VALUE *argv, VALUE self)
+rg_insert_page(int argc, VALUE *argv, VALUE self)
 {
     VALUE pos, child, label;
 
@@ -93,7 +104,7 @@ note_insert_page(int argc, VALUE *argv, VALUE self)
 }
 
 static VALUE
-note_insert_page_menu(int argc, VALUE *argv, VALUE self)
+rg_insert_page_menu(int argc, VALUE *argv, VALUE self)
 {
     VALUE pos, child, tab_label, menu_label;
 
@@ -107,35 +118,35 @@ note_insert_page_menu(int argc, VALUE *argv, VALUE self)
 }
 
 static VALUE
-note_remove_page(VALUE self, VALUE pos)
+rg_remove_page(VALUE self, VALUE pos)
 {
     gtk_notebook_remove_page(_SELF(self), NUM2INT(pos));
     return self;
 }
 
 static VALUE
-note_page_num(VALUE self, VALUE child)
+rg_page_num(VALUE self, VALUE child)
 {
     return INT2FIX(gtk_notebook_page_num(_SELF(self),
                                          RVAL2WIDGET(child)));
 }
 
 static VALUE
-note_next_page(VALUE self)
+rg_next_page(VALUE self)
 {
     gtk_notebook_next_page(_SELF(self));
     return self;
 }
 
 static VALUE
-note_prev_page(VALUE self)
+rg_prev_page(VALUE self)
 {
     gtk_notebook_prev_page(_SELF(self));
     return self;
 }
 
 static VALUE
-note_reorder_child(VALUE self, VALUE child, VALUE pos)
+rg_reorder_child(VALUE self, VALUE child, VALUE pos)
 {
     gtk_notebook_reorder_child(_SELF(self), RVAL2WIDGET(child),
                                NUM2INT(pos));
@@ -143,14 +154,14 @@ note_reorder_child(VALUE self, VALUE child, VALUE pos)
 }
 
 static VALUE
-note_get_menu_label(VALUE self, VALUE child)
+rg_get_menu_label(VALUE self, VALUE child)
 {
     return GOBJ2RVAL(gtk_notebook_get_menu_label(_SELF(self),
                                                  RVAL2WIDGET(child)));
 }
 
 static VALUE
-note_get_nth_page(VALUE self, VALUE page_num)
+rg_get_nth_page(VALUE self, VALUE page_num)
 {
     GtkWidget *page = gtk_notebook_get_nth_page(_SELF(self),
                                                 NUM2INT(page_num));
@@ -159,21 +170,21 @@ note_get_nth_page(VALUE self, VALUE page_num)
 
 #if GTK_CHECK_VERSION(2,2,0)
 static VALUE
-note_get_n_pages(VALUE self)
+rg_n_pages(VALUE self)
 {
     return INT2NUM(gtk_notebook_get_n_pages(_SELF(self)));
 }
 #endif
 
 static VALUE
-note_get_tab_label(VALUE self, VALUE child)
+rg_get_tab_label(VALUE self, VALUE child)
 {
     return GOBJ2RVAL(gtk_notebook_get_tab_label(_SELF(self),
                                                 RVAL2WIDGET(child)));
 }
 
 static VALUE
-note_query_tab_label_packing(VALUE self, VALUE child)
+rg_query_tab_label_packing(VALUE self, VALUE child)
 {
     gboolean expand, fill;
     GtkPackType pack_type;
@@ -190,7 +201,7 @@ note_query_tab_label_packing(VALUE self, VALUE child)
 }
 
 static VALUE
-note_set_menu_label(VALUE self, VALUE child, VALUE label)
+rg_set_menu_label(VALUE self, VALUE child, VALUE label)
 {
     gtk_notebook_set_menu_label(_SELF(self),
                                 RVAL2WIDGET(child),
@@ -199,7 +210,7 @@ note_set_menu_label(VALUE self, VALUE child, VALUE label)
 }
 
 static VALUE
-note_set_menu_label_text(VALUE self, VALUE child, VALUE text)
+rg_set_menu_label_text(VALUE self, VALUE child, VALUE text)
 {
     gtk_notebook_set_menu_label_text(_SELF(self),
                                      RVAL2WIDGET(child),
@@ -208,7 +219,7 @@ note_set_menu_label_text(VALUE self, VALUE child, VALUE text)
 }
 
 static VALUE
-note_set_tab_label(VALUE self, VALUE child, VALUE label)
+rg_set_tab_label(VALUE self, VALUE child, VALUE label)
 {
     gtk_notebook_set_tab_label(_SELF(self),
                                RVAL2WIDGET(child),
@@ -217,7 +228,7 @@ note_set_tab_label(VALUE self, VALUE child, VALUE label)
 }
 
 static VALUE
-note_set_tab_label_packing(VALUE self, VALUE child, VALUE expand, VALUE fill, VALUE pack_type)
+rg_set_tab_label_packing(VALUE self, VALUE child, VALUE expand, VALUE fill, VALUE pack_type)
 {
     gtk_notebook_set_tab_label_packing(_SELF(self),
                                        RVAL2WIDGET(child),
@@ -227,7 +238,7 @@ note_set_tab_label_packing(VALUE self, VALUE child, VALUE expand, VALUE fill, VA
 }
 
 static VALUE
-note_set_tab_label_text(VALUE self, VALUE child, VALUE text)
+rg_set_tab_label_text(VALUE self, VALUE child, VALUE text)
 {
     gtk_notebook_set_tab_label_text(_SELF(self),
                                     RVAL2WIDGET(child),
@@ -236,14 +247,14 @@ note_set_tab_label_text(VALUE self, VALUE child, VALUE text)
 }
 
 static VALUE
-note_get_menu_label_text(VALUE self, VALUE child)
+rg_get_menu_label_text(VALUE self, VALUE child)
 {
     return CSTR2RVAL(gtk_notebook_get_menu_label_text(_SELF(self), 
                                                       RVAL2WIDGET(child)));
 }
 
 static VALUE
-note_get_tab_label_text(VALUE self, VALUE child)
+rg_get_tab_label_text(VALUE self, VALUE child)
 {
     return CSTR2RVAL(gtk_notebook_get_tab_label_text(_SELF(self), 
                                                      RVAL2WIDGET(child)));
@@ -251,13 +262,13 @@ note_get_tab_label_text(VALUE self, VALUE child)
 
 #if GTK_CHECK_VERSION(2,10,0)
 static VALUE
-note_get_tab_reorderable(VALUE self, VALUE child)
+rg_get_tab_reorderable(VALUE self, VALUE child)
 {
     return CBOOL2RVAL(gtk_notebook_get_tab_reorderable(_SELF(self), 
                                                        GTK_WIDGET(RVAL2GOBJ(child))));
 }
 static VALUE
-note_set_tab_reorderable(VALUE self, VALUE child, VALUE reorderable)
+rg_set_tab_reorderable(VALUE self, VALUE child, VALUE reorderable)
 {
     gtk_notebook_set_tab_reorderable(_SELF(self), GTK_WIDGET(RVAL2GOBJ(child)),
                                      RVAL2CBOOL(reorderable));
@@ -265,13 +276,13 @@ note_set_tab_reorderable(VALUE self, VALUE child, VALUE reorderable)
 }
 
 static VALUE
-note_get_tab_detachable(VALUE self, VALUE child)
+rg_get_tab_detachable(VALUE self, VALUE child)
 {
     return CBOOL2RVAL(gtk_notebook_get_tab_detachable(_SELF(self), 
                                                       GTK_WIDGET(RVAL2GOBJ(child))));
 }
 static VALUE
-note_set_tab_detachable(VALUE self, VALUE child, VALUE detachable)
+rg_set_tab_detachable(VALUE self, VALUE child, VALUE detachable)
 {
     gtk_notebook_set_tab_detachable(_SELF(self), GTK_WIDGET(RVAL2GOBJ(child)),
                                      RVAL2CBOOL(detachable));
@@ -288,7 +299,7 @@ creation_func(GtkNotebook *source, GtkWidget *page, gint x, gint y, gpointer fun
 }
 
 static VALUE
-note_set_window_creation_hook(VALUE self)
+rg_s_set_window_creation_hook(VALUE self)
 {
     VALUE func = rb_block_proc();
     G_RELATIVE(self, func);
@@ -300,7 +311,7 @@ note_set_window_creation_hook(VALUE self)
 
 #if GTK_CHECK_VERSION(2,20,0)
 static VALUE
-note_set_action_widget(VALUE self, VALUE widget, VALUE pack_type)
+rg_set_action_widget(VALUE self, VALUE widget, VALUE pack_type)
 {
     gtk_notebook_set_action_widget(_SELF(self),
                                    RVAL2WIDGET(widget),
@@ -309,7 +320,7 @@ note_set_action_widget(VALUE self, VALUE widget, VALUE pack_type)
 }
 
 static VALUE
-note_get_action_widget(VALUE self, VALUE pack_type)
+rg_get_action_widget(VALUE self, VALUE pack_type)
 {
     return GOBJ2RVAL(gtk_notebook_get_action_widget(_SELF(self),
                                                     RVAL2GENUM(pack_type, GTK_TYPE_PACK_TYPE)));
@@ -322,20 +333,20 @@ note_get_action_widget(VALUE self, VALUE pack_type)
  */
 typedef struct {
     VALUE parent;
-    GtkNotebookPage* page;
+    GtkNotebookPage *page;
 } GtkNotebookPageData;
 
-GtkNotebookPageData*
-notebookpage_copy (const GtkNotebookPage* page)
+static GtkNotebookPageData *
+notebookpage_copy(const GtkNotebookPage *page)
 {
-  GtkNotebookPageData* data;
+  GtkNotebookPageData *data;
   g_return_val_if_fail (page != NULL, NULL);
   data = g_new(GtkNotebookPageData, 1);
-  data->page = (GtkNotebookPage*)page;
+  data->page = (GtkNotebookPage *)page;
   return data;
 }
 
-GType
+static GType
 gtk_notebookpage_get_type(void)
 {
   static GType our_type = 0;
@@ -347,7 +358,7 @@ gtk_notebookpage_get_type(void)
 }
 
 static VALUE
-signal_g2r_func(guint num, const GValue *values)
+signal_g2r_func(G_GNUC_UNUSED guint num, const GValue *values)
 {
     GtkNotebookPageData npp;
     npp.parent = GVAL2RVAL(&values[0]);
@@ -356,102 +367,55 @@ signal_g2r_func(guint num, const GValue *values)
                        GVAL2RVAL(&values[2]));
 }
 
-/* Defined as the "page" property.
-*/
-
-/* Defined as properties
-// "enable-popup" property
-void        gtk_notebook_popup_enable       (GtkNotebook *notebook);
-void        gtk_notebook_popup_disable      (GtkNotebook *notebook);
-
-void        gtk_notebook_set_group_id       (GtkNotebook *notebook,
-                                             gint group_id);
-gint        gtk_notebook_get_group_id       (GtkNotebook *notebook);
-
-// "homogeneous" property
-void        gtk_notebook_set_homogeneous_tabs
-                                            (GtkNotebook *notebook,
-                                             gboolean homogeneous);
-// "page" property.
-#define     gtk_notebook_current_page
-#define     gtk_notebook_set_page
-gint        gtk_notebook_get_current_page   (GtkNotebook *notebook);
-void        gtk_notebook_set_current_page   (GtkNotebook *notebook,
-                                             gint page_num);
-
-gboolean    gtk_notebook_get_scrollable     (GtkNotebook *notebook);
-void        gtk_notebook_set_scrollable     (GtkNotebook *notebook,
-                                             gboolean scrollable);
-
-void        gtk_notebook_set_show_border    (GtkNotebook *notebook,
-                                             gboolean show_border);
-gboolean    gtk_notebook_get_show_border    (GtkNotebook *notebook);
-
-gboolean    gtk_notebook_get_show_tabs      (GtkNotebook *notebook);
-void        gtk_notebook_set_show_tabs      (GtkNotebook *notebook,
-                                             gboolean show_tabs);
-
-GtkPositionType gtk_notebook_get_tab_pos    (GtkNotebook *notebook);
-void        gtk_notebook_set_tab_pos        (GtkNotebook *notebook,
-                                             GtkPositionType pos);
-
-void        gtk_notebook_set_tab_hborder    (GtkNotebook *notebook,
-                                             guint tab_hborder);
-void        gtk_notebook_set_tab_border     (GtkNotebook *notebook,
-                                             guint border_width);
-void        gtk_notebook_set_tab_vborder    (GtkNotebook *notebook,
-                                             guint tab_vborder);
- */
-
 /*****************************************/
 
 void 
-Init_gtk_notebook()
+Init_gtk_notebook(VALUE mGtk)
 {
-    VALUE gNotebook = G_DEF_CLASS(GTK_TYPE_NOTEBOOK, "Notebook", mGtk);
+    VALUE RG_TARGET_NAMESPACE = G_DEF_CLASS(GTK_TYPE_NOTEBOOK, "Notebook", mGtk);
     G_DEF_CLASS(GTK_TYPE_NOTEBOOK_PAGE, "NotebookPage", mGtk);
 
-    rb_define_method(gNotebook, "initialize", note_initialize, 0);
-    rb_define_method(gNotebook, "append_page", note_append_page, -1);
-    rb_define_method(gNotebook, "append_page_menu", note_append_page_menu, -1);
-    rb_define_method(gNotebook, "prepend_page", note_prepend_page, -1);
-    rb_define_method(gNotebook, "prepend_page_menu", note_prepend_page_menu, -1);
-    rb_define_method(gNotebook, "insert_page", note_insert_page, -1);
-    rb_define_method(gNotebook, "insert_page_menu", note_insert_page_menu, -1);
-    rb_define_method(gNotebook, "remove_page", note_remove_page, 1);
-    rb_define_method(gNotebook, "page_num", note_page_num, 1);
-    rb_define_method(gNotebook, "next_page", note_next_page, 0);
-    rb_define_method(gNotebook, "prev_page", note_prev_page, 0);
-    rb_define_method(gNotebook, "reorder_child", note_reorder_child, 2);
-    rb_define_method(gNotebook, "get_menu_label", note_get_menu_label, 1);
-    rb_define_method(gNotebook, "get_nth_page", note_get_nth_page, 1);
+    RG_DEF_METHOD(initialize, 0);
+    RG_DEF_METHOD(append_page, -1);
+    RG_DEF_METHOD(append_page_menu, -1);
+    RG_DEF_METHOD(prepend_page, -1);
+    RG_DEF_METHOD(prepend_page_menu, -1);
+    RG_DEF_METHOD(insert_page, -1);
+    RG_DEF_METHOD(insert_page_menu, -1);
+    RG_DEF_METHOD(remove_page, 1);
+    RG_DEF_METHOD(page_num, 1);
+    RG_DEF_METHOD(next_page, 0);
+    RG_DEF_METHOD(prev_page, 0);
+    RG_DEF_METHOD(reorder_child, 2);
+    RG_DEF_METHOD(get_menu_label, 1);
+    RG_DEF_METHOD(get_nth_page, 1);
 #if GTK_CHECK_VERSION(2,2,0)
-    rb_define_method(gNotebook, "n_pages", note_get_n_pages, 0);
+    RG_DEF_METHOD(n_pages, 0);
 #endif
-    rb_define_method(gNotebook, "get_tab_label", note_get_tab_label, 1);
-    rb_define_method(gNotebook, "query_tab_label_packing", note_query_tab_label_packing, 1);
-    rb_define_method(gNotebook, "set_menu_label", note_set_menu_label, 2);
-    rb_define_method(gNotebook, "set_menu_label_text", note_set_menu_label_text, 2);
-    rb_define_method(gNotebook, "set_tab_label", note_set_tab_label, 2);
-    rb_define_method(gNotebook, "set_tab_label_packing", note_set_tab_label_packing, 4);
-    rb_define_method(gNotebook, "set_tab_label_text", note_set_tab_label_text, 2);
-    rb_define_method(gNotebook, "get_menu_label_text", note_get_menu_label_text, 1);
-    rb_define_method(gNotebook, "get_tab_label_text", note_get_tab_label_text, 1);
+    RG_DEF_METHOD(get_tab_label, 1);
+    RG_DEF_METHOD(query_tab_label_packing, 1);
+    RG_DEF_METHOD(set_menu_label, 2);
+    RG_DEF_METHOD(set_menu_label_text, 2);
+    RG_DEF_METHOD(set_tab_label, 2);
+    RG_DEF_METHOD(set_tab_label_packing, 4);
+    RG_DEF_METHOD(set_tab_label_text, 2);
+    RG_DEF_METHOD(get_menu_label_text, 1);
+    RG_DEF_METHOD(get_tab_label_text, 1);
 
 #if GTK_CHECK_VERSION(2,10,0)
-    rb_define_method(gNotebook, "get_tab_reorderable", note_get_tab_reorderable, 1);
-    rb_define_method(gNotebook, "set_tab_reorderable", note_set_tab_reorderable, 2);
-    rb_define_method(gNotebook, "get_tab_detachable", note_get_tab_detachable, 1);
-    rb_define_method(gNotebook, "set_tab_detachable", note_set_tab_detachable, 2);
-    rb_define_singleton_method(gNotebook, "set_window_creation_hook", note_set_window_creation_hook, 0);
+    RG_DEF_METHOD(get_tab_reorderable, 1);
+    RG_DEF_METHOD(set_tab_reorderable, 2);
+    RG_DEF_METHOD(get_tab_detachable, 1);
+    RG_DEF_METHOD(set_tab_detachable, 2);
+    RG_DEF_SMETHOD(set_window_creation_hook, 0);
 #endif
 #if GTK_CHECK_VERSION(2,20,0)
-    rb_define_method(gNotebook, "set_action_widget", note_set_action_widget, 2);
-    rb_define_method(gNotebook, "get_action_widget", note_get_action_widget, 1);
+    RG_DEF_METHOD(set_action_widget, 2);
+    RG_DEF_METHOD(get_action_widget, 1);
 #endif
     /* GtkNotebookTab */
-    rb_define_const(gNotebook, "TAB_FIRST", GTK_NOTEBOOK_TAB_FIRST);
-    rb_define_const(gNotebook, "TAB_LAST", GTK_NOTEBOOK_TAB_LAST);
+    rb_define_const(RG_TARGET_NAMESPACE, "TAB_FIRST", GTK_NOTEBOOK_TAB_FIRST);
+    rb_define_const(RG_TARGET_NAMESPACE, "TAB_LAST", GTK_NOTEBOOK_TAB_LAST);
 
-    G_DEF_SIGNAL_FUNC(gNotebook, "switch_page", (GValToRValSignalFunc)signal_g2r_func);
+    G_DEF_SIGNAL_FUNC(RG_TARGET_NAMESPACE, "switch_page", (GValToRValSignalFunc)signal_g2r_func);
 }
