@@ -1,17 +1,28 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
-/************************************************
-
-  rbgtktextiter.c -
-
-  $Author: ggc $
-  $Date: 2007/07/13 16:07:32 $
-
-  Copyright (C) 2002-2005 Ruby-GNOME2 Project Team
-  Copyright (C) 2002,2003 Masahiro Sakai
-************************************************/
+/*
+ *  Copyright (C) 2011  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2002-2005 Ruby-GNOME2 Project Team
+ *  Copyright (C) 2002,2003 Masahiro Sakai
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
+ */
 
 #include "global.h"
 
+#define RG_TARGET_NAMESPACE cTextIter
 #define _SELF(s) ((GtkTextIter*)RVAL2BOXED(s, GTK_TYPE_TEXT_ITER))
 #define RVAL2TAG(t) (GTK_TEXT_TAG(RVAL2GOBJ(t)))
 #define ITR2RVAL(i) (BOXED2RVAL(i, GTK_TYPE_TEXT_ITER))
@@ -20,7 +31,7 @@ static gboolean is_compat_240;
 static ID id_pixbuf;
 
 static VALUE
-get_buffer(VALUE self)
+rg_buffer(VALUE self)
 {
     return GOBJ2RVAL(gtk_text_iter_get_buffer(_SELF(self)));
 }
@@ -40,7 +51,7 @@ def_gint_getter(visible_line_offset)
 def_gint_getter(visible_line_index)
 
 static VALUE
-get_char(VALUE self)
+rg_char(VALUE self)
 {
     gchar buf[10];
     gint len = g_unichar_to_utf8(gtk_text_iter_get_char(_SELF(self)), buf);
@@ -49,31 +60,31 @@ get_char(VALUE self)
 }
 
 static VALUE
-get_slice(VALUE self, VALUE rhs)
+rg_get_slice(VALUE self, VALUE rhs)
 {
     return CSTR2RVAL(gtk_text_iter_get_slice(_SELF(self), _SELF(rhs)));
 }
 
 static VALUE
-get_text(VALUE self, VALUE rhs)
+rg_get_text(VALUE self, VALUE rhs)
 {
     return CSTR2RVAL(gtk_text_iter_get_text(_SELF(self), _SELF(rhs)));
 }
 
 static VALUE
-get_visible_slice(VALUE self, VALUE rhs)
+rg_get_visible_slice(VALUE self, VALUE rhs)
 {
     return CSTR2RVAL(gtk_text_iter_get_visible_slice(_SELF(self), _SELF(rhs)));
 }
 
 static VALUE
-get_visible_text(VALUE self, VALUE rhs)
+rg_get_visible_text(VALUE self, VALUE rhs)
 {
     return CSTR2RVAL(gtk_text_iter_get_visible_text(_SELF(self), _SELF(rhs)));
 }
 
 static VALUE
-get_pixbuf(VALUE self)
+rg_pixbuf(VALUE self)
 {
     GdkPixbuf* pixbuf = gtk_text_iter_get_pixbuf(_SELF(self));
     VALUE ret = Qnil;
@@ -85,67 +96,66 @@ get_pixbuf(VALUE self)
 }
 
 static VALUE
-get_marks(VALUE self)
+rg_marks(VALUE self)
 {
     return GSLIST2ARYF(gtk_text_iter_get_marks(_SELF(self)));
 }
 
 static VALUE
-get_toggled_tags(VALUE self, VALUE toggled_on)
+rg_toggled_tags(VALUE self, VALUE toggled_on)
 {
     return GSLIST2ARYF(gtk_text_iter_get_toggled_tags(_SELF(self), RVAL2CBOOL(toggled_on)));
 }
 
 static VALUE
-get_child_anchor(VALUE self)
+rg_child_anchor(VALUE self)
 {
     GtkTextChildAnchor* anchor = gtk_text_iter_get_child_anchor(_SELF(self));
     return anchor ? GOBJ2RVAL(anchor) : Qnil;
 }
 
 static VALUE
-begins_tag(VALUE self, VALUE tag)
+rg_begins_tag_p(VALUE self, VALUE tag)
 {
     return CBOOL2RVAL(gtk_text_iter_begins_tag(_SELF(self), RVAL2TAG(tag)));
 }
 
 static VALUE
-ends_tag(VALUE self, VALUE tag)
+rg_ends_tag_p(VALUE self, VALUE tag)
 {
     return CBOOL2RVAL(gtk_text_iter_ends_tag(_SELF(self), RVAL2TAG(tag)));
 }
 
 static VALUE
-toggles_tag(VALUE self, VALUE tag)
+rg_toggles_tag_p(VALUE self, VALUE tag)
 {
     return CBOOL2RVAL(gtk_text_iter_toggles_tag(_SELF(self), RVAL2TAG(tag)));
 }
 
 static VALUE
-has_tag(VALUE self, VALUE tag)
+rg_has_tag_p(VALUE self, VALUE tag)
 {
     return CBOOL2RVAL(gtk_text_iter_has_tag(_SELF(self), RVAL2TAG(tag)));
 }
 
 static VALUE
-get_tags(VALUE self)
+rg_tags(VALUE self)
 {
     return GSLIST2ARYF(gtk_text_iter_get_tags(_SELF(self)));
 }
 
 static VALUE
-editable(VALUE self, VALUE default_setting)
+rg_editable_p(VALUE self, VALUE default_setting)
 {
     return CBOOL2RVAL(gtk_text_iter_editable(_SELF(self), RVAL2CBOOL(default_setting)));
 }
 
 static VALUE
-can_insert(VALUE self, VALUE default_setting)
+rg_can_insert_p(VALUE self, VALUE default_setting)
 {
     return CBOOL2RVAL(gtk_text_iter_can_insert(_SELF(self), RVAL2CBOOL(default_setting)));
 }
 
-    
 #define def_predicate(__name__) \
 static VALUE \
 __name__(VALUE self) \
@@ -166,19 +176,19 @@ def_gint_getter(chars_in_line)
 def_gint_getter(bytes_in_line)
 
 static VALUE
-get_attributes(VALUE self)
+rg_attributes(VALUE self)
 {
     GtkTextAttributes attr;
-    
+
     if(gtk_text_iter_get_attributes(_SELF(self), &attr) == TRUE){
         return BOXED2RVAL(&attr, GTK_TYPE_TEXT_ATTRIBUTES);
     } else {
         return Qnil;
     }
 }
-    
+
 static VALUE
-get_language(VALUE self)
+rg_language(VALUE self)
 {
     return CSTR2RVAL(pango_language_to_string(gtk_text_iter_get_language(_SELF(self))));
 }
@@ -186,7 +196,6 @@ get_language(VALUE self)
 def_predicate(is_end)
 def_predicate(is_start)
 
-
 #define def_move(__name__) \
 static VALUE \
 __name__(VALUE self) \
@@ -241,7 +250,7 @@ def_move_gint(backward_cursor_positions)
 def_move(forward_to_line_end)
 
 static VALUE
-forward_to_end(VALUE self)
+rg_forward_to_end(VALUE self)
 {
     gtk_text_iter_forward_to_end(_SELF(self));
     return self;
@@ -264,7 +273,7 @@ def_gint_setter(visible_line_offset)
 def_gint_setter(visible_line_index)
 
 static VALUE
-forward_to_tag_toggle(int argc, VALUE *argv, VALUE self)
+rg_forward_to_tag_toggle(int argc, VALUE *argv, VALUE self)
 {
     VALUE tag;
 
@@ -274,7 +283,7 @@ forward_to_tag_toggle(int argc, VALUE *argv, VALUE self)
 }
 
 static VALUE
-backward_to_tag_toggle(int argc, VALUE *argv, VALUE self)
+rg_backward_to_tag_toggle(int argc, VALUE *argv, VALUE self)
 {
     VALUE tag;
 
@@ -290,11 +299,11 @@ char_predicate_func(guint32 ch, gpointer func)
 }
 
 static VALUE
-forward_find_char(int argc, VALUE *argv, VALUE self)
+rg_forward_find_char(int argc, VALUE *argv, VALUE self)
 {
     VALUE limit;
     volatile VALUE func = rb_block_proc();
-    
+
     rb_scan_args(argc, argv, "01", &limit);
     return CBOOL2RVAL(gtk_text_iter_forward_find_char(_SELF(self),
                                                       (GtkTextCharPredicate)char_predicate_func, 
@@ -303,7 +312,7 @@ forward_find_char(int argc, VALUE *argv, VALUE self)
 }
 
 static VALUE
-backward_find_char(int argc, VALUE *argv, VALUE self)
+rg_backward_find_char(int argc, VALUE *argv, VALUE self)
 {
     VALUE limit;
     volatile VALUE func = rb_block_proc();
@@ -316,7 +325,7 @@ backward_find_char(int argc, VALUE *argv, VALUE self)
 }
 
 static VALUE
-forward_search(int argc, VALUE *argv, VALUE self)
+rg_forward_search(int argc, VALUE *argv, VALUE self)
 {
     GtkTextIter m_start, m_end;
     VALUE str, flags, limit;
@@ -339,7 +348,7 @@ forward_search(int argc, VALUE *argv, VALUE self)
 }
 
 static VALUE
-backward_search(int argc, VALUE *argv, VALUE self)
+rg_backward_search(int argc, VALUE *argv, VALUE self)
 {
     GtkTextIter m_start, m_end;
     VALUE str, flags, limit;
@@ -361,13 +370,13 @@ backward_search(int argc, VALUE *argv, VALUE self)
 }
 
 static VALUE
-equal(VALUE self, VALUE other)
+rg_operator_equal(VALUE self, VALUE other)
 {
     return CBOOL2RVAL(gtk_text_iter_equal(_SELF(self), _SELF(other)));
 }
 
 static VALUE
-compare(VALUE self, VALUE rhs)
+rg_operator_compare(VALUE self, VALUE rhs)
 {
     return INT2NUM(gtk_text_iter_compare(_SELF(self), _SELF(rhs)));
 }
@@ -375,7 +384,7 @@ compare(VALUE self, VALUE rhs)
 /*
   The following methods don't have to be implimented.
   Including Comparable module is enough.
-  
+
 gboolean    gtk_text_iter_in_range          (const GtkTextIter *iter,
                                              const GtkTextIter *start,
                                              const GtkTextIter *end);
@@ -384,123 +393,122 @@ void        gtk_text_iter_order             (GtkTextIter *first,
 */
 
 void
-Init_gtk_textiter()
+Init_gtk_textiter(VALUE mGtk)
 {
-    VALUE cTextIter = G_DEF_CLASS(GTK_TYPE_TEXT_ITER, "TextIter", mGtk);
-    rb_include_module(cTextIter, rb_mComparable);
+    VALUE RG_TARGET_NAMESPACE = G_DEF_CLASS(GTK_TYPE_TEXT_ITER, "TextIter", mGtk);
+    rb_include_module(RG_TARGET_NAMESPACE, rb_mComparable);
 
     is_compat_240 = gtk_check_version(2, 4, 0) ? FALSE : TRUE;
 
     id_pixbuf = rb_intern("pixbuf");
 
-    rb_define_method(cTextIter, "buffer", get_buffer, 0);
-    rb_define_method(cTextIter, "offset", get_offset, 0);
-    rb_define_method(cTextIter, "line", get_line, 0);
-    rb_define_method(cTextIter, "line_offset", get_line_offset, 0);
-    rb_define_method(cTextIter, "line_index", get_line_index, 0);
-    rb_define_method(cTextIter, "visible_line_offset", get_visible_line_offset, 0);
-    rb_define_method(cTextIter, "visible_line_index", get_visible_line_index, 0);
-    rb_define_method(cTextIter, "char", get_char, 0);
+    RG_DEF_METHOD(buffer, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "offset", get_offset, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "line", get_line, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "line_offset", get_line_offset, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "line_index", get_line_index, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "visible_line_offset", get_visible_line_offset, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "visible_line_index", get_visible_line_index, 0);
+    RG_DEF_METHOD(char, 0);
 
-    rb_define_method(cTextIter, "get_slice", get_slice, 1);
-    rb_define_method(cTextIter, "get_text", get_text, 1);
-    rb_define_method(cTextIter, "get_visible_slice", get_visible_slice, 1);
-    rb_define_method(cTextIter, "get_visible_text", get_visible_text, 1);
+    RG_DEF_METHOD(get_slice, 1);
+    RG_DEF_METHOD(get_text, 1);
+    RG_DEF_METHOD(get_visible_slice, 1);
+    RG_DEF_METHOD(get_visible_text, 1);
 
-    rb_define_method(cTextIter, "pixbuf", get_pixbuf, 0);
-    rb_define_method(cTextIter, "marks", get_marks, 0);
-    rb_define_method(cTextIter, "child_anchor", get_child_anchor, 0);
+    RG_DEF_METHOD(pixbuf, 0);
+    RG_DEF_METHOD(marks, 0);
+    RG_DEF_METHOD(child_anchor, 0);
 
-    rb_define_method(cTextIter, "toggled_tags", get_toggled_tags, 1);
-    rb_define_method(cTextIter, "begins_tag?", begins_tag, 1);
-    rb_define_method(cTextIter, "ends_tag?", ends_tag, 1);
-    rb_define_method(cTextIter, "toggles_tag?", toggles_tag, 1);
-    rb_define_method(cTextIter, "has_tag?", has_tag, 1);
-    rb_define_method(cTextIter, "tags", get_tags, 0);
+    RG_DEF_METHOD(toggled_tags, 1);
+    RG_DEF_METHOD_P(begins_tag, 1);
+    RG_DEF_METHOD_P(ends_tag, 1);
+    RG_DEF_METHOD_P(toggles_tag, 1);
+    RG_DEF_METHOD_P(has_tag, 1);
+    RG_DEF_METHOD(tags, 0);
 
-    rb_define_method(cTextIter, "editable?", editable, 1);
-    rb_define_method(cTextIter, "can_insert?", can_insert, 1);
+    RG_DEF_METHOD_P(editable, 1);
+    RG_DEF_METHOD_P(can_insert, 1);
 
-    rb_define_method(cTextIter, "starts_word?", starts_word, 0);
-    rb_define_method(cTextIter, "ends_word?", ends_word, 0);
-    rb_define_method(cTextIter, "inside_word?", inside_word, 0);
-    rb_define_method(cTextIter, "starts_sentence?", starts_sentence, 0);
-    rb_define_method(cTextIter, "ends_sentence?", ends_sentence, 0);
-    rb_define_method(cTextIter, "starts_line?", starts_line, 0);
-    rb_define_method(cTextIter, "ends_line?", ends_line, 0);
-    rb_define_method(cTextIter, "cursor_position?", is_cursor_position, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "starts_word?", starts_word, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "ends_word?", ends_word, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "inside_word?", inside_word, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "starts_sentence?", starts_sentence, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "ends_sentence?", ends_sentence, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "starts_line?", starts_line, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "ends_line?", ends_line, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "cursor_position?", is_cursor_position, 0);
 
-    rb_define_method(cTextIter, "chars_in_line", get_chars_in_line, 0);
-    rb_define_method(cTextIter, "bytes_in_line", get_bytes_in_line, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "chars_in_line", get_chars_in_line, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "bytes_in_line", get_bytes_in_line, 0);
 
-    rb_define_method(cTextIter, "attributes", get_attributes, 0);
+    RG_DEF_METHOD(attributes, 0);
 
-    rb_define_method(cTextIter, "language", get_language, 0);
-    rb_define_method(cTextIter, "end?", is_end, 0);
-    rb_define_method(cTextIter, "start?", is_start, 0);
+    RG_DEF_METHOD(language, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "end?", is_end, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "start?", is_start, 0);
 
-    rb_define_method(cTextIter, "forward_char", forward_char, 0);
-    rb_define_method(cTextIter, "backward_char", backward_char, 0);
-    rb_define_method(cTextIter, "forward_chars", forward_chars, 1);
-    rb_define_method(cTextIter, "backward_chars", backward_chars, 1);
-    rb_define_method(cTextIter, "forward_line", forward_line, 0);
-    rb_define_method(cTextIter, "backward_line", backward_line, 0);
-    rb_define_method(cTextIter, "forward_lines", forward_lines, 1);
-    rb_define_method(cTextIter, "backward_lines", backward_lines, 1);
-    rb_define_method(cTextIter, "forward_word_end", forward_word_end, 0);
-    rb_define_method(cTextIter, "backward_word_start", backward_word_start, 0);
-    rb_define_method(cTextIter, "forward_word_ends", forward_word_ends, 1);
-    rb_define_method(cTextIter, "backward_word_starts", backward_word_starts, 1);
-    rb_define_method(cTextIter, "forward_sentence_end", forward_sentence_end, 0);
-    rb_define_method(cTextIter, "backward_sentence_start", backward_sentence_start, 0);
-    rb_define_method(cTextIter, "forward_sentence_ends", forward_sentence_ends, 1);
-    rb_define_method(cTextIter, "backward_sentence_starts", backward_sentence_starts, 1);
+    rb_define_method(RG_TARGET_NAMESPACE, "forward_char", forward_char, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "backward_char", backward_char, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "forward_chars", forward_chars, 1);
+    rb_define_method(RG_TARGET_NAMESPACE, "backward_chars", backward_chars, 1);
+    rb_define_method(RG_TARGET_NAMESPACE, "forward_line", forward_line, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "backward_line", backward_line, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "forward_lines", forward_lines, 1);
+    rb_define_method(RG_TARGET_NAMESPACE, "backward_lines", backward_lines, 1);
+    rb_define_method(RG_TARGET_NAMESPACE, "forward_word_end", forward_word_end, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "backward_word_start", backward_word_start, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "forward_word_ends", forward_word_ends, 1);
+    rb_define_method(RG_TARGET_NAMESPACE, "backward_word_starts", backward_word_starts, 1);
+    rb_define_method(RG_TARGET_NAMESPACE, "forward_sentence_end", forward_sentence_end, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "backward_sentence_start", backward_sentence_start, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "forward_sentence_ends", forward_sentence_ends, 1);
+    rb_define_method(RG_TARGET_NAMESPACE, "backward_sentence_starts", backward_sentence_starts, 1);
 
 #if GTK_CHECK_VERSION(2,4,0)
-    rb_define_method(cTextIter, "forward_visible_word_ends", forward_visible_word_ends, 1);
-    rb_define_method(cTextIter, "backward_visible_word_starts", backward_visible_word_starts, 1);
-    rb_define_method(cTextIter, "forward_visible_word_end", forward_visible_word_end, 0);
-    rb_define_method(cTextIter, "backword_visible_word_start", backward_visible_word_start, 0);
-    rb_define_method(cTextIter, "forward_visible_cursor_position", forward_visible_cursor_position, 0);
-    rb_define_method(cTextIter, "backward_visible_cursor_position", backward_visible_cursor_position, 0);
-    rb_define_method(cTextIter, "forward_visible_cursor_positions", forward_visible_cursor_positions, 1);
-    rb_define_method(cTextIter, "backward_visible_cursor_positions", backward_visible_cursor_positions, 1); 
+    rb_define_method(RG_TARGET_NAMESPACE, "forward_visible_word_ends", forward_visible_word_ends, 1);
+    rb_define_method(RG_TARGET_NAMESPACE, "backward_visible_word_starts", backward_visible_word_starts, 1);
+    rb_define_method(RG_TARGET_NAMESPACE, "forward_visible_word_end", forward_visible_word_end, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "backword_visible_word_start", backward_visible_word_start, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "forward_visible_cursor_position", forward_visible_cursor_position, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "backward_visible_cursor_position", backward_visible_cursor_position, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "forward_visible_cursor_positions", forward_visible_cursor_positions, 1);
+    rb_define_method(RG_TARGET_NAMESPACE, "backward_visible_cursor_positions", backward_visible_cursor_positions, 1); 
 #endif
 #if GTK_CHECK_VERSION(2,8,0)
-    rb_define_method(cTextIter, "forward_visible_line", forward_visible_line, 0); 
-    rb_define_method(cTextIter, "backward_visible_line", backward_visible_line, 0); 
-    rb_define_method(cTextIter, "forward_visible_lines", forward_visible_lines, 1); 
-    rb_define_method(cTextIter, "backward_visible_lines", backward_visible_lines, 1); 
+    rb_define_method(RG_TARGET_NAMESPACE, "forward_visible_line", forward_visible_line, 0); 
+    rb_define_method(RG_TARGET_NAMESPACE, "backward_visible_line", backward_visible_line, 0); 
+    rb_define_method(RG_TARGET_NAMESPACE, "forward_visible_lines", forward_visible_lines, 1); 
+    rb_define_method(RG_TARGET_NAMESPACE, "backward_visible_lines", backward_visible_lines, 1); 
 #endif
-    rb_define_method(cTextIter, "forward_cursor_position", forward_cursor_position, 0);
-    rb_define_method(cTextIter, "backward_cursor_position", backward_cursor_position, 0);
-    rb_define_method(cTextIter, "forward_cursor_positions", forward_cursor_positions, 1);
-    rb_define_method(cTextIter, "backward_cursor_positions", backward_cursor_positions, 1);
-    rb_define_method(cTextIter, "forward_to_end", forward_to_end, 0);
-    rb_define_method(cTextIter, "forward_to_line_end", forward_to_line_end, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "forward_cursor_position", forward_cursor_position, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "backward_cursor_position", backward_cursor_position, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "forward_cursor_positions", forward_cursor_positions, 1);
+    rb_define_method(RG_TARGET_NAMESPACE, "backward_cursor_positions", backward_cursor_positions, 1);
+    RG_DEF_METHOD(forward_to_end, 0);
+    rb_define_method(RG_TARGET_NAMESPACE, "forward_to_line_end", forward_to_line_end, 0);
 
+    rb_define_method(RG_TARGET_NAMESPACE, "set_offset", set_offset, 1);
+    rb_define_method(RG_TARGET_NAMESPACE, "set_line", set_line, 1);
+    rb_define_method(RG_TARGET_NAMESPACE, "set_line_offset", set_line_offset, 1);
+    rb_define_method(RG_TARGET_NAMESPACE, "set_line_index", set_line_index, 1);
 
-    rb_define_method(cTextIter, "set_offset", set_offset, 1);
-    rb_define_method(cTextIter, "set_line", set_line, 1);
-    rb_define_method(cTextIter, "set_line_offset", set_line_offset, 1);
-    rb_define_method(cTextIter, "set_line_index", set_line_index, 1);
+    rb_define_method(RG_TARGET_NAMESPACE, "set_visible_line_offset", set_visible_line_offset, 1);
+    rb_define_method(RG_TARGET_NAMESPACE, "set_visible_line_index", set_visible_line_index, 1);
 
-    rb_define_method(cTextIter, "set_visible_line_offset", set_visible_line_offset, 1);
-    rb_define_method(cTextIter, "set_visible_line_index", set_visible_line_index, 1);
+    RG_DEF_METHOD(forward_to_tag_toggle, -1);
+    RG_DEF_METHOD(backward_to_tag_toggle, -1);
+    RG_DEF_METHOD(forward_find_char, -1);
+    RG_DEF_METHOD(backward_find_char, -1);
+    RG_DEF_METHOD(forward_search, -1);
+    RG_DEF_METHOD(backward_search, -1);
 
-    rb_define_method(cTextIter, "forward_to_tag_toggle", forward_to_tag_toggle, -1);
-    rb_define_method(cTextIter, "backward_to_tag_toggle", backward_to_tag_toggle, -1);
-    rb_define_method(cTextIter, "forward_find_char", forward_find_char, -1);
-    rb_define_method(cTextIter, "backward_find_char", backward_find_char, -1);
-    rb_define_method(cTextIter, "forward_search", forward_search, -1);
-    rb_define_method(cTextIter, "backward_search", backward_search, -1);
+    RG_DEF_METHOD_OPERATOR("==", equal, 1);
+    RG_DEF_METHOD_OPERATOR("<=>", compare, 1);
 
-    rb_define_method(cTextIter, "==", equal, 1);
-    rb_define_method(cTextIter, "<=>", compare, 1);
-
-    G_DEF_SETTERS(cTextIter);
+    G_DEF_SETTERS(RG_TARGET_NAMESPACE);
 
     /* GtkTextSearchFlags */
-    G_DEF_CLASS(GTK_TYPE_TEXT_SEARCH_FLAGS, "SearchFlags", cTextIter);
-    G_DEF_CONSTANTS(cTextIter, GTK_TYPE_TEXT_SEARCH_FLAGS, "GTK_TEXT_");
+    G_DEF_CLASS(GTK_TYPE_TEXT_SEARCH_FLAGS, "SearchFlags", RG_TARGET_NAMESPACE);
+    G_DEF_CONSTANTS(RG_TARGET_NAMESPACE, GTK_TYPE_TEXT_SEARCH_FLAGS, "GTK_TEXT_");
 }
