@@ -1,32 +1,43 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
-/************************************************
-
-  rbgtktoolbar.c -
-
-  $Author: ggc $
-  $Date: 2007/07/13 16:07:32 $
-
-  Copyright (C) 2002-2004 Ruby-GNOME2 Project Team
-  Copyright (C) 1998-2000 Yukihiro Matsumoto,
-                          Daisuke Kanda,
-                          Hiroshi Igarashi
-************************************************/
+/*
+ *  Copyright (C) 2011  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2002-2004 Ruby-GNOME2 Project Team
+ *  Copyright (C) 1998-2000 Yukihiro Matsumoto,
+ *                          Daisuke Kanda,
+ *                          Hiroshi Igarashi
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
+ */
 
 #include "global.h"
 
+#define RG_TARGET_NAMESPACE cToolbar
 #define _SELF(self) (GTK_TOOLBAR(RVAL2GOBJ(self)))
 #define N_RVAL2CSTR(text) (NIL_P(text) ? NULL : RVAL2CSTR(text))
 #define N_RVAL2WIDGET(w)  (NIL_P(w) ? NULL : GTK_WIDGET(RVAL2GOBJ(w)))
 
 static VALUE
-tbar_initialize(VALUE self)
+rg_initialize(VALUE self)
 {
     RBGTK_INITIALIZE(self, gtk_toolbar_new());
     return Qnil;
 }
 
 static VALUE
-tbar_append(int argc, VALUE *argv, VALUE self)
+rg_append(int argc, VALUE *argv, VALUE self)
 {
     GtkWidget* ret = NULL;
     VALUE type = Qnil;
@@ -62,7 +73,7 @@ tbar_append(int argc, VALUE *argv, VALUE self)
         rb_scan_args(argc, argv, "13", &stock_id, &ttext, &ptext, &func);
         if (NIL_P(func)) func = rb_block_proc();
         G_RELATIVE(self, func);
-        
+
         ret = gtk_toolbar_insert_stock(_SELF(self), rb_id2name(SYM2ID(stock_id)),
                                        N_RVAL2CSTR(ttext), N_RVAL2CSTR(ptext),
                                        GTK_SIGNAL_FUNC(exec_callback),
@@ -78,7 +89,7 @@ tbar_append(int argc, VALUE *argv, VALUE self)
 }
 
 static VALUE
-tbar_prepend(int argc, VALUE *argv, VALUE self)
+rg_prepend(int argc, VALUE *argv, VALUE self)
 {
     GtkWidget* ret = NULL;
     VALUE type = Qnil;
@@ -113,7 +124,7 @@ tbar_prepend(int argc, VALUE *argv, VALUE self)
         rb_scan_args(argc, argv, "13", &stock_id, &ttext, &ptext, &func);
         if (NIL_P(func)) func = rb_block_proc();
         G_RELATIVE(self, func);
-        
+
         ret = gtk_toolbar_insert_stock(_SELF(self), rb_id2name(SYM2ID(stock_id)),
                                        N_RVAL2CSTR(ttext), N_RVAL2CSTR(ptext),
                                        GTK_SIGNAL_FUNC(exec_callback),
@@ -129,7 +140,7 @@ tbar_prepend(int argc, VALUE *argv, VALUE self)
 }
 
 static VALUE
-tbar_insert(int argc, VALUE *argv, VALUE self)
+rg_insert(int argc, VALUE *argv, VALUE self)
 {
     GtkWidget* ret = NULL;
     VALUE type = Qnil;
@@ -166,7 +177,7 @@ tbar_insert(int argc, VALUE *argv, VALUE self)
         rb_scan_args(argc, argv, "14", &pos, &stock_id, &ttext, &ptext, &func);
         if (NIL_P(func)) func = rb_block_proc();
         G_RELATIVE(self, func);
-        
+
         ret = gtk_toolbar_insert_stock(_SELF(self), rb_id2name(SYM2ID(stock_id)),
                                        N_RVAL2CSTR(ttext), N_RVAL2CSTR(ptext),
                                        GTK_SIGNAL_FUNC(exec_callback),
@@ -191,134 +202,120 @@ tbar_insert(int argc, VALUE *argv, VALUE self)
 
 #if GTK_CHECK_VERSION(2,4,0)
 static VALUE
-tbar_get_item_index(VALUE self, VALUE item)
+rg_item_index(VALUE self, VALUE item)
 {
     return INT2NUM(gtk_toolbar_get_item_index(_SELF(self), GTK_TOOL_ITEM(RVAL2GOBJ(item))));
 }
 
 static VALUE
-tbar_get_n_items(VALUE self)
+rg_n_items(VALUE self)
 {
     return INT2NUM(gtk_toolbar_get_n_items(_SELF(self)));
 }
 
 static VALUE
-tbar_get_nth_item(VALUE self, VALUE n)
+rg_nth_item(VALUE self, VALUE n)
 {
     return GOBJ2RVAL(gtk_toolbar_get_nth_item(_SELF(self), NUM2INT(n)));
 }
 
 static VALUE
-tbar_get_drop_index(VALUE self, VALUE x, VALUE y)
+rg_drop_index(VALUE self, VALUE x, VALUE y)
 {
     return INT2NUM(gtk_toolbar_get_drop_index(_SELF(self), NUM2INT(x), NUM2INT(y)));
 }
 
 static VALUE
-tbar_set_drop_highlight_item(VALUE self, VALUE item, VALUE index)
+rg_set_drop_highlight_item(VALUE self, VALUE item, VALUE index)
 {
     gtk_toolbar_set_drop_highlight_item(_SELF(self), 
                                         GTK_TOOL_ITEM(RVAL2GOBJ(item)), 
                                         NUM2INT(index));
     return self;
 }
-/* Defined as Properties
-void        gtk_toolbar_set_show_arrow      (GtkToolbar *toolbar,
-                                             gboolean show_arrow);
-gboolean    gtk_toolbar_get_show_arrow      (GtkToolbar *toolbar);
-*/
 
 static VALUE
-tbar_get_relief_style(VALUE self)
+rg_relief_style(VALUE self)
 {
     return GENUM2RVAL(gtk_toolbar_get_relief_style(_SELF(self)), GTK_TYPE_RELIEF_STYLE);
 }
 #endif
 
 static VALUE
-tbar_append_space(VALUE self)
+rg_append_space(VALUE self)
 {
     gtk_toolbar_append_space(_SELF(self));
     return self;
 }
 
 static VALUE
-tbar_prepend_space(VALUE self)
+rg_prepend_space(VALUE self)
 {
     gtk_toolbar_prepend_space(_SELF(self));
     return self;
 }
 
 static VALUE
-tbar_insert_space(VALUE self, VALUE pos)
+rg_insert_space(VALUE self, VALUE pos)
 {
     gtk_toolbar_insert_space(_SELF(self), NUM2INT(pos));
     return self;
 }
 
-/* Defined as Properties:
-void                gtk_toolbar_set_tooltips            (GtkToolbar *toolbar,
-                                                         gboolean enable);
-void                gtk_toolbar_set_icon_size           (GtkToolbar *toolbar,
-                                                         GtkIconSize icon_size);
-GtkIconSize         gtk_toolbar_get_icon_size           (GtkToolbar *toolbar);
-gboolean            gtk_toolbar_get_tooltips            (GtkToolbar *toolbar);
-*/
-
 static VALUE
-tbar_remove_space(VALUE self, VALUE position)
+rg_remove_space(VALUE self, VALUE position)
 {
     gtk_toolbar_remove_space(_SELF(self), NUM2INT(position));
     return self;
 }
 
 static VALUE
-tbar_unset_icon_size(VALUE self)
+rg_unset_icon_size(VALUE self)
 {
     gtk_toolbar_unset_icon_size(_SELF(self));
     return self;
 }
 
 static VALUE
-tbar_unset_style(VALUE self)
+rg_unset_style(VALUE self)
 {
     gtk_toolbar_unset_style(_SELF(self));
     return self;
 }
 
 void 
-Init_gtk_toolbar()
+Init_gtk_toolbar(VALUE mGtk)
 {
-    VALUE gToolbar = G_DEF_CLASS(GTK_TYPE_TOOLBAR, "Toolbar", mGtk);
+    VALUE RG_TARGET_NAMESPACE = G_DEF_CLASS(GTK_TYPE_TOOLBAR, "Toolbar", mGtk);
 
-    rb_define_method(gToolbar, "initialize", tbar_initialize, 0);
+    RG_DEF_METHOD(initialize, 0);
 #if GTK_CHECK_VERSION(2,4,0)
-    rb_define_method(gToolbar, "item_index", tbar_get_item_index, 1);
-    rb_define_method(gToolbar, "n_items", tbar_get_n_items, 0);
-    rb_define_method(gToolbar, "nth_item", tbar_get_nth_item, 1);
-    rb_define_method(gToolbar, "drop_index", tbar_get_drop_index, 2);
-    rb_define_method(gToolbar, "set_drop_highlight_item", tbar_set_drop_highlight_item, 2);
-    rb_define_method(gToolbar, "relief_style", tbar_get_relief_style, 0);
+    RG_DEF_METHOD(item_index, 1);
+    RG_DEF_METHOD(n_items, 0);
+    RG_DEF_METHOD(nth_item, 1);
+    RG_DEF_METHOD(drop_index, 2);
+    RG_DEF_METHOD(set_drop_highlight_item, 2);
+    RG_DEF_METHOD(relief_style, 0);
 #endif
-    rb_define_method(gToolbar, "append", tbar_append, -1);
-    rb_define_method(gToolbar, "prepend", tbar_prepend, -1);
-    rb_define_method(gToolbar, "insert", tbar_insert, -1);
-    rb_define_method(gToolbar, "append_space", tbar_append_space, 0);
-    rb_define_method(gToolbar, "prepend_space", tbar_prepend_space, 0);
-    rb_define_method(gToolbar, "insert_space", tbar_insert_space, 1);
-    rb_define_method(gToolbar, "remove_space", tbar_remove_space, 1);
-    rb_define_method(gToolbar, "unset_icon_size", tbar_unset_icon_size, 0);
-    rb_define_method(gToolbar, "unset_style", tbar_unset_style, 0);
+    RG_DEF_METHOD(append, -1);
+    RG_DEF_METHOD(prepend, -1);
+    RG_DEF_METHOD(insert, -1);
+    RG_DEF_METHOD(append_space, 0);
+    RG_DEF_METHOD(prepend_space, 0);
+    RG_DEF_METHOD(insert_space, 1);
+    RG_DEF_METHOD(remove_space, 1);
+    RG_DEF_METHOD(unset_icon_size, 0);
+    RG_DEF_METHOD(unset_style, 0);
 
     /* GtkToolbarChildType */
-    G_DEF_CLASS(GTK_TYPE_TOOLBAR_CHILD_TYPE, "ChildType", gToolbar);
-    G_DEF_CONSTANTS(gToolbar, GTK_TYPE_TOOLBAR_CHILD_TYPE, "GTK_TOOLBAR_");
+    G_DEF_CLASS(GTK_TYPE_TOOLBAR_CHILD_TYPE, "ChildType", RG_TARGET_NAMESPACE);
+    G_DEF_CONSTANTS(RG_TARGET_NAMESPACE, GTK_TYPE_TOOLBAR_CHILD_TYPE, "GTK_TOOLBAR_");
 
     /* GtkToolbarSpaceStyle */
-    G_DEF_CLASS(GTK_TYPE_TOOLBAR_SPACE_STYLE, "SpaceStyle", gToolbar);
-    G_DEF_CONSTANTS(gToolbar, GTK_TYPE_TOOLBAR_SPACE_STYLE, "GTK_TOOLBAR_");
+    G_DEF_CLASS(GTK_TYPE_TOOLBAR_SPACE_STYLE, "SpaceStyle", RG_TARGET_NAMESPACE);
+    G_DEF_CONSTANTS(RG_TARGET_NAMESPACE, GTK_TYPE_TOOLBAR_SPACE_STYLE, "GTK_TOOLBAR_");
 
     /* GtkToolbarStyle(from Standard Constants) */
-    G_DEF_CLASS(GTK_TYPE_TOOLBAR_STYLE, "Style", gToolbar);
-    G_DEF_CONSTANTS(gToolbar, GTK_TYPE_TOOLBAR_STYLE, "GTK_TOOLBAR_");
+    G_DEF_CLASS(GTK_TYPE_TOOLBAR_STYLE, "Style", RG_TARGET_NAMESPACE);
+    G_DEF_CONSTANTS(RG_TARGET_NAMESPACE, GTK_TYPE_TOOLBAR_STYLE, "GTK_TOOLBAR_");
 }
