@@ -1,16 +1,27 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
-/************************************************
-
-  rbgtktreeview.c -
-
-  $Author: ggc $
-  $Date: 2007/07/13 16:07:32 $
-
-  Copyright (C) 2002-2005 Masao Mutoh
-************************************************/
+/*
+ *  Copyright (C) 2011  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2002-2005 Masao Mutoh
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
+ */
 
 #include "global.h"
 
+#define RG_TARGET_NAMESPACE cTreeView
 #define _SELF(s) (GTK_TREE_VIEW(RVAL2GOBJ(s)))
 #define TREEVIEW_COL(c) (GTK_TREE_VIEW_COLUMN(RVAL2GOBJ(c)))
 #define RVAL2CELLRENDERER(c) (GTK_CELL_RENDERER(RVAL2GOBJ(c)))
@@ -19,7 +30,7 @@ static ID id_model;
 static ID id_selection;
 
 static VALUE
-treeview_initialize(int argc, VALUE *argv, VALUE self)
+rg_initialize(int argc, VALUE *argv, VALUE self)
 {
     VALUE model;
     GtkWidget *widget;
@@ -37,7 +48,7 @@ treeview_initialize(int argc, VALUE *argv, VALUE self)
 }
 
 static VALUE
-treeview_get_selection(VALUE self)
+rg_selection(VALUE self)
 {
     VALUE ret = GOBJ2RVAL(gtk_tree_view_get_selection(_SELF(self)));
     G_CHILD_SET(self, id_selection, ret);
@@ -45,14 +56,14 @@ treeview_get_selection(VALUE self)
 }
 
 static VALUE
-treeview_columns_autosize(VALUE self)
+rg_columns_autosize(VALUE self)
 {
     gtk_tree_view_columns_autosize(_SELF(self));
     return self;
 }
 
 static VALUE
-treeview_append_column(VALUE self, VALUE column)
+rg_append_column(VALUE self, VALUE column)
 {
     G_CHILD_ADD(self, column);
     return INT2NUM(gtk_tree_view_append_column(_SELF(self), 
@@ -60,7 +71,7 @@ treeview_append_column(VALUE self, VALUE column)
 }
 
 static VALUE
-treeview_remove_column(VALUE self, VALUE column)
+rg_remove_column(VALUE self, VALUE column)
 {
     G_CHILD_REMOVE(self, column);
     return INT2NUM(gtk_tree_view_remove_column(_SELF(self), 
@@ -77,7 +88,7 @@ cell_data_func(GtkTreeViewColumn *column, GtkCellRenderer *cell, GtkTreeModel *m
 }
 
 static VALUE
-treeview_insert_column(int argc, VALUE *argv, VALUE self)
+rg_insert_column(int argc, VALUE *argv, VALUE self)
 {
     VALUE args[4];
 
@@ -112,17 +123,19 @@ treeview_insert_column(int argc, VALUE *argv, VALUE self)
         const gchar *name;
         VALUE ary;
         GtkCellRenderer* renderer = RVAL2CELLRENDERER(args[2]);
-        
+
         GtkTreeViewColumn* column = gtk_tree_view_column_new();
 
         Check_Type(args[3], T_HASH);
 
+        /* TODO: Should this really be done before we know that everything
+         * below worked without error? */
         G_CHILD_ADD(self, args[2]);
         G_CHILD_ADD(self, args[3]);
 
         gtk_tree_view_column_set_title(column, RVAL2CSTR(args[1]));
         gtk_tree_view_column_pack_start(column, renderer, TRUE);
-        
+
         ret = gtk_tree_view_insert_column(_SELF(self), column, NUM2INT(args[0]));
         ary = rb_funcall(args[3], rb_intern("to_a"), 0);
         for (i = 0; i < RARRAY_LEN(ary); i++) {
@@ -139,26 +152,26 @@ treeview_insert_column(int argc, VALUE *argv, VALUE self)
         }
         return INT2NUM(ret);
     } else {
-	rb_raise(rb_eArgError, "Wrong number of arguments: %d", argc);
+        rb_raise(rb_eArgError, "Wrong number of arguments: %d", argc);
     }
 
     return Qnil;
 }
 
 static VALUE
-treeview_get_column(VALUE self, VALUE num)
+rg_get_column(VALUE self, VALUE num)
 {
     return GOBJ2RVAL(gtk_tree_view_get_column(_SELF(self), NUM2INT(num)));
 }
 
 static VALUE
-treeview_get_columns(VALUE self)
+rg_columns(VALUE self)
 {
     return GLIST2ARYF(gtk_tree_view_get_columns(_SELF(self)));
 }
 
 static VALUE
-treeview_move_column_after(VALUE self, VALUE column, VALUE base_column)
+rg_move_column_after(VALUE self, VALUE column, VALUE base_column)
 {
     gtk_tree_view_move_column_after(_SELF(self), TREEVIEW_COL(column),
                                     NIL_P(base_column) ? NULL : TREEVIEW_COL(base_column));
@@ -174,7 +187,7 @@ column_drop_func(GtkTreeView *treeview, GtkTreeViewColumn *column, GtkTreeViewCo
 }
 
 static VALUE
-treeview_set_column_drag_function(VALUE self)
+rg_set_column_drag_function(VALUE self)
 {
     VALUE func = rb_block_proc();
     G_RELATIVE(self, func);
@@ -185,14 +198,14 @@ treeview_set_column_drag_function(VALUE self)
 }
 
 static VALUE
-treeview_scroll_to_point(VALUE self, VALUE x, VALUE y)
+rg_scroll_to_point(VALUE self, VALUE x, VALUE y)
 {
     gtk_tree_view_scroll_to_point(_SELF(self), NUM2INT(x), NUM2INT(y));
     return self;
 }
 
 static VALUE
-treeview_scroll_to_cell(VALUE self, VALUE path, VALUE column, VALUE use_align, VALUE row_align, VALUE col_align)
+rg_scroll_to_cell(VALUE self, VALUE path, VALUE column, VALUE use_align, VALUE row_align, VALUE col_align)
 {
     gtk_tree_view_scroll_to_cell(_SELF(self),
                                  NIL_P(path) ? NULL : RVAL2GTKTREEPATH(path),
@@ -203,7 +216,7 @@ treeview_scroll_to_cell(VALUE self, VALUE path, VALUE column, VALUE use_align, V
 }
 
 static VALUE
-treeview_set_cursor(VALUE self, VALUE path, VALUE focus_column, VALUE start_editing)
+rg_set_cursor(VALUE self, VALUE path, VALUE focus_column, VALUE start_editing)
 {
     gtk_tree_view_set_cursor(_SELF(self), RVAL2GTKTREEPATH(path),
                              NIL_P(focus_column) ? NULL : TREEVIEW_COL(focus_column), 
@@ -212,7 +225,7 @@ treeview_set_cursor(VALUE self, VALUE path, VALUE focus_column, VALUE start_edit
 }
 
 static VALUE
-treeview_get_cursor(VALUE self)
+rg_cursor(VALUE self)
 {
     GtkTreePath* path;
     GtkTreeViewColumn* focus_column;
@@ -222,28 +235,22 @@ treeview_get_cursor(VALUE self)
                        GOBJ2RVAL(focus_column));
 }
 
-/* Defined as Signals
-void                gtk_tree_view_row_activated         (GtkTreeView *tree_view,
-                                                         GtkTreePath *path,
-                                                         GtkTreeViewColumn *column);
-*/
-
 static VALUE
-treeview_expand_all(VALUE self)
+rg_expand_all(VALUE self)
 {
     gtk_tree_view_expand_all(_SELF(self));
     return self;
 }
 
 static VALUE
-treeview_collapse_all(VALUE self)
+rg_collapse_all(VALUE self)
 {
     gtk_tree_view_collapse_all(_SELF(self));
     return self;
 }
 
 static VALUE
-treeview_expand_row(VALUE self, VALUE path, VALUE open_all)
+rg_expand_row(VALUE self, VALUE path, VALUE open_all)
 {
     return CBOOL2RVAL(gtk_tree_view_expand_row(_SELF(self), 
                                                RVAL2GTKTREEPATH(path),
@@ -252,7 +259,7 @@ treeview_expand_row(VALUE self, VALUE path, VALUE open_all)
 
 #if GTK_CHECK_VERSION(2,2,0)
 static VALUE
-treeview_expand_to_path(VALUE self, VALUE path)
+rg_expand_to_path(VALUE self, VALUE path)
 {
     gtk_tree_view_expand_to_path(_SELF(self), RVAL2GTKTREEPATH(path));
     return self;
@@ -260,7 +267,7 @@ treeview_expand_to_path(VALUE self, VALUE path)
 #endif
 
 static VALUE
-treeview_collapse_row(VALUE self, VALUE path)
+rg_collapse_row(VALUE self, VALUE path)
 {
     return CBOOL2RVAL(gtk_tree_view_collapse_row(_SELF(self), 
                                                  RVAL2GTKTREEPATH(path)));
@@ -274,7 +281,7 @@ mapping_func(GtkTreeView *treeview, GtkTreePath *path, gpointer func)
 }
 
 static VALUE
-treeview_map_expanded_rows(VALUE self)
+rg_map_expanded_rows(VALUE self)
 {
     VALUE func = rb_block_proc();
     G_RELATIVE(self, func);
@@ -285,14 +292,14 @@ treeview_map_expanded_rows(VALUE self)
 }
 
 static VALUE
-treeview_row_expanded(VALUE self, VALUE path)
+rg_row_expanded_p(VALUE self, VALUE path)
 {
     return CBOOL2RVAL(gtk_tree_view_row_expanded(_SELF(self), 
                                                  RVAL2GTKTREEPATH(path)));
 }
 
 static VALUE
-treeview_get_path_at_pos(VALUE self, VALUE x, VALUE y)
+rg_get_path_at_pos(VALUE self, VALUE x, VALUE y)
 {
     GtkTreePath* path;
     GtkTreeViewColumn* column;
@@ -309,7 +316,7 @@ treeview_get_path_at_pos(VALUE self, VALUE x, VALUE y)
 }
 
 static VALUE
-treeview_get_cell_area(VALUE self, VALUE path, VALUE column)
+rg_get_cell_area(VALUE self, VALUE path, VALUE column)
 {
     GdkRectangle rect;
     gtk_tree_view_get_cell_area(_SELF(self), 
@@ -320,7 +327,7 @@ treeview_get_cell_area(VALUE self, VALUE path, VALUE column)
 }
 
 static VALUE
-treeview_get_background_area(VALUE self, VALUE path, VALUE column)
+rg_get_background_area(VALUE self, VALUE path, VALUE column)
 {
     GdkRectangle rect;
     gtk_tree_view_get_background_area(_SELF(self), 
@@ -331,7 +338,7 @@ treeview_get_background_area(VALUE self, VALUE path, VALUE column)
 }
 
 static VALUE
-treeview_get_visible_rect(VALUE self)
+rg_visible_rect(VALUE self)
 {
     GdkRectangle rect;
     gtk_tree_view_get_visible_rect(_SELF(self), &rect);
@@ -340,7 +347,7 @@ treeview_get_visible_rect(VALUE self)
 
 #if GTK_CHECK_VERSION(2,8,0)
 static VALUE
-treeview_get_visible_range(VALUE self)
+rg_visible_range(VALUE self)
 {
     GtkTreePath* start_path;
     GtkTreePath* end_path;
@@ -353,13 +360,13 @@ treeview_get_visible_range(VALUE self)
 #endif
 
 static VALUE
-treeview_get_bin_window(VALUE self)
+rg_bin_window(VALUE self)
 {
     return GOBJ2RVAL(gtk_tree_view_get_bin_window(_SELF(self)));
 }
 
 static VALUE
-treeview_widget_to_tree_coords(VALUE self, VALUE wx, VALUE wy)
+rg_widget_to_tree_coords(VALUE self, VALUE wx, VALUE wy)
 {
     gint tx, ty;
     gtk_tree_view_widget_to_tree_coords(_SELF(self), 
@@ -369,7 +376,7 @@ treeview_widget_to_tree_coords(VALUE self, VALUE wx, VALUE wy)
 }
 
 static VALUE
-treeview_tree_to_widget_coords(VALUE self, VALUE tx, VALUE ty)
+rg_tree_to_widget_coords(VALUE self, VALUE tx, VALUE ty)
 {
     gint wx, wy;
     gtk_tree_view_tree_to_widget_coords(_SELF(self),
@@ -380,7 +387,7 @@ treeview_tree_to_widget_coords(VALUE self, VALUE tx, VALUE ty)
 
 #if GTK_CHECK_VERSION(2,12,0)
 static VALUE
-treeview_convert_bin_window_to_tree_coords(VALUE self, VALUE bx, VALUE by)
+rg_convert_bin_window_to_tree_coords(VALUE self, VALUE bx, VALUE by)
 {
     gint tx, ty;
     gtk_tree_view_convert_bin_window_to_tree_coords(_SELF(self),
@@ -389,7 +396,7 @@ treeview_convert_bin_window_to_tree_coords(VALUE self, VALUE bx, VALUE by)
     return rb_ary_new3(2, INT2NUM(tx), INT2NUM(ty));
 }
 static VALUE
-treeview_convert_bin_window_to_widget_coords(VALUE self, VALUE bx, VALUE by)
+rg_convert_bin_window_to_widget_coords(VALUE self, VALUE bx, VALUE by)
 {
     gint wx, wy;
     gtk_tree_view_convert_bin_window_to_widget_coords(_SELF(self),
@@ -399,7 +406,7 @@ treeview_convert_bin_window_to_widget_coords(VALUE self, VALUE bx, VALUE by)
 }
 
 static VALUE
-treeview_convert_tree_to_bin_window_coords(VALUE self, VALUE tx, VALUE ty)
+rg_convert_tree_to_bin_window_coords(VALUE self, VALUE tx, VALUE ty)
 {
     gint bx, by;
     gtk_tree_view_convert_tree_to_bin_window_coords(_SELF(self),
@@ -408,7 +415,7 @@ treeview_convert_tree_to_bin_window_coords(VALUE self, VALUE tx, VALUE ty)
     return rb_ary_new3(2, INT2NUM(bx), INT2NUM(by));
 }
 static VALUE
-treeview_convert_tree_to_widget_coords(VALUE self, VALUE tx, VALUE ty)
+rg_convert_tree_to_widget_coords(VALUE self, VALUE tx, VALUE ty)
 {
     gint wx, wy;
     gtk_tree_view_convert_tree_to_widget_coords(_SELF(self),
@@ -418,7 +425,7 @@ treeview_convert_tree_to_widget_coords(VALUE self, VALUE tx, VALUE ty)
 }
 
 static VALUE
-treeview_convert_widget_to_bin_window_coords(VALUE self, VALUE wx, VALUE wy)
+rg_convert_widget_to_bin_window_coords(VALUE self, VALUE wx, VALUE wy)
 {
     gint bx, by;
     gtk_tree_view_convert_widget_to_bin_window_coords(_SELF(self),
@@ -427,7 +434,7 @@ treeview_convert_widget_to_bin_window_coords(VALUE self, VALUE wx, VALUE wy)
     return rb_ary_new3(2, INT2NUM(bx), INT2NUM(by));
 }
 static VALUE
-treeview_convert_widget_to_tree_coords(VALUE self, VALUE wx, VALUE wy)
+rg_convert_widget_to_tree_coords(VALUE self, VALUE wx, VALUE wy)
 {
     gint tx, ty;
     gtk_tree_view_convert_widget_to_tree_coords(_SELF(self),
@@ -438,47 +445,55 @@ treeview_convert_widget_to_tree_coords(VALUE self, VALUE wx, VALUE wy)
 #endif
 
 static VALUE
-treeview_enable_model_drag_dest(VALUE self, VALUE targets, VALUE actions)
+rg_enable_model_drag_dest(VALUE self, VALUE rbtargets, VALUE rbactions)
 {
-    const GtkTargetEntry* entries = rbgtk_get_target_entry(targets);
-    int num = RARRAY_LEN(targets);
+    GtkTreeView *view = _SELF(self);
+    GdkDragAction actions = RVAL2GFLAGS(rbactions, GDK_TYPE_DRAG_ACTION);
+    long n;
+    GtkTargetEntry *targets = RVAL2GTKTARGETENTRIES(rbtargets, &n);
+
+    gtk_tree_view_enable_model_drag_dest(view, targets, n, actions);
+
+    g_free(targets);
 
-    gtk_tree_view_enable_model_drag_dest(_SELF(self),  entries, 
-                                         num, RVAL2GFLAGS(actions, GDK_TYPE_DRAG_ACTION));
     return self;
 }
 
 static VALUE
-treeview_enable_model_drag_source(VALUE self, VALUE start_button_mask, VALUE targets, VALUE actions)
+rg_enable_model_drag_source(VALUE self, VALUE rbstart_button_mask, VALUE rbtargets, VALUE rbactions)
 {
-    GtkTargetEntry* entries = rbgtk_get_target_entry(targets);
-    if (entries){
-        gint num = RARRAY_LEN(targets);
-        
-        gtk_tree_view_enable_model_drag_source(_SELF(self), 
-                                               RVAL2GFLAGS(start_button_mask, GDK_TYPE_MODIFIER_TYPE), 
-                                               entries, num,
-                                               RVAL2GFLAGS(actions, GDK_TYPE_DRAG_ACTION));
-    }
+    GtkTreeView *view = _SELF(self);
+    GdkModifierType start_button_mask = RVAL2GFLAGS(rbstart_button_mask, GDK_TYPE_MODIFIER_TYPE);
+    GdkDragAction actions = RVAL2GFLAGS(rbactions, GDK_TYPE_DRAG_ACTION);
+    long n;
+    GtkTargetEntry *targets = RVAL2GTKTARGETENTRIES_ACCEPT_NIL(rbtargets, &n);
+
+    if (targets == NULL)
+        return self;
+
+    gtk_tree_view_enable_model_drag_source(view, start_button_mask, targets, n, actions);
+
+    g_free(targets);
+
     return self;
 }
 
 static VALUE
-treeview_unset_rows_drag_source(VALUE self)
+rg_unset_rows_drag_source(VALUE self)
 {
     gtk_tree_view_unset_rows_drag_source(_SELF(self));
     return self;
 }
 
 static VALUE
-treeview_unset_rows_drag_dest(VALUE self)
+rg_unset_rows_drag_dest(VALUE self)
 {
     gtk_tree_view_unset_rows_drag_dest(_SELF(self));
     return self;
 }
 
 static VALUE
-treeview_set_drag_dest_row(VALUE self, VALUE path, VALUE pos)
+rg_set_drag_dest_row(VALUE self, VALUE path, VALUE pos)
 {
     gtk_tree_view_set_drag_dest_row(_SELF(self), 
                                     NIL_P(path)?NULL:RVAL2GTKTREEPATH(path),
@@ -487,7 +502,7 @@ treeview_set_drag_dest_row(VALUE self, VALUE path, VALUE pos)
 }
 
 static VALUE
-treeview_get_drag_dest_row(VALUE self)
+rg_drag_dest_row(VALUE self)
 {
     GtkTreePath* path = NULL;
     GtkTreeViewDropPosition pos;
@@ -497,7 +512,7 @@ treeview_get_drag_dest_row(VALUE self)
 }
 
 static VALUE
-treeview_get_dest_row_at_pos(VALUE self, VALUE drag_x, VALUE drag_y)
+rg_get_dest_row_at_pos(VALUE self, VALUE drag_x, VALUE drag_y)
 {
     GtkTreePath* path;
     GtkTreeViewDropPosition pos;
@@ -511,7 +526,7 @@ treeview_get_dest_row_at_pos(VALUE self, VALUE drag_x, VALUE drag_y)
 }
 
 static VALUE
-treeview_create_row_drag_icon(VALUE self, VALUE path)
+rg_create_row_drag_icon(VALUE self, VALUE path)
 {
     return GOBJ2RVAL(gtk_tree_view_create_row_drag_icon(_SELF(self),
                                                         RVAL2GTKTREEPATH(path)));
@@ -533,7 +548,7 @@ search_equal_func(GtkTreeModel *model, gint column, const gchar *key, GtkTreeIte
 }
 
 static VALUE
-treeview_set_search_equal_func(VALUE self)
+rg_set_search_equal_func(VALUE self)
 {
     VALUE func = rb_block_proc();
     G_RELATIVE(self, func);
@@ -543,13 +558,11 @@ treeview_set_search_equal_func(VALUE self)
     return self;
 }
 
-
-
 /*
  * Optional Signals
  */
 static VALUE
-treeview_signal_func(guint num, const GValue *values)
+treeview_signal_func(G_GNUC_UNUSED guint num, const GValue *values)
 {
     GtkTreeView* view = g_value_get_object(&values[0]);
     GtkTreeIter* iter = g_value_get_boxed(&values[1]);
@@ -560,7 +573,7 @@ treeview_signal_func(guint num, const GValue *values)
 
 #if GTK_CHECK_VERSION(2,2,0)
 static VALUE
-treeview_set_cursor_on_cell(VALUE self, VALUE path, VALUE focus_column, VALUE focus_cell, VALUE start_editing)
+rg_set_cursor_on_cell(VALUE self, VALUE path, VALUE focus_column, VALUE focus_cell, VALUE start_editing)
 {
     gtk_tree_view_set_cursor_on_cell(_SELF(self), RVAL2GTKTREEPATH(path),
                                      NIL_P(focus_column) ? NULL : TREEVIEW_COL(focus_column), 
@@ -570,22 +583,6 @@ treeview_set_cursor_on_cell(VALUE self, VALUE path, VALUE focus_column, VALUE fo
 }
 #endif
 
-/* Defined as Property.
-gboolean    gtk_tree_view_get_fixed_height_mode
-                                            (GtkTreeView *tree_view);
-void        gtk_tree_view_set_fixed_height_mode
-                                            (GtkTreeView *tree_view,
-                                             gboolean enable);
-gboolean    gtk_tree_view_get_hover_selection
-                                            (GtkTreeView *tree_view);
-void        gtk_tree_view_set_hover_selection
-                                            (GtkTreeView *tree_view,
-                                             gboolean hover);
-gboolean    gtk_tree_view_get_hover_expand  (GtkTreeView *tree_view);
-void        gtk_tree_view_set_hover_expand  (GtkTreeView *tree_view,
-                                             gboolean expand);
-*/
-
 /* How can I implement this?
 GtkTreeViewRowSeparatorFunc gtk_tree_view_get_row_separator_func
                                             (GtkTreeView *tree_view);
@@ -603,7 +600,7 @@ row_separator_func(GtkTreeModel *model, GtkTreeIter *iter, gpointer func)
 }
 
 static VALUE
-treeview_set_row_separator_func(VALUE self)
+rg_set_row_separator_func(VALUE self)
 {
     VALUE func = rb_block_proc();
 
@@ -618,13 +615,13 @@ treeview_set_row_separator_func(VALUE self)
 
 #if GTK_CHECK_VERSION(2,10,0)
 static VALUE
-treeview_get_search_entry(VALUE self)
+rg_search_entry(VALUE self)
 {
     return GOBJ2RVAL(gtk_tree_view_get_search_entry(_SELF(self)));
 }
 
 static VALUE
-treeview_set_search_entry(VALUE self, VALUE entry)
+rg_set_search_entry(VALUE self, VALUE entry)
 {
     gtk_tree_view_set_search_entry(_SELF(self), RVAL2GOBJ(entry));
     return self;
@@ -667,9 +664,8 @@ remove_callback_reference(gpointer data)
     G_CHILD_REMOVE(mGtk, (VALUE)data);
 }
 
-
 static VALUE
-treeview_set_search_position_func(VALUE self)
+rg_set_search_position_func(VALUE self)
 {
     VALUE func = rb_block_proc();
     G_CHILD_ADD(mGtk, func);
@@ -681,118 +677,94 @@ treeview_set_search_position_func(VALUE self)
 }
 
 #endif
-/* Defined as properties
-gboolean    gtk_tree_view_get_headers_clickable
-                                            (GtkTreeView *tree_view);
-void        gtk_tree_view_set_headers_clickable
-                                            (GtkTreeView *tree_view,
-                                             gboolean setting);
-gboolean    gtk_tree_view_get_rubber_banding
-                                            (GtkTreeView *tree_view);
-void        gtk_tree_view_set_rubber_banding
-                                            (GtkTreeView *tree_view,
-                                             gboolean enable);
-gboolean    gtk_tree_view_get_enable_tree_lines
-                                            (GtkTreeView *tree_view);
-void        gtk_tree_view_set_enable_tree_lines
-                                            (GtkTreeView *tree_view,
-                                             gboolean enabled);
-
-// Use Gtk::TreeView#enable_grid_lines, #set_enable_grid_lines instead.
-GtkTreeViewGridLines gtk_tree_view_get_grid_lines
-                                            (GtkTreeView *tree_view);
-
-void        gtk_tree_view_set_grid_lines    (GtkTreeView *tree_view,
-                                             GtkTreeViewGridLines grid_lines);
-*/
 
 void 
-Init_gtk_treeview()
+Init_gtk_treeview(VALUE mGtk)
 {
-    VALUE gTv = G_DEF_CLASS(GTK_TYPE_TREE_VIEW, "TreeView", mGtk);
+    VALUE RG_TARGET_NAMESPACE = G_DEF_CLASS(GTK_TYPE_TREE_VIEW, "TreeView", mGtk);
 
     id_selection = rb_intern("selection");
     id_model = rb_intern("model");
 
-    rb_define_method(gTv, "initialize", treeview_initialize, -1);
-    rb_define_method(gTv, "selection", treeview_get_selection, 0);
-    rb_define_method(gTv, "columns_autosize", treeview_columns_autosize, 0);
-    rb_define_method(gTv, "append_column", treeview_append_column, 1);
-    rb_define_method(gTv, "remove_column", treeview_remove_column, 1);
-    rb_define_method(gTv, "insert_column", treeview_insert_column, -1);
-    rb_define_method(gTv, "get_column", treeview_get_column, 1);
-    rb_define_method(gTv, "columns", treeview_get_columns, 0);
-    rb_define_method(gTv, "move_column_after", treeview_move_column_after, 2);
-    rb_define_method(gTv, "set_column_drag_function", treeview_set_column_drag_function, 0);
-    rb_define_method(gTv, "scroll_to_point", treeview_scroll_to_point, 2);
-    rb_define_method(gTv, "scroll_to_cell", treeview_scroll_to_cell, 5);
-    rb_define_method(gTv, "set_cursor", treeview_set_cursor, 3);
-    rb_define_method(gTv, "cursor", treeview_get_cursor, 0);
-    rb_define_method(gTv, "expand_all", treeview_expand_all, 0);
-    rb_define_method(gTv, "collapse_all", treeview_collapse_all, 0);
-    rb_define_method(gTv, "expand_row", treeview_expand_row, 2);
-    rb_define_method(gTv, "collapse_row", treeview_collapse_row, 1);
+    RG_DEF_METHOD(initialize, -1);
+    RG_DEF_METHOD(selection, 0);
+    RG_DEF_METHOD(columns_autosize, 0);
+    RG_DEF_METHOD(append_column, 1);
+    RG_DEF_METHOD(remove_column, 1);
+    RG_DEF_METHOD(insert_column, -1);
+    RG_DEF_METHOD(get_column, 1);
+    RG_DEF_METHOD(columns, 0);
+    RG_DEF_METHOD(move_column_after, 2);
+    RG_DEF_METHOD(set_column_drag_function, 0);
+    RG_DEF_METHOD(scroll_to_point, 2);
+    RG_DEF_METHOD(scroll_to_cell, 5);
+    RG_DEF_METHOD(set_cursor, 3);
+    RG_DEF_METHOD(cursor, 0);
+    RG_DEF_METHOD(expand_all, 0);
+    RG_DEF_METHOD(collapse_all, 0);
+    RG_DEF_METHOD(expand_row, 2);
+    RG_DEF_METHOD(collapse_row, 1);
 #if GTK_CHECK_VERSION(2,2,0)
-    rb_define_method(gTv, "expand_to_path", treeview_expand_to_path, 1);
+    RG_DEF_METHOD(expand_to_path, 1);
 #endif
-    rb_define_method(gTv, "map_expanded_rows", treeview_map_expanded_rows, 0);
-    rb_define_method(gTv, "row_expanded?", treeview_row_expanded, 1);
-    rb_define_method(gTv, "get_path_at_pos", treeview_get_path_at_pos, 2);
-    rb_define_alias(gTv, "get_path", "get_path_at_pos");
-    rb_define_method(gTv, "get_cell_area", treeview_get_cell_area, 2);
-    rb_define_method(gTv, "get_background_area", treeview_get_background_area, 2);
-    rb_define_method(gTv, "visible_rect", treeview_get_visible_rect, 0);
+    RG_DEF_METHOD(map_expanded_rows, 0);
+    RG_DEF_METHOD_P(row_expanded, 1);
+    RG_DEF_METHOD(get_path_at_pos, 2);
+    RG_DEF_ALIAS("get_path", "get_path_at_pos");
+    RG_DEF_METHOD(get_cell_area, 2);
+    RG_DEF_METHOD(get_background_area, 2);
+    RG_DEF_METHOD(visible_rect, 0);
 #if GTK_CHECK_VERSION(2,8,0)
-    rb_define_method(gTv, "visible_range", treeview_get_visible_range, 0);
+    RG_DEF_METHOD(visible_range, 0);
 #endif
 
-    rb_define_method(gTv, "bin_window", treeview_get_bin_window, 0);
-    rb_define_method(gTv, "widget_to_tree_coords", treeview_widget_to_tree_coords, 2);
-    rb_define_method(gTv, "tree_to_widget_coords", treeview_tree_to_widget_coords, 2);
+    RG_DEF_METHOD(bin_window, 0);
+    RG_DEF_METHOD(widget_to_tree_coords, 2);
+    RG_DEF_METHOD(tree_to_widget_coords, 2);
 #if GTK_CHECK_VERSION(2,12,0)
-    rb_define_method(gTv, "convert_bin_window_to_tree_coords", treeview_convert_bin_window_to_tree_coords, 2);
-    rb_define_method(gTv, "convert_bin_window_to_widget_coords", treeview_convert_bin_window_to_widget_coords, 2);
-    rb_define_method(gTv, "convert_tree_to_bin_window_coords", treeview_convert_tree_to_bin_window_coords, 2);
-    rb_define_method(gTv, "convert_tree_to_widget_coords", treeview_convert_tree_to_widget_coords, 2);
-    rb_define_method(gTv, "convert_widget_to_bin_window_coords", treeview_convert_widget_to_bin_window_coords, 2);
-    rb_define_method(gTv, "convert_widget_to_tree_coords", treeview_convert_widget_to_tree_coords, 2);
+    RG_DEF_METHOD(convert_bin_window_to_tree_coords, 2);
+    RG_DEF_METHOD(convert_bin_window_to_widget_coords, 2);
+    RG_DEF_METHOD(convert_tree_to_bin_window_coords, 2);
+    RG_DEF_METHOD(convert_tree_to_widget_coords, 2);
+    RG_DEF_METHOD(convert_widget_to_bin_window_coords, 2);
+    RG_DEF_METHOD(convert_widget_to_tree_coords, 2);
 #endif
-    rb_define_method(gTv, "enable_model_drag_dest", treeview_enable_model_drag_dest, 2);
-    rb_define_method(gTv, "enable_model_drag_source", treeview_enable_model_drag_source, 3);
-    rb_define_method(gTv, "unset_rows_drag_source", treeview_unset_rows_drag_source, 0);
-    rb_define_method(gTv, "unset_rows_drag_dest", treeview_unset_rows_drag_dest, 0);
-    rb_define_method(gTv, "set_drag_dest_row", treeview_set_drag_dest_row, 2);
-    rb_define_method(gTv, "drag_dest_row", treeview_get_drag_dest_row, 0);
-    rb_define_method(gTv, "get_dest_row_at_pos", treeview_get_dest_row_at_pos, 2);
-    rb_define_alias(gTv, "get_dest_row", "get_dest_row_at_pos");
-    rb_define_method(gTv, "create_row_drag_icon", treeview_create_row_drag_icon, 1);
-    rb_define_method(gTv, "set_search_equal_func", treeview_set_search_equal_func, 0);
+    RG_DEF_METHOD(enable_model_drag_dest, 2);
+    RG_DEF_METHOD(enable_model_drag_source, 3);
+    RG_DEF_METHOD(unset_rows_drag_source, 0);
+    RG_DEF_METHOD(unset_rows_drag_dest, 0);
+    RG_DEF_METHOD(set_drag_dest_row, 2);
+    RG_DEF_METHOD(drag_dest_row, 0);
+    RG_DEF_METHOD(get_dest_row_at_pos, 2);
+    RG_DEF_ALIAS("get_dest_row", "get_dest_row_at_pos");
+    RG_DEF_METHOD(create_row_drag_icon, 1);
+    RG_DEF_METHOD(set_search_equal_func, 0);
 #if GTK_CHECK_VERSION(2,2,0)
-    rb_define_method(gTv, "set_cursor_on_cell", treeview_set_cursor_on_cell, 4);
+    RG_DEF_METHOD(set_cursor_on_cell, 4);
 #endif
 
 #if GTK_CHECK_VERSION(2,6,0)
-    rb_define_method(gTv, "set_row_separator_func", treeview_set_row_separator_func, 0);
+    RG_DEF_METHOD(set_row_separator_func, 0);
 #endif
 #if GTK_CHECK_VERSION(2,10,0)
-    rb_define_method(gTv, "search_entry", treeview_get_search_entry, 0);
-    rb_define_method(gTv, "set_search_entry", treeview_set_search_entry, 1);
-    rb_define_method(gTv, "set_search_position_func", treeview_set_search_position_func, 0);
+    RG_DEF_METHOD(search_entry, 0);
+    RG_DEF_METHOD(set_search_entry, 1);
+    RG_DEF_METHOD(set_search_position_func, 0);
 #endif
 
     /* Constants */
-    G_DEF_CLASS(GTK_TYPE_TREE_VIEW_DROP_POSITION, "DropPosition", gTv);
-    G_DEF_CONSTANTS(gTv, GTK_TYPE_TREE_VIEW_DROP_POSITION, "GTK_TREE_VIEW_");
+    G_DEF_CLASS(GTK_TYPE_TREE_VIEW_DROP_POSITION, "DropPosition", RG_TARGET_NAMESPACE);
+    G_DEF_CONSTANTS(RG_TARGET_NAMESPACE, GTK_TYPE_TREE_VIEW_DROP_POSITION, "GTK_TREE_VIEW_");
 
 #if GTK_CHECK_VERSION(2,10,0)
     /* GtkTreeViewGridLines */
-    G_DEF_CLASS(GTK_TYPE_TREE_VIEW_GRID_LINES, "GridLines", gTv);
-    G_DEF_CONSTANTS(gTv, GTK_TYPE_TREE_VIEW_GRID_LINES, "GTK_TREE_VIEW_");
+    G_DEF_CLASS(GTK_TYPE_TREE_VIEW_GRID_LINES, "GridLines", RG_TARGET_NAMESPACE);
+    G_DEF_CONSTANTS(RG_TARGET_NAMESPACE, GTK_TYPE_TREE_VIEW_GRID_LINES, "GTK_TREE_VIEW_");
 #endif
 
     /* Option Signals */
-    G_DEF_SIGNAL_FUNC(gTv, "row-collapsed", (GValToRValSignalFunc)treeview_signal_func);
-    G_DEF_SIGNAL_FUNC(gTv, "row-expanded", (GValToRValSignalFunc)treeview_signal_func);
-    G_DEF_SIGNAL_FUNC(gTv, "test-collapse-row", (GValToRValSignalFunc)treeview_signal_func);
-    G_DEF_SIGNAL_FUNC(gTv, "test-expand-row", (GValToRValSignalFunc)treeview_signal_func);
+    G_DEF_SIGNAL_FUNC(RG_TARGET_NAMESPACE, "row-collapsed", (GValToRValSignalFunc)treeview_signal_func);
+    G_DEF_SIGNAL_FUNC(RG_TARGET_NAMESPACE, "row-expanded", (GValToRValSignalFunc)treeview_signal_func);
+    G_DEF_SIGNAL_FUNC(RG_TARGET_NAMESPACE, "test-collapse-row", (GValToRValSignalFunc)treeview_signal_func);
+    G_DEF_SIGNAL_FUNC(RG_TARGET_NAMESPACE, "test-expand-row", (GValToRValSignalFunc)treeview_signal_func);
 }
