@@ -1,21 +1,32 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
-/************************************************
-
-  rbgtktreeviewcolumn.c -
-
-  $Author: ggc $
-  $Date: 2007/07/13 16:07:32 $
-
-  Copyright (C) 2002-2004 Masao Mutoh
-************************************************/
+/*
+ *  Copyright (C) 2011  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2002-2004 Masao Mutoh
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
+ */
 
 #include "global.h"
 
+#define RG_TARGET_NAMESPACE cTreeViewColumn
 #define _SELF(s) (GTK_TREE_VIEW_COLUMN(RVAL2GOBJ(s)))
 #define RVAL2CELLRENDERER(c) (GTK_CELL_RENDERER(RVAL2GOBJ(c)))
 
 static VALUE
-tvc_initialize(int argc, VALUE *argv, VALUE self)
+rg_initialize(int argc, VALUE *argv, VALUE self)
 {
     int i;
     int col;
@@ -54,7 +65,7 @@ tvc_initialize(int argc, VALUE *argv, VALUE self)
 }
 
 static VALUE
-tvc_pack_start(VALUE self, VALUE cell, VALUE expand)
+rg_pack_start(VALUE self, VALUE cell, VALUE expand)
 {
     G_CHILD_ADD(self, cell);
     gtk_tree_view_column_pack_start(_SELF(self), RVAL2CELLRENDERER(cell), RVAL2CBOOL(expand));
@@ -62,7 +73,7 @@ tvc_pack_start(VALUE self, VALUE cell, VALUE expand)
 }
 
 static VALUE
-tvc_pack_end(VALUE self, VALUE cell, VALUE expand)
+rg_pack_end(VALUE self, VALUE cell, VALUE expand)
 {
     G_CHILD_ADD(self, cell);
     gtk_tree_view_column_pack_end(_SELF(self), RVAL2CELLRENDERER(cell), RVAL2CBOOL(expand));
@@ -70,7 +81,7 @@ tvc_pack_end(VALUE self, VALUE cell, VALUE expand)
 }
 
 static VALUE
-tvc_clear(VALUE self)
+rg_clear(VALUE self)
 {
     G_CHILD_REMOVE_ALL(self);
     gtk_tree_view_column_clear(_SELF(self));
@@ -78,13 +89,13 @@ tvc_clear(VALUE self)
 }
 
 static VALUE
-tvc_get_cell_renderers(VALUE self)
+rg_cell_renderers(VALUE self)
 {
     return GLIST2ARYF(gtk_tree_view_column_get_cell_renderers(_SELF(self)));
 }
 
 static VALUE
-tvc_add_attribute(VALUE self, VALUE cell, VALUE attribute, VALUE column)
+rg_add_attribute(VALUE self, VALUE cell, VALUE attribute, VALUE column)
 {
     const gchar *name;
     if (SYMBOL_P(attribute)) {
@@ -98,7 +109,7 @@ tvc_add_attribute(VALUE self, VALUE cell, VALUE attribute, VALUE column)
 }
 
 static VALUE
-tvc_set_attributes(VALUE self, VALUE renderer, VALUE attributes)
+rg_set_attributes(VALUE self, VALUE renderer, VALUE attributes)
 {
     GtkTreeViewColumn *tvc;
     GtkCellRenderer *grenderer;
@@ -135,9 +146,8 @@ cell_data_func(GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, GtkTreeMod
                GTKTREEITER2RVAL(iter));
 }
 
-
 static VALUE
-tvc_set_cell_data_func(VALUE self, VALUE renderer)
+rg_set_cell_data_func(VALUE self, VALUE renderer)
 {
     volatile VALUE func = rb_block_proc();
     G_RELATIVE(self, func);
@@ -148,35 +158,21 @@ tvc_set_cell_data_func(VALUE self, VALUE renderer)
 }
 
 static VALUE
-tvc_clear_attributes(VALUE self, VALUE cell)
+rg_clear_attributes(VALUE self, VALUE cell)
 {
     gtk_tree_view_column_clear_attributes(_SELF(self), RVAL2CELLRENDERER(cell));
     return self;
 }
 
-/* Defined as Properties:
-void                gtk_tree_view_column_set_spacing    (GtkTreeViewColumn *tree_column,
-                                                         gint spacing);
-gint                gtk_tree_view_column_get_spacing    (GtkTreeViewColumn *tree_column);
-*/
-
 static VALUE
-tvc_clicked(VALUE self)
+rg_clicked(VALUE self)
 {
     gtk_tree_view_column_clicked(_SELF(self));
     return self;
 }
 
-/* Defined as Properties:
-void                gtk_tree_view_column_set_sort_column_id
-                                                        (GtkTreeViewColumn *tree_column,
-                                                         gint sort_column_id);
-gint                gtk_tree_view_column_get_sort_column_id
-                                                        (GtkTreeViewColumn *tree_column);
-*/
-
 static VALUE
-tvc_cell_set_cell_data(VALUE self, VALUE model, VALUE iter, VALUE is_expander, VALUE is_expanded)
+rg_cell_set_cell_data(VALUE self, VALUE model, VALUE iter, VALUE is_expander, VALUE is_expanded)
 {
     gtk_tree_view_column_cell_set_cell_data(_SELF(self), 
                                             GTK_TREE_MODEL(RVAL2GOBJ(model)),
@@ -187,7 +183,7 @@ tvc_cell_set_cell_data(VALUE self, VALUE model, VALUE iter, VALUE is_expander, V
 }
 
 static VALUE
-tvc_cell_get_size(VALUE self)
+rg_cell_size(VALUE self)
 {
     GdkRectangle cell_area;
     gint x_offset, y_offset, width, height;
@@ -216,7 +212,7 @@ tvc_cell_get_size(VALUE self)
 }
 
 static VALUE
-tvc_cell_is_visible(VALUE self)
+rg_cell_is_visible_p(VALUE self)
 {
     return CBOOL2RVAL(gtk_tree_view_column_cell_is_visible(_SELF(self)));
 }
@@ -224,7 +220,7 @@ tvc_cell_is_visible(VALUE self)
 #if GTK_CHECK_VERSION(2,2,0)
 
 static VALUE
-tvc_focus_cell(VALUE self, VALUE renderer)
+rg_focus_cell(VALUE self, VALUE renderer)
 {
     gtk_tree_view_column_focus_cell(_SELF(self), RVAL2CELLRENDERER(renderer));
 
@@ -235,7 +231,7 @@ tvc_focus_cell(VALUE self, VALUE renderer)
 
 #if GTK_CHECK_VERSION(2,8,0)
 static VALUE
-tvc_queue_resize(VALUE self)
+rg_queue_resize(VALUE self)
 {
     gtk_tree_view_column_queue_resize(_SELF(self));
     return self;
@@ -244,41 +240,60 @@ tvc_queue_resize(VALUE self)
 
 #if GTK_CHECK_VERSION(2,12,0)
 static VALUE
-tvc_get_tree_view(VALUE self)
+rg_tree_view(VALUE self)
 {
     return GOBJ2RVAL(gtk_tree_view_column_get_tree_view(_SELF(self)));
 }
 #endif
 
+#if !GTK_CHECK_VERSION(2,18,0)
+static VALUE
+rg_sort_column_id(VALUE self)
+{
+    return INT2NUM(gtk_tree_view_column_get_sort_column_id(_SELF(self)));
+}
+
+static VALUE
+rg_set_sort_column_id(VALUE self, VALUE id)
+{
+    gtk_tree_view_column_set_sort_column_id(_SELF(self), NUM2INT(id));
+    return self;
+}
+#endif
 
 void
-Init_gtk_treeviewcolumn()
+Init_gtk_treeviewcolumn(VALUE mGtk)
 {
-    VALUE tvc = G_DEF_CLASS(GTK_TYPE_TREE_VIEW_COLUMN, "TreeViewColumn", mGtk);
+    VALUE RG_TARGET_NAMESPACE = G_DEF_CLASS(GTK_TYPE_TREE_VIEW_COLUMN, "TreeViewColumn", mGtk);
 
-    rb_define_method(tvc, "initialize", tvc_initialize, -1);
-    rb_define_method(tvc, "pack_start", tvc_pack_start, 2);
-    rb_define_method(tvc, "pack_end", tvc_pack_end, 2);
-    rb_define_method(tvc, "clear", tvc_clear, 0);
-    rb_define_method(tvc, "cell_renderers", tvc_get_cell_renderers, 0);
-    rb_define_method(tvc, "add_attribute", tvc_add_attribute, 3);
-    rb_define_method(tvc, "set_attributes", tvc_set_attributes, 2);
-    rb_define_method(tvc, "set_cell_data_func", tvc_set_cell_data_func, 1);
-    rb_define_method(tvc, "clear_attributes", tvc_clear_attributes, 1);
-    rb_define_method(tvc, "clicked", tvc_clicked, 0);
-    rb_define_method(tvc, "cell_set_cell_data", tvc_cell_set_cell_data, 4);
-    rb_define_method(tvc, "cell_size", tvc_cell_get_size, 0);
-    rb_define_method(tvc, "cell_is_visible?", tvc_cell_is_visible, 0);
+    RG_DEF_METHOD(initialize, -1);
+    RG_DEF_METHOD(pack_start, 2);
+    RG_DEF_METHOD(pack_end, 2);
+    RG_DEF_METHOD(clear, 0);
+    RG_DEF_METHOD(cell_renderers, 0);
+    RG_DEF_METHOD(add_attribute, 3);
+    RG_DEF_METHOD(set_attributes, 2);
+    RG_DEF_METHOD(set_cell_data_func, 1);
+    RG_DEF_METHOD(clear_attributes, 1);
+    RG_DEF_METHOD(clicked, 0);
+    RG_DEF_METHOD(cell_set_cell_data, 4);
+    RG_DEF_METHOD(cell_size, 0);
+    RG_DEF_METHOD_P(cell_is_visible, 0);
 #if GTK_CHECK_VERSION(2,2,0)
-    rb_define_method(tvc, "focus_cell", tvc_focus_cell, 1);
+    RG_DEF_METHOD(focus_cell, 1);
 #endif
 #if GTK_CHECK_VERSION(2,8,0)
-    rb_define_method(tvc, "queue_resize", tvc_queue_resize, 0);
+    RG_DEF_METHOD(queue_resize, 0);
 #endif
 #if GTK_CHECK_VERSION(2,12,0)
-    rb_define_method(tvc, "tree_view", tvc_get_tree_view, 0);
+    RG_DEF_METHOD(tree_view, 0);
+#endif
+#if !GTK_CHECK_VERSION(2,18,0)
+    RG_DEF_METHOD(sort_column_id, 0);
+    RG_DEF_METHOD(set_sort_column_id, 1);
+    RG_DEF_ALIAS("sort_column_id=", "set_sort_column_id");
 #endif
     /* GtkTreeViewColumnSizing */
-    G_DEF_CLASS(GTK_TYPE_TREE_VIEW_COLUMN_SIZING, "Sizing", tvc);
-    G_DEF_CONSTANTS(tvc, GTK_TYPE_TREE_VIEW_COLUMN_SIZING, "GTK_TREE_VIEW_COLUMN_");
+    G_DEF_CLASS(GTK_TYPE_TREE_VIEW_COLUMN_SIZING, "Sizing", RG_TARGET_NAMESPACE);
+    G_DEF_CONSTANTS(RG_TARGET_NAMESPACE, GTK_TYPE_TREE_VIEW_COLUMN_SIZING, "GTK_TREE_VIEW_COLUMN_");
 }
