@@ -7,7 +7,7 @@
 
 require 'gtk2'
 
-base_dir = Pathname.new(__FILE__).dirname.dirname.dirname.expand_path
+base_dir = Pathname.new(__FILE__).dirname.dirname.expand_path
 vendor_dir = base_dir + "vendor" + "local"
 vendor_bin_dir = vendor_dir + "bin"
 GLib.prepend_environment_path(vendor_bin_dir)
