@@ -1,17 +1,29 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
-/************************************************
+/*
+ *  Copyright (C) 2011  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2002-2005 Masao Mutoh
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
+ */
 
-  rbpangoattribute.c -
+#include "rbpangoprivate.h"
 
-  $Author: ggc $
-  $Date: 2007/07/13 16:07:33 $
+#define RG_TARGET_NAMESPACE pattr
 
-  Copyright (C) 2002-2005 Masao Mutoh
-************************************************/
-
-#include "rbpango.h"
-
-VALUE pattr, attrstring, pattrint, pattrfloat, pattrcolor, pattrbool;
+VALUE RG_TARGET_NAMESPACE, attrstring, pattrint, pattrfloat, pattrcolor, pattrbool;
 static VALUE type_to_klass;
 
 /***********************************************/
@@ -29,7 +41,7 @@ pango_get_attribute_klass(VALUE attr_type)
     if (TYPE(attr_type) == T_STRING){
         const char *strtype = RVAL2CSTR(attr_type);
         if (strcmp(strtype, "Attribute") == 0){
-            type = pattr;
+            type = RG_TARGET_NAMESPACE;
         } else if (strcmp(strtype, "AttrString") == 0){
             type = attrstring;
         } else if (strcmp(strtype, "AttrInt") == 0){
@@ -63,7 +75,7 @@ pango_get_attribute(VALUE attr)
 
     if (NIL_P(attr)) return NULL;
 
-    if (!rb_obj_is_kind_of(attr, pattr)) {
+    if (!rb_obj_is_kind_of(attr, RG_TARGET_NAMESPACE)) {
         rb_raise(rb_eTypeError, "not a Pango::Attribute...");
     }
     Data_Get_Struct(attr, PangoAttribute, gattr);
@@ -72,7 +84,7 @@ pango_get_attribute(VALUE attr)
 
 /***********************************************/
 static VALUE
-attr_s_allocate(VALUE klass)
+rg_s_allocate(VALUE klass)
 {
     /* Don't define destroy method here.
        return Data_Wrap_Struct(klass, 0, pango_attribute_destroy, 0);
@@ -84,9 +96,9 @@ attr_s_allocate(VALUE klass)
 #define attr_s_new rb_class_new_instance
 #else
 static VALUE
-attr_s_new(int argc, VALUE *argv, VALUE klass)
+rg_s_new(int argc, VALUE *argv, VALUE klass)
 {
-    VALUE obj = attr_s_allocate(klass);
+    VALUE obj = rg_s_allocate(klass);
     rb_obj_call_init(obj, argc, argv);
     return obj;
 }
@@ -105,13 +117,13 @@ gboolean    pango_parse_markup              (const char *markup_text,
 */
 
 static VALUE
-attr_s_type_register(VALUE self, VALUE name)
+rg_s_type_register(G_GNUC_UNUSED VALUE self, VALUE name)
 {
     return INT2NUM(pango_attr_type_register(RVAL2CSTR(name)));
 }
 
 static VALUE
-attr_equal(VALUE self, VALUE other)
+rg_operator_attr_equal(VALUE self, VALUE other)
 {
     return CBOOL2RVAL(pango_attribute_equal(RVAL2ATTR(self), RVAL2ATTR(other)));
 }
@@ -121,26 +133,26 @@ attr_equal(VALUE self, VALUE other)
  */
 /* PangoAttribute */
 static VALUE
-attr_start_index(VALUE self)
+rg_start_index(VALUE self)
 {
     return UINT2NUM(RVAL2ATTR(self)->start_index);
 }
 
 static VALUE
-attr_set_start_index(VALUE self, VALUE value)
+rg_set_start_index(VALUE self, VALUE value)
 {
     RVAL2ATTR(self)->start_index = NUM2UINT(value);
     return Qnil;
 }
 
 static VALUE
-attr_end_index(VALUE self)
+rg_end_index(VALUE self)
 {
     return UINT2NUM(RVAL2ATTR(self)->end_index);
 }
 
 static VALUE
-attr_set_end_index(VALUE self, VALUE value)
+rg_set_end_index(VALUE self, VALUE value)
 {
     RVAL2ATTR(self)->end_index = NUM2UINT(value);
     return Qnil;
@@ -157,7 +169,7 @@ attr_string_value(VALUE self)
 static VALUE
 attr_language_value(VALUE self)
 {
-    return BOXED2RVAL(((PangoAttrLanguage*)RVAL2ATTR(self))->value, PANGO_TYPE_LANGUAGE);
+    return PANGOLANGUAGE2RVAL(((PangoAttrLanguage*)RVAL2ATTR(self))->value);
 }
 
 /* PangoAttrColor */
@@ -165,7 +177,7 @@ static VALUE
 attr_color_value(VALUE self)
 {
     PangoColor color = ((PangoAttrColor*)RVAL2ATTR(self))->color;
-    return BOXED2RVAL(&color, PANGO_TYPE_COLOR);
+    return PANGOCOLOR2RVAL(&color);
 }
 
 /* PangoAttrInt */
@@ -193,7 +205,7 @@ attr_bool_value(VALUE self)
 static VALUE
 attr_fontdesc_value(VALUE self)
 {
-    return BOXED2RVAL(((PangoAttrFontDesc*)RVAL2ATTR(self))->desc, PANGO_TYPE_FONT_DESCRIPTION);
+    return PANGOFONTDESCRIPTION2RVAL(((PangoAttrFontDesc*)RVAL2ATTR(self))->desc);
 }
 
 /* PangoAttrShape */
@@ -201,14 +213,14 @@ static VALUE
 attr_shape_ink_rect(VALUE self)
 {
     PangoRectangle rect = ((PangoAttrShape*)RVAL2ATTR(self))->ink_rect;
-    return BOXED2RVAL(&rect, PANGO_TYPE_RECTANGLE);
+    return PANGORECTANGLE2RVAL(&rect);
 }
 
 static VALUE
 attr_shape_logical_rect(VALUE self)
 {
     PangoRectangle rect = ((PangoAttrShape*)RVAL2ATTR(self))->logical_rect;
-    return BOXED2RVAL(&rect, PANGO_TYPE_RECTANGLE);
+    return PANGORECTANGLE2RVAL(&rect);
 }
 
 static VALUE
@@ -240,7 +252,7 @@ static VALUE
 attr_AttrLanguage_initialize(VALUE self, VALUE lang)
 {
     DATA_PTR(self) = pango_attr_language_new(
-                     (PangoLanguage*)RVAL2BOXED(lang, PANGO_TYPE_LANGUAGE));
+                     RVAL2PANGOLANGUAGE(lang));
     return Qnil;
 }
 
@@ -275,14 +287,14 @@ attr_AttrAbsoluteSize_initialize(VALUE self, VALUE size)
 static VALUE
 attr_AttrGravity_initialize(VALUE self, VALUE gravity)
 {
-    DATA_PTR(self) = pango_attr_gravity_new(RVAL2GENUM(gravity, PANGO_TYPE_GRAVITY));
+    DATA_PTR(self) = pango_attr_gravity_new(RVAL2PANGOGRAVITY(gravity));
     return Qnil;
 }
 
 static VALUE
 attr_AttrGravityHint_initialize(VALUE self, VALUE gravity_hint)
 {
-    DATA_PTR(self) = pango_attr_gravity_hint_new(RVAL2GENUM(gravity_hint, PANGO_TYPE_GRAVITY_HINT));
+    DATA_PTR(self) = pango_attr_gravity_hint_new(RVAL2PANGOGRAVITYHINT(gravity_hint));
     return Qnil;
 }
 #endif
@@ -290,10 +302,7 @@ attr_AttrGravityHint_initialize(VALUE self, VALUE gravity_hint)
 static VALUE
 attr_AttrFontDescription_initialize(VALUE self, VALUE fontdescription)
 {
-    DATA_PTR(self) = pango_attr_font_desc_new(
-        (PangoFontDescription*)RVAL2BOXED(fontdescription, 
-                                          PANGO_TYPE_FONT_DESCRIPTION));
-
+    DATA_PTR(self) = pango_attr_font_desc_new(RVAL2PANGOFONTDESCRIPTION(fontdescription));
     return Qnil;
 }
 
@@ -317,7 +326,7 @@ attr_AttrStrikethrough_initialize(VALUE self, VALUE strikethrough)
     DATA_PTR(self) = pango_attr_strikethrough_new(RVAL2CBOOL(strikethrough));
     return Qnil;
 }
-#if HAVE_PANGO_ATTR_STRIKETHROUGH_COLOR_NEW
+#ifdef HAVE_PANGO_ATTR_STRIKETHROUGH_COLOR_NEW
 static VALUE
 attr_AttrStrikethroughColor_initialize(VALUE self, VALUE r, VALUE g, VALUE b)
 {
@@ -327,7 +336,7 @@ attr_AttrStrikethroughColor_initialize(VALUE self, VALUE r, VALUE g, VALUE b)
 #endif
 
 MAKE_ATTRENUM_INIT(AttrUnderline, underline, PANGO_TYPE_UNDERLINE); 
-#if HAVE_PANGO_ATTR_UNDERLINE_COLOR_NEW
+#ifdef HAVE_PANGO_ATTR_UNDERLINE_COLOR_NEW
 static VALUE
 attr_AttrUnderlineColor_initialize(VALUE self, VALUE r, VALUE g, VALUE b)
 {
@@ -340,25 +349,25 @@ static VALUE
 attr_AttrShape_initialize(int argc, VALUE *argv, VALUE self)
 {
     VALUE ink_rect, logical_rect, data;
-    
+
     rb_scan_args(argc, argv, "21", &ink_rect, &logical_rect, &data);
 
     if (NIL_P(data)){
         DATA_PTR(self) = pango_attr_shape_new(
-            (PangoRectangle*)RVAL2BOXED(ink_rect, PANGO_TYPE_RECTANGLE),
-            (PangoRectangle*)RVAL2BOXED(logical_rect, PANGO_TYPE_RECTANGLE));
+            RVAL2PANGORECTANGLE(ink_rect),
+            RVAL2PANGORECTANGLE(logical_rect));
     } else {
 #if PANGO_CHECK_VERSION(1,8,0)
         G_RELATIVE(self, data);
         DATA_PTR(self) = pango_attr_shape_new_with_data(
-            (PangoRectangle*)RVAL2BOXED(ink_rect, PANGO_TYPE_RECTANGLE),
-            (PangoRectangle*)RVAL2BOXED(logical_rect, PANGO_TYPE_RECTANGLE),
+            RVAL2PANGORECTANGLE(ink_rect),
+            RVAL2PANGORECTANGLE(logical_rect),
             (gpointer)data, NULL, NULL);
 #else
         rb_warning("not supported in Pango-1.6.x. the 3rd parameter was ignored.");
         DATA_PTR(self) = pango_attr_shape_new(
-            (PangoRectangle*)RVAL2BOXED(ink_rect, PANGO_TYPE_RECTANGLE),
-            (PangoRectangle*)RVAL2BOXED(logical_rect, PANGO_TYPE_RECTANGLE));     
+            RVAL2PANGORECTANGLE(ink_rect),
+            RVAL2PANGORECTANGLE(logical_rect));     
 #endif
     }
 
@@ -390,53 +399,51 @@ MAKE_ATTRINT_INIT(AttrLetterSpacing, letter_spacing);
 #define MAKE_ATTR(gtype, name, parent, num)\
 tmpklass = rb_define_class_under(mPango, #name, parent);\
 rb_hash_aset(type_to_klass, INT2FIX(gtype), tmpklass);\
-rb_define_method(tmpklass, "initialize", attr_## name ## _initialize , num);
+rbg_define_method(tmpklass, "initialize", attr_## name ## _initialize , num);
 
 void
-Init_pango_attribute()
+Init_pango_attribute(VALUE mPango)
 {
     VALUE tmpklass;
-    pattr = rb_define_class_under(mPango, "Attribute", rb_cData);
+    RG_TARGET_NAMESPACE = rb_define_class_under(mPango, "Attribute", rb_cData);
 
-    rb_define_singleton_method(pattr, "type_register", attr_s_type_register, 1);
-    rb_define_method(pattr, "==", attr_equal, 1);
-    rb_define_method(pattr, "start_index", attr_start_index, 0);
-    rb_define_method(pattr, "set_start_index", attr_set_start_index, 1);
-    rb_define_method(pattr, "end_index", attr_end_index, 0);
-    rb_define_method(pattr, "set_end_index", attr_set_end_index, 1);
-
-    G_DEF_SETTERS(pattr);
+    RG_DEF_SMETHOD(type_register, 1);
+    RG_DEF_METHOD_OPERATOR("==", attr_equal, 1);
+    RG_DEF_METHOD(start_index, 0);
+    RG_DEF_METHOD(set_start_index, 1);
+    RG_DEF_METHOD(end_index, 0);
+    RG_DEF_METHOD(set_end_index, 1);
 
 #ifndef HAVE_RB_DEFINE_ALLOC_FUNC
-    rb_define_singleton_method(pattr, "allocate", attr_s_allocate, 0);
+    RG_DEF_SMETHOD(allocate, 0);
 #else
-    rb_define_alloc_func(pattr, (VALUE(*)_((VALUE)))attr_s_allocate);
+    rb_define_alloc_func(RG_TARGET_NAMESPACE, (VALUE(*)_((VALUE)))rg_s_allocate);
 #endif
 #ifndef HAVE_OBJECT_ALLOCATE
-    rb_define_singleton_method(pattr, "new", attr_s_new, -1);
+    RG_DEF_SMETHOD(new, -1);
 #endif
 
-    attrstring = rb_define_class_under(mPango, "AttrString", pattr);
-    rb_define_method(attrstring, "value", attr_string_value, 0);
+    attrstring = rb_define_class_under(mPango, "AttrString", RG_TARGET_NAMESPACE);
+    rbg_define_method(attrstring, "value", attr_string_value, 0);
 
-    pattrint = rb_define_class_under(mPango, "AttrInt", pattr);
-    rb_define_method(pattrint, "value", attr_int_value, 0);
+    pattrint = rb_define_class_under(mPango, "AttrInt", RG_TARGET_NAMESPACE);
+    rbg_define_method(pattrint, "value", attr_int_value, 0);
 
-    pattrfloat = rb_define_class_under(mPango, "AttrFloat", pattr);
-    rb_define_method(pattrfloat, "value", attr_float_value, 0);
+    pattrfloat = rb_define_class_under(mPango, "AttrFloat", RG_TARGET_NAMESPACE);
+    rbg_define_method(pattrfloat, "value", attr_float_value, 0);
 
-    pattrcolor = rb_define_class_under(mPango, "AttrColor", pattr);
-    rb_define_method(pattrcolor, "value", attr_color_value, 0);
+    pattrcolor = rb_define_class_under(mPango, "AttrColor", RG_TARGET_NAMESPACE);
+    rbg_define_method(pattrcolor, "value", attr_color_value, 0);
 
-    pattrbool = rb_define_class_under(mPango, "AttrBool", pattr);
-    rb_define_method(pattrbool, "value", attr_bool_value, 0);
+    pattrbool = rb_define_class_under(mPango, "AttrBool", RG_TARGET_NAMESPACE);
+    rbg_define_method(pattrbool, "value", attr_bool_value, 0);
 
     rb_global_variable(&type_to_klass);
     type_to_klass = rb_hash_new();
 
-    MAKE_ATTR(PANGO_ATTR_LANGUAGE, AttrLanguage, pattr, 1);
-    rb_define_method(tmpklass, "value", attr_language_value, 0);
-    
+    MAKE_ATTR(PANGO_ATTR_LANGUAGE, AttrLanguage, RG_TARGET_NAMESPACE, 1);
+    rbg_define_method(tmpklass, "value", attr_language_value, 0);
+
     MAKE_ATTR(PANGO_ATTR_FAMILY, AttrFamily, attrstring, 1);
     MAKE_ATTR(PANGO_ATTR_STYLE, AttrStyle, pattrint, 1);
     MAKE_ATTR(PANGO_ATTR_WEIGHT, AttrWeight, pattrint, 1);
@@ -450,30 +457,30 @@ Init_pango_attribute()
     MAKE_ATTR(PANGO_ATTR_GRAVITY, AttrGravity, pattrint, 1);
     MAKE_ATTR(PANGO_ATTR_GRAVITY_HINT, AttrGravityHint, pattrint, 1);
 #endif
-    MAKE_ATTR(PANGO_ATTR_FONT_DESC, AttrFontDescription, pattr, 1);
-    rb_define_method(tmpklass, "value", attr_fontdesc_value, 0);
+    MAKE_ATTR(PANGO_ATTR_FONT_DESC, AttrFontDescription, RG_TARGET_NAMESPACE, 1);
+    rbg_define_method(tmpklass, "value", attr_fontdesc_value, 0);
     MAKE_ATTR(PANGO_ATTR_FOREGROUND, AttrForeground, pattrcolor, 3);
     MAKE_ATTR(PANGO_ATTR_BACKGROUND, AttrBackground, pattrcolor, 3);
     MAKE_ATTR(PANGO_ATTR_UNDERLINE, AttrUnderline, pattrint, 1);
     /* PangoUnderline */
     G_DEF_CLASS(PANGO_TYPE_UNDERLINE, "Underline", tmpklass);
     G_DEF_CONSTANTS(tmpklass, PANGO_TYPE_UNDERLINE, "PANGO_UNDERLINE_");
-#if HAVE_PANGO_ATTR_UNDERLINE_COLOR_NEW
+#ifdef HAVE_PANGO_ATTR_UNDERLINE_COLOR_NEW
     MAKE_ATTR(PANGO_ATTR_UNDERLINE_COLOR, AttrUnderlineColor, pattrcolor, 3);
 #endif
 
     MAKE_ATTR(PANGO_ATTR_STRIKETHROUGH, AttrStrikethrough, pattrbool, 1);
-#if HAVE_PANGO_ATTR_STRIKETHROUGH_COLOR_NEW
+#ifdef HAVE_PANGO_ATTR_STRIKETHROUGH_COLOR_NEW
     MAKE_ATTR(PANGO_ATTR_STRIKETHROUGH_COLOR, AttrStrikethroughColor, pattrcolor, 3);
 #endif
     MAKE_ATTR(PANGO_ATTR_RISE, AttrRise, pattrint, 1);
 #if PANGO_CHECK_VERSION(1,6,0)
     MAKE_ATTR(PANGO_ATTR_LETTER_SPACING, AttrLetterSpacing, pattrint, 1);
 #endif
-    MAKE_ATTR(PANGO_ATTR_SHAPE, AttrShape, pattr, -1);
-    rb_define_method(tmpklass, "ink_rect", attr_shape_ink_rect, 0);
-    rb_define_method(tmpklass, "logical_rect", attr_shape_logical_rect, 0);
-    rb_define_method(tmpklass, "value", attr_shape_value, 0);
+    MAKE_ATTR(PANGO_ATTR_SHAPE, AttrShape, RG_TARGET_NAMESPACE, -1);
+    rbg_define_method(tmpklass, "ink_rect", attr_shape_ink_rect, 0);
+    rbg_define_method(tmpklass, "logical_rect", attr_shape_logical_rect, 0);
+    rbg_define_method(tmpklass, "value", attr_shape_value, 0);
     MAKE_ATTR(PANGO_ATTR_SCALE, AttrScale, pattrfloat, 1);
     /* PangoScale */
     rb_define_const(tmpklass, "XX_SMALL", rb_float_new(PANGO_SCALE_XX_SMALL));
@@ -487,31 +494,31 @@ Init_pango_attribute()
     MAKE_ATTR(PANGO_ATTR_FALLBACK, AttrFallback, pattrbool, 1);
 #endif
     /* PangoAttrType */
-    G_DEF_CLASS(PANGO_TYPE_ATTR_TYPE, "Type", pattr);
+    G_DEF_CLASS(PANGO_TYPE_ATTR_TYPE, "Type", RG_TARGET_NAMESPACE);
 #define INT2ATTRTYPE(x) rbgobj_make_enum((x), PANGO_TYPE_ATTR_TYPE)
-    rb_define_const(pattr, "TYPE_INVALID", INT2ATTRTYPE(PANGO_ATTR_INVALID));
-    rb_define_const(pattr, "TYPE_LANGUAGE", INT2ATTRTYPE(PANGO_ATTR_LANGUAGE));
-    rb_define_const(pattr, "TYPE_FAMILY", INT2ATTRTYPE(PANGO_ATTR_FAMILY));
-    rb_define_const(pattr, "TYPE_STYLE", INT2ATTRTYPE(PANGO_ATTR_STYLE));
-    rb_define_const(pattr, "TYPE_WEIGHT", INT2ATTRTYPE(PANGO_ATTR_WEIGHT));
-    rb_define_const(pattr, "TYPE_VARIANT", INT2ATTRTYPE(PANGO_ATTR_VARIANT));
-    rb_define_const(pattr, "TYPE_STRETCH", INT2ATTRTYPE(PANGO_ATTR_STRETCH));
-    rb_define_const(pattr, "TYPE_SIZE", INT2ATTRTYPE(PANGO_ATTR_SIZE));
-    rb_define_const(pattr, "TYPE_FONT_DESC", INT2ATTRTYPE(PANGO_ATTR_FONT_DESC));
-    rb_define_const(pattr, "TYPE_FOREGROUND", INT2ATTRTYPE(PANGO_ATTR_FOREGROUND));
-    rb_define_const(pattr, "TYPE_BACKGROUND", INT2ATTRTYPE(PANGO_ATTR_BACKGROUND));
-    rb_define_const(pattr, "TYPE_UNDERLINE", INT2ATTRTYPE(PANGO_ATTR_UNDERLINE));
-    rb_define_const(pattr, "TYPE_STRIKETHROUGH", INT2ATTRTYPE(PANGO_ATTR_STRIKETHROUGH));
+    rb_define_const(RG_TARGET_NAMESPACE, "TYPE_INVALID", INT2ATTRTYPE(PANGO_ATTR_INVALID));
+    rb_define_const(RG_TARGET_NAMESPACE, "TYPE_LANGUAGE", INT2ATTRTYPE(PANGO_ATTR_LANGUAGE));
+    rb_define_const(RG_TARGET_NAMESPACE, "TYPE_FAMILY", INT2ATTRTYPE(PANGO_ATTR_FAMILY));
+    rb_define_const(RG_TARGET_NAMESPACE, "TYPE_STYLE", INT2ATTRTYPE(PANGO_ATTR_STYLE));
+    rb_define_const(RG_TARGET_NAMESPACE, "TYPE_WEIGHT", INT2ATTRTYPE(PANGO_ATTR_WEIGHT));
+    rb_define_const(RG_TARGET_NAMESPACE, "TYPE_VARIANT", INT2ATTRTYPE(PANGO_ATTR_VARIANT));
+    rb_define_const(RG_TARGET_NAMESPACE, "TYPE_STRETCH", INT2ATTRTYPE(PANGO_ATTR_STRETCH));
+    rb_define_const(RG_TARGET_NAMESPACE, "TYPE_SIZE", INT2ATTRTYPE(PANGO_ATTR_SIZE));
+    rb_define_const(RG_TARGET_NAMESPACE, "TYPE_FONT_DESC", INT2ATTRTYPE(PANGO_ATTR_FONT_DESC));
+    rb_define_const(RG_TARGET_NAMESPACE, "TYPE_FOREGROUND", INT2ATTRTYPE(PANGO_ATTR_FOREGROUND));
+    rb_define_const(RG_TARGET_NAMESPACE, "TYPE_BACKGROUND", INT2ATTRTYPE(PANGO_ATTR_BACKGROUND));
+    rb_define_const(RG_TARGET_NAMESPACE, "TYPE_UNDERLINE", INT2ATTRTYPE(PANGO_ATTR_UNDERLINE));
+    rb_define_const(RG_TARGET_NAMESPACE, "TYPE_STRIKETHROUGH", INT2ATTRTYPE(PANGO_ATTR_STRIKETHROUGH));
 #if PANGO_CHECK_VERSION(1,8,0)
-    rb_define_const(pattr, "TYPE_STRIKETHROUGH_COLOR", INT2ATTRTYPE(PANGO_ATTR_STRIKETHROUGH_COLOR));
+    rb_define_const(RG_TARGET_NAMESPACE, "TYPE_STRIKETHROUGH_COLOR", INT2ATTRTYPE(PANGO_ATTR_STRIKETHROUGH_COLOR));
 #endif
-    rb_define_const(pattr, "TYPE_RISE", INT2ATTRTYPE(PANGO_ATTR_RISE));
-    rb_define_const(pattr, "TYPE_SHAPE", INT2ATTRTYPE(PANGO_ATTR_SHAPE));
-    rb_define_const(pattr, "TYPE_SCALE", INT2ATTRTYPE(PANGO_ATTR_SCALE));
+    rb_define_const(RG_TARGET_NAMESPACE, "TYPE_RISE", INT2ATTRTYPE(PANGO_ATTR_RISE));
+    rb_define_const(RG_TARGET_NAMESPACE, "TYPE_SHAPE", INT2ATTRTYPE(PANGO_ATTR_SHAPE));
+    rb_define_const(RG_TARGET_NAMESPACE, "TYPE_SCALE", INT2ATTRTYPE(PANGO_ATTR_SCALE));
 #if PANGO_CHECK_VERSION(1,8,0)
-    rb_define_const(pattr, "TYPE_FALLBACK", INT2ATTRTYPE(PANGO_ATTR_FALLBACK));
+    rb_define_const(RG_TARGET_NAMESPACE, "TYPE_FALLBACK", INT2ATTRTYPE(PANGO_ATTR_FALLBACK));
 #endif
 #if PANGO_CHECK_VERSION(1,6,0)
-    rb_define_const(pattr, "TYPE_LETTER_SPACING", INT2ATTRTYPE(PANGO_ATTR_LETTER_SPACING));
+    rb_define_const(RG_TARGET_NAMESPACE, "TYPE_LETTER_SPACING", INT2ATTRTYPE(PANGO_ATTR_LETTER_SPACING));
 #endif
 }
